$title  The GTAP standard model in GAMS.
display "com: The GTAP standard model in GAMS.";
$ontext
Time-stamp:     <2012-12-06 20:38:52 >
Author:     Shiro Takeda
First-written:  <2006/06/22>

Note:

+ The benchmark data and parameters are imported from basedata.gdx and
  default.gdx (which are created from basedata.har and default.prm by har2gdx).
  However, the following PARAMETER and SET must be defined by yourself.

  + The value of RORDELTA (investment allocation binary coefficient) + The set
  of sluggish endowment commodities ("es" in this program).

 You can specify the the value of RORDELTA by assigning the proper value to the
 global variable RORDELTA below and you can specify the SET "es" in
 gtap_set_sluggish.gms file.

+ Parameters fo benchmark data and equations are basically represented by upper
  case identifiers and endogenous ariables are basically represented by lower
  case identifiers although there are some exceptions.

+ I tried to replicate the GTAP model as precisely as possible.  However, some
  linearized equations in gtap.tab cannot be intrinsically transformed to level
  form.  These equations include

   GLOBALINV
   PRICGDS
   PRIMFACTPR
   PRIMFACTPRWLD

  In order to create the model completely written in level form, the
  specification of these equations is slightly modified by me.  This means that
  the results from our model do not intrinsically coincide with those from the
  original GTAP model.  The differences in results from two models are ignorable
  when you add only small shocks.  However, an experiment with large shocks may
  generate highly different results.

+ In the appendix of gtap.tab, many variables are defined in order to report
  various effects.  Such variables are omitte in my program except for some
  variables (e.g. vgdp, EV).

+ Explanatory texts for sets, variables, parameters, and equations are directly
  taken from gtap.tab.

+ This code is likely to include bugs, so be careful when you use it.

$offtext

*   ----------------------------------------------------------------------
*   Important variables:

*	Experiment name:
$if not setglobal exp_name $setglobal exp_name numeraire_shock

*	Parameter file name:
$if not setglobal par_file $setglobal par_file default.prm

*  	Version of GTAP (5 or 6): The parameters in the base data are slightly
*  	different in GTAP ver. 6 and older version.  To handle this, you need to
*  	set the value of the follwoing variable.
$if not setglobal gtap_data_ver $setglobal gtap_data_ver 6

*	The value of RORDELTA (investment allocation binary coefficient): Choose
*	zero or one.
$if not setglobal rordelta $setglobal rordelta 0

*	The name of the closure file that specifies exogenous variables:
$if not setglobal cls_file $setglobal cls_file default.cls

*	The name of the file that executes shock experiment:
$if not setglobal shock_file $setglobal shock_file %exp_name%.shk

*	The name of the file that defines sluggish factor (sluggish endowment
*	commodities):
$if not setglobal sf_file $setglobal sf_file sluggish_factor_default.gms

*	The file name of updated data:
$if not setglobal updated_data_file $setglobal updated_data_file %exp_name%_upd.har

*	The name of solution file:
$if not setglobal solution_file $setglobal solution_file %exp_name%_sol.har

*	Base dataset file name:
$if not setglobal basedata_file $setglobal basedata_file basedata.har

*	Set file name:
$if not setglobal set_file $setglobal set_file sets.har

*	The name of the model file:
$if not setglobal main_model_file $setglobal main_model_file ..\gtap_model.gms

*	The name of a program for exporting solutions:
$if not setglobal solution_program_file $setglobal solution_program_file ..\gtap_export_solution.gms

*	The file name of a program for creating updated data:
$if not setglobal update_program_file $setglobal update_program_file ..\gtap_update_data.gms

*  	If non-zero, proceed up to the calibration:
$if not setglobal calibration_only $setglobal calibration_only 0

*  	If non-zero, proceed up to the benchmark replication:
$if not setglobal bench_rep_only $setglobal bench_rep_only 0

*   	If non-zero, proceed up to the cleanup calculation:
$if not setglobal clean_up_only $setglobal clean_up_only 0

*	Solver choice.  You can solve the model using MCP or NLP solver.  If you
*	solve the model by MCP solver, set non-zero to this variable.  Zero
*	means NLP solver.
$if not setglobal solver_mcp $setglobal solver_mcp 1

*	Type of MCP solver (path or miles):
$if not setglobal mcp_solver $setglobal mcp_solver path

*	Type of NLP solver (minos, conopt, and pathnlp etc).
$if not setglobal nlp_solver $setglobal nlp_solver pathnlp

*	The scale adjustment factor.  The scale of the original data (mil US$)
*	are adjusted (divided) by this factor.
$if not setglobal scale_factor $setglobal scale_factor 1e-3

*	Flag for debug:
$if not setglobal fl_debug $setglobal fl_debug 0

*	The name of the program for repoting ouputs in the appendix:
$if not setglobal appendix_file $setglobal appendix_file ..\gtap_app_output.gms

display "com: ---- Show the values of global variables -----";
display "exp_name =		%exp_name%";
display "par_file =		%par_file%";
display "gtap_data_ver =	%gtap_data_ver%";
display "rordelta =		%rordelta%";
display "cls_file =		%cls_file%";
display "shock_file =		%shock_file%";
display "sf_file =		%sf_file%";
display "updated_data_file =	%updated_data_file%";
display "solution_file =	%solution_file%";
display "basedata_file =	%basedata_file%";
display "set_file =		%set_file%";
display "main_model_file =	%main_model_file%";
display "solution_program_file =	%solution_program_file%";
display "update_program_file =	%update_program_file%";
display "";
display "calibration_only =		%calibration_only%";
display "bench_rep_only =		%bench_rep_only%";
display "clean_up_only =		%clean_up_only%";
display "solver_mcp =		%solver_mcp%";
display "mcp_solver =		%mcp_solver%";
display "nlp_solver =		%nlp_solver%";
display "scale_factor =		%scale_factor%";
display "fl_debug =		%fl_debug%";

*	----------------------------------------------------------------------
*	Option settings

*	Limit reports:
option limrow=0, limcol=0;

*   ----------------------------------------------------------------------
*   Model:
$include %main_model_file%
$if not %calibration_only% == "0" $goto end

*   ----------------------------------------------------------------------
*   Include closure file that sets exogenous variables:
$include .\%cls_file%

*   ----------------------------------------------------------------------
*   Parameters in the appendix of gtap.tab:
* $include ..\gtap_app_parameters.gms

*   ----------------------------------------------------------------------
*   Benchmark replication and clean up calculation:
$setglobal skip_shock 0
$include ..\gtap_bench_replication.gms
$if not %skip_shock% == "0" $goto end

*   ----------------------------------------------------------------------
*   Shocks:
display "com: Shocks:";
$include .\%shock_file%

*   ----------------------------------------------------------------------
*   Output in the appendix:
display "com: Output in the appendix:";
* $include %appendix_file%

*   ----------------------------------------------------------------------
*   Export solutions:
display "com: Export solutions:";
$include %solution_program_file%

*   ----------------------------------------------------------------------
*   Create updated data:
$include %update_program_file%

$label end

execute 'del .\%exp_name%_titlemaker.cmd';

display "com: --- Program ends here ---";

* --------------------
* Local Variables:
* mode: gams
* fill-column: 80
* End:
