$title Parameters declaration for the appendix:
display "com: Parameters declaration for the appendix:";
$ontext
Time-stamp: 	<2012-12-06 19:49:39 >
Author: 	Shiro Takeda
First-written:	<2006/06/23>

The program for reporting EV and GDP.

Summary Indices
Equivalent Variation
Terms of Trade Decomposition

$offtext

*	Summary Indices:
parameter
    psw(r)		"Index of prices received for tradeables produced in r"
    pdw(r)		"Index of prices paid for tradeables used in region r"
    tot(r)		"Terms of trade for region r: tot(r) = psw(r) - pdw(r)"
    vgdp(r)		"Change in value of GDP"
    pgdp(r)		"GDP price index"
    qgdp(r)		"GDP quantity index"
;
parameter
    VXW(*,r)		"Value of exports by comm. i and region r at FOB prices"
    VXWREGION(r)	"Value of exports by region r at FOB prices"
    VIW(*,s)		"Value of commodity imports i into s at CIF prices"
    VIWREGION(r)	"Value of commodity imports by region r at CIF prices"
    VENDWREG(r)		"Value of primary factors, at mkt prices, by region"
    VENDWWLD		"Value of primary factors, at mkt prices, worldwide \\"
    GDP(r)		"Gross Domestic Product in region r"
*     VXWCOMMOD(*)	"Value of world exports by commodity i at FOB prices"
*     VXWLD		"Value of commodity exports, FOB, globally"
*     VIWCOMMOD(*)	"Global value of commodity imports, CIF, by commodity"
*     PW_PM(*,r)		"Ratio of world to domestic prices"
*     VOW(*,r)		"Value of output in r at FOB including transportation services"
*     VWOW(*)		"Value of world supply at world prices for i"
*     VWOU(*)		"Value of world output of i at user prices"
    TBAL(*)		"Trade balance for region r"
;
*	Equivalent variation:
parameter
    uelasev(r)		"Elasticity of cost of utility wrt utility, for EV calc."
    ueprivev(r)		"Utility elasticity of private consn expenditure, for EV calc."
    ugev(r)		"Per capita utility from gov't expend., for EV calc."
    upev(r)		"Per capita utility from private expend., for EV calc."
    qsaveev(r)		"Total quantity of savings demanded, for EV calc."
    yev(r)		"Regional household income in region r, for EV calc."
    ypev(r)		"Private consumption expenditure in region r, for EV calc."
    ygev(r)		"Government consumption expenditure in region r, for EV calc."
    qpev(*,r)		"Private hhld demand for commodity i in region r, for EV calc."
    ysaveev(r)		"Net savings expenditure, for EV calc."
    dpavev(r)		"Average distribution parameter shift, for EV calc."
    EV(*)		"Equivalent variation, \$ US million"
;
*	----------------------------------------------------------------------
*	Parameters for percentage changes:

*	Summary Indices:
parameter
    pc_psw(r)		"Index of prices received for tradeables produced in r"
    pc_pdw(r)		"Index of prices paid for tradeables used in region r"
    pc_tot(r)		"Terms of trade for region r: tot(r) = psw(r) - pdw(r)"
    pc_vgdp(r)		"Change in value of GDP"
    pc_pgdp(r)		"GDP price index"
    pc_qgdp(r)		"GDP quantity index"
;
*	Equivalent variation:
parameter
    EV(*)		"Equivalent variation, \$ US million"
;

*	----------------------------------------------------------------------
*	Level parameters:

parameter
    l_vxwd(*,t,r,s)
    l_vst(*,*,r)
    l_vxw(*,*,*)
    l_vxwregion(*,r)
    l_vxwregion(*,r)
    l_viws(*,t,s,r)
    l_viw(*,*,*)
    l_viwregion(*,r)
    l_gdp(*,*)

    l_vga(*,t,r)
    l_vpa(*,t,r)
    l_reginv(*,r)
;
*	----------------------------------------------------------------------
*	Share paramters:
parameter
    sh_cons(*,t,r)
    sh_vxwd_vxwregion(*,t,r,s)
    sh_vst_vxwregion(*,m,r)
    sh_viws_viwregion(*,t,s,r)

    sh_vga_gdp(*,t,r)
    sh_vpa_gdp(*,t,r)
    sh_reginv_gdp(*,r)
    sh_vxwd_gdp(*,t,r,s)
    sh_vst_gdp(*,m,r)
    sh_viws_gdp(*,t,s,r)
    ;

set	b_c	/ b, c /;

*	----------------------------------------------------------------------
*	Variables and equations for calculating equivalent variation
$ontext

Equivalent variation is defined as

EV = e(p_0,u_1) - e(p_0,u_0)

To derive the value of EV, it is necessary to compute the value of e(p_0,u_1),
that is, the minimum expenditure to realize utility level in the new equilibrium
under the old price vector.

$offtext

variables
    ug_ev(r)		Per capita utility from gov't expend. in region r
    qg_ev(t,r)		Government hhld demand for commodity i in region r
    up_ev(r)		Per capita utility from private expend. in region r
    uepriv_ev(r)	Elasticity of cost wrt utility from private consumption
    vconshr_ev(t,r)	Share of private hhld consumption devoted to good i in r
    qp_ev(t,r)		Private hhld demand for commodity i in region r
    uelas_ev(r)		Elasticity of cost of utility wrt utility
    yp_ev(r)		Regional private consumption expenditure in region r
    yg_ev(r)		Regional government consumption expenditure in region r
    qsave_ev(r)		Regional demand for NET savings
    y_ev(r)		Regional household income in region r

    u_ev(r)		Per capita utility from aggregate hhld expend. in region r
;

equations
    GOVU_EV(r)		"Per capita utility from gov't expend. in region r"
    GOVDMNDS_EV(t,r)	"Government hhld demand for commodity i in region r"
    PRIVATEU_EV(r)	"Per capita utility from private expend. in region r"
    UTILELASPRIV_EV(r)	"Elasticity of cost wrt utility from private consumption"
    E_VCONSHR_EV(t,r)	"Share of private hhld consumption devoted to good i in r"
    PRIVDMNDS_EV(t,r)	"Private hhld demand for commodity i in region r"
    UTILITELASTIC_EV(r)	"Elasticity of cost of utility wrt utility"
    PRIVCONSEXP_EV(r)	"Regional private consumption expenditure in region r"
    GOVCONSEXP_EV(r)	"Regional government consumption expenditure in region r"
    SAVING_EV(r)	"Regional demand for NET savings"
    UTILITY_EV(r)	"Regional household income in region r"

;
$ontext
In equations defined below, all price variables are set to their initial values
(normally unity).  For example, equation GOVU_EV(r) is derived by setting
pgov(r) to unity in the original equation GOVU(r).

GOVU(r) ..

    yg0(r) * yg(r) =e=
    pgov0(r) * pgov(r) * ug0(r) * ug(r) * pop0(r) * pop(r);

$offtext

GOVU_EV(r) ..

    yg0(r) * yg_ev(r)
    =e= pgov0(r) * ug0(r) * ug_ev(r) * pop0(r) * pop(r);

GOVDMNDS_EV(t,r)$qg0(t,r) ..

    qg_ev(t,r) =e= pop(r) * ug_ev(r);

PRIVATEU_EV(r) ..

    sum(t$qp0(t,r),
	SH_BP(t,r) * (up0(r)*up_ev(r))**(SUBPAR(t,r)*INCPAR(t,r))
	* (pp0(t,r)/(yp0(r)*yp_ev(r)/(pop0(r)*pop(r))))**(SUBPAR(t,r)))
    =e= 1;

UTILELASPRIV_EV(r) ..

    uepriv0(r) * uepriv_ev(r) =e=
    sum(t$CONSHR(t,r), vconshr0(t,r) * vconshr_ev(t,r) * INCPAR(t,r));


E_VCONSHR_EV(t,r)$CONSHR(t,r) ..

    vconshr0(t,r) * vconshr_ev(t,r) =e=
    pp0(t,r) * qp0(t,r) * qp_ev(t,r) / (yp0(r)*yp_ev(r));

PRIVDMNDS_EV(t,r)$VPA(t,r) ..

    (qp0(t,r)*qp_ev(t,r)/(pop0(r)*pop(r)))
    =e= (SH_BP(t,r) * (up0(r)*up_ev(r))**(SUBPAR(t,r) * INCPAR(t,r))
	* SUBPAR(t,r)
	* (pp0(t,r)/(yp0(r)*yp_ev(r)/(pop0(r)*pop(r))))**(SUBPAR(t,r) - 1)
    ) /
    (sum(tt, SH_BP(tt,r) * (up0(r)*up_ev(r))**(SUBPAR(tt,r) * INCPAR(tt,r))
	* SUBPAR(tt,r)
	* (pp0(tt,r)/(yp0(r)*yp_ev(r)/(pop0(r)*pop(r))))**(SUBPAR(tt,r))));

UTILITELASTIC_EV(r) ..

    uelas0(r) * uelas_ev(r) =e=
    1 / (dppriv0(r) * dppriv(r) / (uepriv0(r) * uepriv_ev(r))
	+ dpgov0(r) * dpgov(r) + dpsave0(r) * dpsave(r));

PRIVCONSEXP_EV(r) ..

    yp0(r) * yp_ev(r) =e=
    y0(r) * y_ev(r)
    * (uelas0(r)*uelas_ev(r)/(uepriv0(r)*uepriv_ev(r)))
    * dppriv0(r) * dppriv(r);

GOVCONSEXP_EV(r) ..

    yg0(r) * yg_ev(r)
    =e= y0(r) * y_ev(r) * uelas0(r) * uelas_ev(r) * dpgov0(r) * dpgov(r);

SAVING_EV(r) ..

    psave0(r) * qsave0(r) * qsave_ev(r)
    =e= y0(r) * y_ev(r) * uelas0(r) * uelas_ev(r) * dpsave0(r) * dpsave(r);

UTILITY_EV(r) ..

    au(r) * up_ev(r)**(dppriv0(r) * dppriv(r))
    * ug_ev(r)**(dpgov0(r) * dpgov(r))
    * qsave_ev(r)**(dpsave0(r) * dpsave(r))
    =e= u_ev(r);

model ev_calc Model for calculation of equivalent variation

      / GOVU_EV.ug_ev, GOVDMNDS_EV.qg_ev, PRIVATEU_EV.up_ev, UTILELASPRIV_EV.uepriv_ev,
	E_VCONSHR_EV.vconshr_ev, PRIVDMNDS_EV.qp_ev, UTILITELASTIC_EV.uelas_ev,
	PRIVCONSEXP_EV.yp_ev, GOVCONSEXP_EV.yg_ev, SAVING_EV.qsave_ev, UTILITY_EV.y_ev
	/;

*	----------------------------------------------------------------------
*	Initialize parameters in the appendix:
display "com: Initialize parameters in the appendix:";

*	----------------------------------------------------------------------
*	Summary indices:
display "com: -- Summary indices:";

*	Level parameters:
l_vxwd("b",t,r,s) = pfob0(t,r,s)*pfob.l(t,r,s)*qxs0(t,r,s)*qxs.l(t,r,s);
l_vst("b",m,r) = pm0(m,r)*pm.l(m,r)*qst0(m,r)*qst.l(m,r);
l_vxw("b",t,r)$m(t) = sum(s, l_vxwd("b",t,r,s)) + l_vst("b",t,r);
l_vxw("b",t,r)$nm(t) = sum(s, l_vxwd("b",t,r,s));
l_vxwregion("b",r) = sum(t, l_vxw("b",t,r));
l_viws("b",t,s,r) = pcif0(t,s,r)*pcif.l(t,s,r)*qxs0(t,s,r)*qxs.l(t,s,r);
l_viw("b",t,s) = sum(r, l_viws("b",t,r,s));
l_viwregion("b",r) = sum(t, l_viw("b",t,r));

l_vga("b",t,r) = pg0(t,r)*pg.l(t,r)*qg0(t,r)*qg.l(t,r);
l_vpa("b",t,r) = pp0(t,r)*pp.l(t,r)*qp0(t,r)*qp.l(t,r);
l_reginv("b",r) = pcgds0(r)*pcgds.l(r)*qcgds0(r)*qcgds.l(r);

l_gdp("b",r)
    = sum(t$VGA(t,r), pg0(t,r)*pg.l(t,r)*qg0(t,r)*qg.l(t,r))
    + sum(t$VPA(t,r), pp0(t,r)*pp.l(t,r)*qp0(t,r)*qp.l(t,r))
    + pcgds0(r)*pcgds.l(r)*qcgds0(r)*qcgds.l(r)
    + sum((t,s)$VXWD(t,r,s),
    pfob0(t,r,s)*pfob.l(t,r,s)*qxs0(t,r,s)*qxs.l(t,r,s))
    + sum(m$VST(m,r), pm0(m,r)*pm.l(m,r)*qst0(m,r)*qst.l(m,r))
    - sum((t,s)$VIWS(t,s,r),
    pcif0(t,s,r)*pcif.l(t,s,r)*qxs0(t,s,r)*qxs.l(t,s,r));

* display l_vxwd, l_vst, l_vxw, l_vxw, l_vxwregion, l_viws, l_viw, l_viwregion,
* 	l_vga, l_vpa, l_reginv, l_gdp;

*	Share parameters:
sh_cons("b",t,r) = vconshr0(t,r) * vconshr.l(t,r);
sh_vxwd_vxwregion("b",t,r,s) = l_vxwd("b",t,r,s)/l_vxwregion("b",r);
sh_vst_vxwregion("b",m,r) = l_vst("b",m,r)/l_vxwregion("b",r);
sh_viws_viwregion("b",t,s,r) = l_viws("b",t,s,r)/l_viwregion("b",r);

sh_vga_gdp("b",t,r) = l_vga("b",t,r)/l_gdp("b",r);
sh_vpa_gdp("b",t,r) = l_vpa("b",t,r)/l_gdp("b",r);
sh_reginv_gdp("b",r) = l_reginv("b",r)/l_gdp("b",r);
sh_vxwd_gdp("b",t,r,s) = l_vxwd("b",t,r,s)/l_gdp("b",r);
sh_vst_gdp("b",m,r) = l_vst("b",m,r)/l_gdp("b",r);
sh_viws_gdp("b",t,s,r) = l_viws("b",t,s,r)/l_gdp("b",r);

* display sh_cons, sh_vxwd_vxwregion, sh_vst_vxwregion, sh_viws_viwregion;
* display sh_vga_gdp, sh_vpa_gdp, sh_reginv_gdp, sh_vxwd_gdp, sh_vxwd_gdp,
* 	sh_viws_gdp; ;

* --------------------
* Local Variables:
* mode: gams
* fill-column: 80
* End:
