$title Model definition file:
display "com: Model definition file:";
$ontext
Time-stamp:     <2012-12-06 19:50:45 >
Author:         Shiro Takeda
First-written:  <2006/06/22>

GTAP main model definition.

Contents:

Import data:
	Set declaration:
	Load and declare sets:
	Declaration of imported parameters:
	Import value data:
	Convert scale
	Import elasticity data:
	Parameter declaration:

Main model definition:
	Variable declaration:
	Equation declaration:
	Original parameters, variables, and equations:
	Parameters for the benchmark values:
	Equation definitions:
	Model declaration:

Model for parameter calibaration:
	Model for calibration of distribution parameters in CDE private utility function:

Substitution parameter in CDE minimum expenditure function
	Model for calibration of distribution parameters:

Calibration:
	Calibration of distribution parameters in CDE private utility function:
	Calibration of distribution parameters in regional utility:
Initial values and lower bounds of endogenous variables:
	Initial values of endogenous variables:
	Lower bound of endogenous variables
Declaration of parameters for displaying results:


Commentary:

+ While most variables in gtap.tab represent the percentage change, all
  variables in this gams code represent the level. For example, qo(i,r) in
  gtap.tab represents the percentage change in industry output of commodity
  i in region r, while qo(i,r) in this code represents the level of industry
  output.

+ Except for several variables, the benchmark values of all variables are
  normalized to unity.  For example, let Q denote the level of output and q0
  denote the benchmark level of output.  Then we introduce a variable q
  which has the following relation

  Q = q0 * q

  and is equal to unity at the benchmark equilibrium.  Like this, endogenous
  variables are basically represented by the combination of the benchmark
  value (q0) and the normalized variable (q).

+ Variables for (power of) tax rates and tax revenues are not normalized to
  unity because some of them are zero at the benchmark equilibrium.

+ The functions are basically represented in the calibrated share form.

+ The definition of variables and equations is almost the same as in
  gtap.tab (except that they are represented in the level form).  However,
  some variables and equations that appear in gtap.tab are not included in
  this code and at the same time some original variables and equations that
  do not appear in gtap.tab are introduced in this code.  This modification
  is done (1) because some variables and equations in gtap.tab cannot be
  represented in the level form and (2) because it is necessary to redeifine
  equations so as to creat one-to-one relation between variables and
  equations which is required for the programming in GAMS MCP format.

+ In the original gtap.tab, Divisia type indices are used in the following
   equations

   GLOBALINV
   PRICGDS
   PRIMFACTPR
   PRIMFACTPRWLD
   PGDP_r

  In our program that uses the level form representation, we cannot treat
  the Divisia index.  So, we use the Tornqvist index that is a discrete
  approximation to a continuous Divisia index.

+ Explanatory texts for variables, parameters, and equations are taken from
  gtap.tab.

+ This code is written so that it duplicates the original gtap.tab as
  precisely as possible.  Thus, the number of variables and equations is
  quite large.  When you use this code, you had better modify it to reduce
  variables and equations.

$offtext

*	----------------------------------------------------------------------
*	Import data:
display "com: Import data:";

*	----------------------------------------------------------------------
*	Convert original GTAP data files to GDX files:
$call 'har2gdx .\%basedata_file% .\%basedata_file%.gdx'
$call 'har2gdx .\%par_file% .\%par_file%.gdx'
$call 'har2gdx .\%set_file% .\%set_file%.gdx'

*	----------------------------------------------------------------------
*	Set declaration:
display "com: -- Set declaration:";
set
    g		Global set
    r(g)	Regions in the model (REG)
    i(g)	Produced commodities (PROD_COMM)
    e(g)	Endowment commodities (ENDW_COMM)
    t(g)	Traded commodities (TRAD_COMM)
    m(g)	Marginal commodities (MARG_COMM)
    d(g)	Demanded commodities (DEM_COMM)
    ns(g)	Non-saving commodities (NSAVE_COMM)
    nm(g)	Non-marginal commodities (NMARG_COMM)
    c(g)	Capital goods commodities (CGDS_COMM)
    es(g)	Sluggish endowment commodities (ENDWS_COMM)
    em(g)	Mobile endowment commodities (ENDWM_COMM)
    ec(g)	Capital endowment commodities (ENDWC_COMM)
;
*	----------------------------------------------------------------------
*	Load and declare sets:
display "com: -- Load and declare sets:";

$gdxin '.\%set_file%.gdx'
$load g=globalset c=cgds_comm r=reg e=endw_comm m=marg_comm t=trad_comm
$gdxin

$gdxin '.\%basedata_file%.gdx'
$load i=prod_comm
$gdxin

*	Sluggish endowment commodities (this needs to be set manually):
$include .\%sf_file%

*	Non-saving commodities:
ns(g) = e(g) + i(g);

*	Non-marginal commodities:
nm(g) = t(g) - m(g);

*	Demanded commodities:
d(g) = e(g) + t(g);

*	Mobile endowment commodities:
em(e)$(not es(e)) = yes;

*	Capital endowment:
ec("Capital") = yes;

alias (g,gg), (r,rr), (r,s), (t,tt), (e,ee), (i,ii), (i,j), (i,k), (d,dd),
      (ec,ecc), (m,mm);
display g, r, e, i, t, m, ns, nm, d, c, es, em, ec;

set
    i_j(i,j)
    i_i(i,j);

i_j(i,j) = yes;
i_j(i,i) = no;
i_i(i,j) = no;
i_i(i,i) = yes;
display i_j, i_i;

*	----------------------------------------------------------------------
*	Declaration of imported parameters:
display "com: -- Declaration of imported parameters:";
parameters
    VERNUM 		Version of GTAP data
    SAVE(r)		Expenditure on NET savings in region r valued at agent's prices
    VDGA(*,r)		Government consumption expenditure on domestic i in r
    VDGM(*,r)		Government consumption expenditure on domestic i in r
    VIGA(*,r)		Government consumption expenditure on imported i
    VIGM(*,r)		Gov't consumption expenditure on i in r
    VDPA(*,r)		Private consumption expenditure on domestic i in r
    VDPM(*,r)		Private consumption expenditure on domestic i in r
    VIPA(*,r)		Private consumption expenditure on imported i in r
    VIPM(*,r)		Private consumption expenditure on i in r
    EVOA(*,r)		Value of commodity i output in region r
    EVFA(*,*,r)		Producer expenditure on i by j in r at agent's prices
    VDFA(*,*,r)		Purchases of domestic i for use by j in region r
    VIFA(*,*,r)		Purchases of imported i for use by j in region r
    VFM(*,*,r)		Producer expenditure on i by j in r valued at mkt prices
    VIFM(*,*,r)		Purchases of imports i for use by j in region r
    VDFM(*,*,r)		Purchases of domestic i for use by j in region r
    VDEP(r)		Value of capital depeciation in r (exogenous)
    VIMS(*,r,s)		Imports of i from r to s valued at domestic mkt prices
    VIWS(*,r,s)		Imports of i from r to s valued CIF (tradeables only)
    VXWD(*,r,s)		Exports of i from r to s valued FOB (tradeables only)
    VXMD(*,r,s)		Exports of i from r to s valued at mkt prices (tradeables only)
    VST(*,r)		Exprts of m from r for int'l trnsport valued at mkt p (tradeables only)
    VKB(r)		Value of beginning-of-period capital stock in region r
    VTMFSD(*,*,r,s)	"Int'l margin usage, by margin, freight, source, and destination"
    DPARSUM(r)		Sum of distribution parameters
    POPD(r)		Population data
;
parameters
    ESUBD(*)		"Region-generic el. of sub. domestic/imported for all agents"
    INCPAR(*,r)		Expansion parameter in the CDE minimum expenditure function
    SUBPAR(*,r)		Substitution parameter in CDE minimum expenditure function
    ESUBT(*)		"Elst. of sub. among composite intermediate inputs in production"
    ESUBVA(*,r)		"Elst. of sub. capital/labor/land, in production of value added in j"
    ESUBVA_
    RORFLEX(r)		Flexibility of expected net ROR on capital stock in r wrt investment
    ESUBM(*)		"Region-generic el. of sub. among imports of i in Armington structure"
    ETRAE(*)		"Elst. of transformation for sluggish primary factor endowments"
;

$if %gtap_data_ver% == "5" POPD(r) = 0;
*	----------------------------------------------------------------------
*	Import value data:
display "com: -- Import value data:";
$gdxin '.\%basedata_file%.gdx'
$load VERNUM SAVE VDGA VDGM VIGA VIGM VDPA VDPM VIPA VIPM EVOA EVFA VDFA VIFA VFM VIFM
$load VDFM VDEP VIMS VIWS VXWD VXMD VKB VTMFSD=VTWR
$if %gtap_data_ver% == "5" $load VST=VST5 DPARSUM
$if %gtap_data_ver% == "6" $load VST DPARSUM=DPSM POPD=POP
$gdxin

*	----------------------------------------------------------------------
*	convert scale:
display "com: -- Convert scale";
parameter
    scale_factor Scale factor for converting data / %scale_factor% /;
display scale_factor;
SAVE(r) = scale_factor * SAVE(r);
VDGA(t,r) = scale_factor * VDGA(t,r);
VDGM(t,r) = scale_factor * VDGM(t,r);
VIGA(t,r) = scale_factor * VIGA(t,r);
VIGM(t,r) = scale_factor * VIGM(t,r);
VDPA(t,r) = scale_factor * VDPA(t,r);
VDPM(t,r) = scale_factor * VDPM(t,r);
VIPA(t,r) = scale_factor * VIPA(t,r);
VIPM(t,r) = scale_factor * VIPM(t,r);
EVOA(e,r) = scale_factor * EVOA(e,r);
EVFA(e,j,r) = scale_factor * EVFA(e,j,r);
VDFA(t,j,r) = scale_factor * VDFA(t,j,r);
VIFA(t,j,r) = scale_factor * VIFA(t,j,r);
VFM(e,j,r) = scale_factor * VFM(e,j,r);
VIFM(t,j,r) = scale_factor * VIFM(t,j,r);
VDFM(t,j,r) = scale_factor * VDFM(t,j,r);
VDEP(r) = scale_factor * VDEP(r);
VIMS(t,r,s) = scale_factor * VIMS(t,r,s);
VIWS(t,r,s) = scale_factor * VIWS(t,r,s);
VXWD(t,r,s) = scale_factor * VXWD(t,r,s);
VXMD(t,r,s) = scale_factor * VXMD(t,r,s);
VST(m,r) = scale_factor * VST(m,r);
VKB(r) = scale_factor * VKB(r);
VTMFSD(m,i,r,s) = scale_factor * VTMFSD(m,i,r,s);

* DPARSUM(r) = scale_factor * DPARSUM(r);

display VERNUM, SAVE, VDGA, VDGM, VIGA, VIGM, VDPA, VDPM, VIPA, VIPM, EVOA, EVFA,
	VDFA, VIFA, VFM, VIFM, VDFM, VDEP, VIMS, VIWS, VXWD, VXMD, VST, VKB,
	VTMFSD, DPARSUM;

*	----------------------------------------------------------------------
*	Import elasticity data:
display "com: -- Import elasticity data:";
$gdxin '.\%par_file%.gdx'
$load ESUBD INCPAR SUBPAR ESUBT ESUBVA_=ESUBVA RORFLEX ESUBM ETRAE
$gdxin

ESUBVA(j,r) = ESUBVA_(j);

$ontext
Note: Basically, values of all parameters are automatically imported from har
file (default.prm by default).	However, you need to set the value of RORDELTA
by yourself because har2gdx cannot export integer value to gdx format.
$offtext
parameter
    RORDELTA	Binary coefficient to switch mechanism of allocating investment funds (note: the value of this variable is not imported)
    / %rordelta% /
;
display RORDELTA;

*	----------------------------------------------------------------------
*	Parameter declaration:
display "com: -- Parameter declaration:";

*	Common coefficients:
parameter
    VFA(*,*,r)		Producer expenditure on i by j in r valued at agent's prices
    VOA(*,r)		Value of commodity i output in region r at agent's prices
    VDM(*,r)		Domestic sales of i in r at mkt prices (tradeables only)
    VOM(*,r)		Value of commodity i output in region r at market prices
;
*	Producer expenditure on i by j in r valued at agent's prices
VFA(e,j,r) = EVFA(e,j,r);
VFA(t,j,s) = VDFA(t,j,s) + VIFA(t,j,s);

*	Value of commodity i output in region r at agent's prices
VOA(e,r) = EVOA(e,r);
VOA(j,r) = sum(d, VFA(d,j,r));

*	Domestic sales of i in r at mkt prices (tradeables only)
VDM(t,r) = VDPM(t,r) + VDGM(t,r) + sum(j, VDFM(t,j,r));

*	Value of commodity i output in region r at market prices
VOM(e,r) = sum(j, VFM(e,j,r));
VOM(m,r) = VDM(m,r) + sum(s, VXMD(m,r,s)) + VST(m,r);
VOM(i,r)$nm(i) = VDM(i,r) + sum(s, VXMD(i,r,s));
VOM(i,r)$c(i) = VOA(i,r);

*	Regional expenditure and income:
parameter
    VGA(*,r)		Government consn expenditure on i in r at agent's prices
    GOVEXP(r)		Government expenditure in region r
    VPA(*,r)		Private hhld expenditure on i in r valued at agent's prices
    PRIVEXP(r)		Private consumption expenditure in region r
    INCOME(r)		"Level of expenditure, which equals NET income in region r"
    DGTAX(*,r)		Tax on government consumption of domestic good i in region r
    IGTAX(*,r)		Tax on government consumption of imported good i in region r
    TGC(r)		Government consumption tax payments in r
    DPTAX(*,r)		Tax on private consumption of domestic good i in region r
    IPTAX(*,r)		Tax on private consumption of imported good i in region r
    TPC(r)		Private consumption tax payments in r
    DFTAX(*,*,r)	Tax on use of domestic intermediate good i by j in r
    IFTAX(*,*,r)	Tax on use of imported intermediate good i by j in r
    TIU(r)		Firms' tax payments on intermediate goods usage in r
    ETAX(*,*,r)		Tax on use of endowment good i by industry j in region r
    TFU(r)		Firms' tax payments on primary factor usage in r
    PTAX(*,r)		Output tax on good i in region r
    TOUT(r)		Production tax payments in r
    XTAXD(*,r,s)	Tax on exports of good i from source r to destination s
    TEX(r)		Export tax payments in r
    MTAX(*,r,s)		Tax on imports of good i from source r in destination s
    TIM(r)		Import tax payments in r
;
*	Government consn expenditure on i in r at agent's prices
VGA(t,s) = VDGA(t,s) + VIGA(t,s);

*	Government expenditure in region r
GOVEXP(r) = sum(t, VGA(t,r));

*	Private hhld expenditure on i in r valued at agent's prices
VPA(t,s) = VDPA(t,s) + VIPA(t,s);

*	Private consumption expenditure in region r
PRIVEXP(r) = sum(t, VPA(t,r));

*	Level of expenditure, which equals NET income in region r
INCOME(r) = PRIVEXP(r) + GOVEXP(r) + SAVE(r);

*	Tax on government consumption of domestic good i in region r
DGTAX(t,r) = VDGA(t,r) - VDGM(t,r);

*	Tax on government consumption of imported good i in region r
IGTAX(t,r) = VIGA(t,r) - VIGM(t,r);

*	Government consumption tax payments in r
TGC(r) = sum(t, DGTAX(t,r) + IGTAX(t,r));

*	Tax on private consumption of domestic good i in region r
DPTAX(t,r) = VDPA(t,r) - VDPM(t,r);

*	Tax on private consumption of imported good i in region r
IPTAX(t,r) = VIPA(t,r) - VIPM(t,r);

*	Private consumption tax payments in r
TPC(r) = sum(t, DPTAX(t,r) + IPTAX(t,r));

*	Tax on use of domestic intermediate good i by j in r
DFTAX(t,j,r) = VDFA(t,j,r) - VDFM(t,j,r);

*	Tax on use of imported intermediate good i by j in r
IFTAX(t,j,r) = VIFA(t,j,r) - VIFM(t,j,r);

*	Firms' tax payments on intermediate goods usage in r
TIU(r) = sum(t, sum(j, DFTAX(t,j,r) + IFTAX(t,j,r)));

*	Tax on use of endowment good i by industry j in region r
ETAX(e,j,r) = VFA(e,j,r) - VFM(e,j,r);

*	Firms' tax payments on primary factor usage in r
TFU(r) = sum(e, sum(j, ETAX(e,j,r)));

*	Output tax on good i in region r
PTAX(ns,r) = VOM(ns,r) - VOA(ns,r);

*	Production tax payments in r
TOUT(r) = sum(i, PTAX(i,r));

*	Tax on exports of good i from source r to destination s
XTAXD(t,r,s) = VXWD(t,r,s) - VXMD(t,r,s);

*	Export tax payments in r
TEX(r) = sum(t, sum(s, XTAXD(t,r,s)));

*	Tax on imports of good i from source r in destination s
MTAX(t,r,s) = VIMS(t,r,s) - VIWS(t,r,s);

*	Import tax payments in r
TIM(r) = sum(t, sum(s, MTAX(t,s,r)));

display VFA, VOA, VDM, VOM, VGA, GOVEXP, VPA, PRIVEXP, INCOME;
display DGTAX, IGTAX, TGC, DPTAX, IPTAX, TPC, DFTAX, IFTAX, TIU, ETAX, TFU;
display PTAX, TOUT, XTAXD, TEX, MTAX, TIM;

*	Miscellaneous coefficients:
parameter
    REGINV(r)		Regional GROSS investment in r (value of cgds output)
    NETINV(r)		Regional NET investment in region r
    GLOBINV		Global expenditures on net investment
    CONSHR(*,r)		Share of private hhld consumption devoted to good i in r
    UELASPRIV(r)	Elasticity of cost wrt utility from private consumption
;
*	Regional GROSS investment in r (value of cgds output)
REGINV(r) = sum(c, VOA(c,r));

*	Regional NET investment in region r
NETINV(r) = sum(c, VOA(c,r)) - VDEP(r);

*	Global expenditures on net investment
GLOBINV = sum(r, NETINV(r));

*	Share of private hhld consumption devoted to good i in r
CONSHR(t,r)$PRIVEXP(r) = VPA(t,r) / PRIVEXP(r);

*	Elasticity of cost wrt utility from private consumption
UELASPRIV(r) = sum(t, CONSHR(t,r) * INCPAR(t,r));

display REGINV, NETINV, GLOBINV, CONSHR, UELASPRIV;

*	Government consumption:
parameter
    GMSHR(*,s)		Share of imports for gov't hhld at agent's prices
;
*	Share of imports for gov't hhld at agent's prices
GMSHR(t,s)$VGA(t,s) = VIGA(t,s) / VGA(t,s);

*	Private consumption modules:
parameter
    XWCONSHR(*,r)	Expansion-parameter-weighted consumption share
    ALPHA(*,r)		1 - sub. parameter in the CDE minimum expenditure function
    APE(*,*,r)		Allen partial elst. of sub. between composite i and k in r
    EY(*,r)		Income elast. of private hhld demand for i in r (HT F4)
    EP(*,*,r)		Uncomp. elast. of private hhld demand for i wrt price of k in r (HT F5)
    PMSHR(*,s)		Share of imports for priv hhld at agent's prices
;
*	Expansion-parameter-weighted consumption share
XWCONSHR(t,r)$UELASPRIV(r) = CONSHR(t,r) * INCPAR(t,r) / UELASPRIV(r);

*	1 - sub. parameter in the CDE minimum expenditure function
ALPHA(t,r) = 1 - SUBPAR(t,r);

*	Allen partial elst. of sub. between composite i and k in r
APE(t,tt,r) = ALPHA(t,r) + ALPHA(tt,r) - sum(ii$t(ii), CONSHR(ii,r) * ALPHA(ii,r));
APE(t,t,r)
    = 2.0 * ALPHA(t,r)
    - sum(j$t(j), CONSHR(j,r) * ALPHA(j,r))
    - (ALPHA(t,r) / CONSHR(t,r))$CONSHR(t,r);

*	Income elast. of private hhld demand for i in r (HT F4)
EY(t,r)
    =	(1.0 / sum(j$t(j), CONSHR(j,r) * INCPAR(j,r)))
    * (INCPAR(t,r) * [1.0 - ALPHA(t,r)]
    + sum(j$t(j), CONSHR(j,r) * INCPAR(j,r) * ALPHA(j,r)))
    + (ALPHA(t,r) - sum(j$t(j), CONSHR(j,r) * ALPHA(j,r)));

*	Uncomp. elast. of private hhld demand for i wrt price of k in r (HT F5)
EP(i,k,r)$(t(i) and t(k)) = (APE(i,k,r) - EY(i,r)) * CONSHR(k,r);

*	Share of imports for priv hhld at agent's prices
PMSHR(t,s)$VPA(t,s) = VIPA(t,s) / VPA(t,s);

*	Firms:
parameter
    FMSHR(*,*,s)	"Share of firms' imports in dom. composite, agent's prices"
    VVA(*,r)		Value added in activity j in region r
    SVADEFAULT(*)	Zerodivide default for SVA
    SVA(*,*,r)		Share of i in total value added in j in r
    STC(*,*,r)		Share of i in total costs of j in r
;
*	"Share of firms' imports in dom. composite, agent's prices"
FMSHR(t,j,s)$VFA(t,j,s) = VIFA(t,j,s) / VFA(t,j,s);

*	Value added in activity j in region r
VVA(j,r) = sum(e, VFA(e,j,r));

*	Zerodivide default for SVA
SVADEFAULT(e) = sum(j, sum(r, VFA(e,j,r)))/ sum(j, sum(r, VVA(j,r)));

*	Share of i in total value added in j in r
SVA(e,j,r)$VVA(j,r) = VFA(e,j,r) / VVA(j,r);

*	Share of i in total costs of j in r
STC(d,j,r) = VFA(d,j,r) / sum(dd, VFA(dd,j,r));

display GMSHR, XWCONSHR, ALPHA, APE, EY, EP, PMSHR, FMSHR, VVA, SVADEFAULT,
	SVA, STC;

*	Investment, Global Bank, Savings:
parameter
    INVKERATIO(r)	Ratio of gross investment to end-of-period capital stock in r
    GRNETRATIO(r)	"Ratio of GROSS/NET rates of return on capital in r"
;
*	Ratio of gross investment to end-of-period capital stock in r
INVKERATIO(r) = REGINV(r) / (VKB(r) + NETINV(r));

*	"Ratio of GROSS/NET rates of return on capital in r"
GRNETRATIO(r) = sum(ec, VOA(ec,r)) / (sum(ecc, VOA(ecc,r)) - VDEP(r));

*	International trade:
parameter
    MSHRS(*,r,s)	Share of imports from r in import bill of s at mkt prices
;
*	Share of imports from r in import bill of s at mkt prices
MSHRS(t,r,s) = VIMS(t,r,s) / sum(rr, VIMS(t,rr,s));

*	International transport services:
parameter
    VTFSD(*,r,s)	Aggregate value of svces in the shipment of i from r to s
    VTMUSE(*)		"International margin services usage, by type"
    VTMPROV(*)		International margin services provision
    VTRPROV(r)		"International margin supply, by region VT international margin supply"
    VT			International margin supply
    VTMUSESHR(*,*,r,s)	"Share of i,r,s usage in global demand for m"
    VTSUPPSHR(*,r)	Share of region r in global supply of margin m
    VTUSE		International margin services usage
    VTFSD_MSH(*,*,r,s)	Share of margin m in cost of getting i from r to s
    VIWSCOST(*,r,s)	Value of imports calculated as total cost of imports
    FOBSHR(*,r,s)	Fob share in VIW
    TRNSHR(*,r,s)	Ransport share in VIW
;
*	Aggregate value of svces in the shipment of i from r to s
VTFSD(t,r,s) = sum(m, VTMFSD(m,t,r,s));

*	"International margin services usage, by type"
VTMUSE(m) = sum(t, sum(r, sum(s, VTMFSD(m,t,r,s))));

*	International margin services provision
VTMPROV(m) = sum(r, VST(m,r));

*	"International margin supply, by region VT international margin supply"
VTRPROV(r) = sum(m, VST(m,r));

*	International margin supply
VT = sum(m, sum(r, VST(m,r)));

*	"Share of i,r,s usage in global demand for m"
VTMUSESHR(m,t,r,s) = VTFSD(t,r,s) / VT;
VTMUSESHR(m,t,r,s)$VTMUSE(m) = VTMFSD(m,t,r,s) / VTMUSE(m);

*	Share of region r in global supply of margin m
VTSUPPSHR(m,r) = VTRPROV(r) / VT;
VTSUPPSHR(m,r)$VTMPROV(m) = VST(m,r) / VTMPROV(m);

*	International margin services usage
VTUSE = sum(m, sum(t, sum((r,s), VTMFSD(m,t,r,s))));

*	Share of margin m in cost of getting i from r to s
VTFSD_MSH(m,t,r,s)$VTFSD(t,r,s) = VTMFSD(m,t,r,s) / VTFSD(t,r,s);
VTFSD_MSH(m,t,r,s)$(VTFSD(t,r,s) = 0) = VTMUSE(m) / VTUSE;

*	Value of imports calculated as total cost of imports
VIWSCOST(t,r,s) = VXWD(t,r,s) + VTFSD(t,r,s);

*	Fob share in VIW
FOBSHR(t,r,s)$VIWSCOST(t,r,s) = VXWD(t,r,s) / VIWSCOST(t,r,s);

*	Ransport share in VIW
TRNSHR(t,r,s)$VIWSCOST(t,r,s) = VTFSD(t,r,s) / VIWSCOST(t,r,s);

*	Regional household:
parameter
    XSHRPRIV(r)		Private expenditure share in regional income
    XSHRGOV(r)		Government expenditure share in regional income
    XSHRSAVE(r)		Saving share in regional income
    TINC(r)		Income tax payments in r
    REVSHR(*,*,r)
    FY(r)		Primary factor income in r net of depreciation
    INDTAX(r)		Indirect tax receipts in r
    UTILELAS(r)		Elasticity of cost of utility wrt utility
    DPARPRIV(r)		Private consumption distribution parameter
    DPARGOV(r)		Government consumption distribution parameter
    DPARSAVE(r)		Saving distribution parameter
    UTILPRIV(r)		Utility from private consumption
    UTILGOV(r)		Utility from government consumption
    UTILSAVE(r)		Utility from saving
;
*	Private expenditure share in regional income
XSHRPRIV(r) = PRIVEXP(r) / INCOME(r);

*	Government expenditure share in regional income
XSHRGOV(r) = GOVEXP(r) / INCOME(r);

*	Saving share in regional income
XSHRSAVE(r) = SAVE(r) / INCOME(r);

*	Income tax payments in r
TINC(r) = sum(e, PTAX(e,r));

REVSHR(e,j,r) = VFM(e,j,r) / sum(i, VFM(e,i,r));

*	Primary factor income in r net of depreciation
FY(r) = sum(e, VOM(e,r)) - VDEP(r);

*	Indirect tax receipts in r
INDTAX(r) = TPC(r) + TGC(r) + TIU(r) + TFU(r) + TOUT(r) + TEX(r) + TIM(r);

*	Elasticity of cost of utility wrt utility
UTILELAS(r)
    = (UELASPRIV(r) * XSHRPRIV(r) + XSHRGOV(r) + XSHRSAVE(r)) / DPARSUM(r);

*	Private consumption distribution parameter
DPARPRIV(r) = UELASPRIV(r) * XSHRPRIV(r) / UTILELAS(r);

*	Government consumption distribution parameter
DPARGOV(r) = XSHRGOV(r) / UTILELAS(r);

*	Saving distribution parameter
DPARSAVE(r) = XSHRSAVE(r) / UTILELAS(r);

*	Utility from private consumption
UTILPRIV(r) = 1.0;

*	Utility from government consumption
UTILGOV(r) = 1.0;

*	Utility from saving
UTILSAVE(r) = 1.0;

display INVKERATIO, GRNETRATIO, MSHRS, VTFSD, VTMUSE, VTMPROV, VTRPROV,
	VTMUSESHR, VTSUPPSHR, VTUSE, VTFSD_MSH, VIWSCOST, FOBSHR, TRNSHR,
	XSHRPRIV, XSHRGOV, XSHRSAVE, TINC, REVSHR, FY, INDTAX, UTILELAS,
	DPARPRIV, DPARGOV, DPARSAVE, UTILPRIV, UTILGOV, UTILSAVE;

*	Market clearing conditions:
parameter
    SHRDFM(*,*,r)	Share of dom. prod. i used by sector j in r at mkt prices
    SHRDPM(*,r)		Share of domestic prod. of i used by private hhlds in r
    SHRDGM(*,r)		Share of imports of i used by gov't hhlds in r
    SHRDM(*,r)		Share of domestic sales of i in r
    SHRST(*,r)		Share of sales of m to global transport services in r
    SHRXMD(*,r,s)	Share of export sales of i to s in r
    VIM(*,r)		Value of imports of commodity i in r at domestic market prices
    SHRIFM(*,*,r)	Share of import i used by sector j in r
    SHRIPM(*,r)		Share of import i used by private hhlds in r
    SHRIGM(*,r)		He share of import i used by gov't hhlds in r
    SHREM(*,*,r)	Share of mobile endowment i used by sector j at mkt prices
;
*	Share of dom. prod. i used by sector j in r at mkt prices
SHRDFM(t,j,r)$VDM(t,r) = VDFM(t,j,r) / VDM(t,r);

*	Share of domestic prod. of i used by private hhlds in r
SHRDPM(t,r)$VDM(t,r) = VDPM(t,r) / VDM(t,r);

*	Share of imports of i used by gov't hhlds in r
SHRDGM(t,r)$VDM(t,r) = VDGM(t,r) / VDM(t,r);

*	Share of domestic sales of i in r
SHRDM(t,r)$VOM(t,r) = VDM(t,r) / VOM(t,r);

*	Share of sales of m to global transport services in r
SHRST(m,r)$VOM(m,r) = VST(m,r) / VOM(m,r);

*	Share of export sales of i to s in r
SHRXMD(t,r,s)$VOM(t,r) = VXMD(t,r,s) / VOM(t,r);

*	Value of imports of commodity i in r at domestic market prices
VIM(t,r) = sum(j, VIFM(t,j,r)) + VIPM(t,r) + VIGM(t,r);

*	Share of import i used by sector j in r
SHRIFM(t,j,r)$VIM(t,r) = VIFM(t,j,r) / VIM(t,r);

*	Share of import i used by private hhlds in r
SHRIPM(t,r)$VIM(t,r) = VIPM(t,r) / VIM(t,r);

*	He share of import i used by gov't hhlds in r
SHRIGM(t,r)$VIM(t,r) = VIGM(t,r) / VIM(t,r);

*	Share of mobile endowment i used by sector j at mkt prices
SHREM(em,j,r)$VOM(em,r) = VFM(em,j,r) / VOM(em,r);

display SHRDFM, SHRDPM, SHRDGM, SHRDM, SHRST, SHRXMD, VIM, SHRIFM, SHRIPM,
	SHRIGM, SHREM;

*	Parameters for setting numeraire goods.
parameter
    VENDWREG(r)		"Value of primary factors, at mkt prices, by region"
    VENDWWLD		"Value of primary factors, at mkt prices, worldwide"
;
*	"Value of primary factors, at mkt prices, by region"
VENDWREG(r) = sum(e, VOM(e,r));

*	"Value of primary factors, at mkt prices, worldwide"
VENDWWLD = sum(r, VENDWREG(r));

display VENDWREG, VENDWWLD;

*	File name for displaying title in DOS window.
file titlemaker /'.\%exp_name%_titlemaker.cmd'/;

*	----------------------------------------------------------------------
*	Parameters for Appendices:
display "com: Parameters for Appendices:";

parameter
    VXW(*,r)		"Value of exports by comm. i and region r at FOB prices"
    VXWREGION(r)	"Value of exports by region r at FOB prices"
    VIW(*,s)		"Value of commodity imports i into s at CIF prices"
    VIWREGION(r)	"Value of commodity imports by region r at CIF prices"

    VENDWREG(r)		"Value of primary factors, at mkt prices, by region"
    VENDWWLD		"Value of primary factors, at mkt prices, worldwide \\"

    GDP(r)		"Gross Domestic Product in region r"
*     VXWCOMMOD(*)	"Value of world exports by commodity i at FOB prices"
*     VXWLD		"Value of commodity exports, FOB, globally"
*     VIWCOMMOD(*)	"Global value of commodity imports, CIF, by commodity"
*     PW_PM(*,r)		"Ratio of world to domestic prices"
*     VOW(*,r)		"Value of output in r at FOB including transportation services"
*     VWOW(*)		"Value of world supply at world prices for i"
*     VWOU(*)		"Value of world output of i at user prices"
    TBAL(*)		"Trade balance for region r"
;

VXW(i,r)$nm(i) = sum(s, VXWD(i,r,s));
VXW(m,r) = sum(s, VXWD(m,r,s)) + VST(m,r);

VXWREGION(r) = sum(t, VXW(t,r));

VIW(t,s) = sum(r, VIWS(t,r,s));

VIWREGION(r) = sum(t, VIW(t,r));

VENDWREG(r) = sum(e, VOM(e,r));

VENDWWLD = sum(r, VENDWREG(r));

GDP(s)
    = sum(i$t(i), VPA(i,s))
    + sum(i$t(i), VGA(i,s))
    + sum(c, VOA(c,s) )
    + sum(i$t(i), sum(r, VXWD(i,s,r)))
    + sum(m, VST(m,s))
    - sum(i$t(i), sum(r, VIWS(i,r,s)));

TBAL(r) = VXWREGION(r)- VIWREGION(r);
TBAL("sum") = sum(r, TBAL(r));

display VXW, VXWREGION, VIW, VIWREGION, VENDWREG, VENDWWLD, GDP, TBAL;

*	----------------------------------------------------------------------
*	Main model definition:
display "com: Main model definition:";

*       ----------------------------------------------------------------------
*       Variable declaration:
display "com: -- Variable declaration:";

*       --------------------------------
*       Preliminary:

*       Saving:
variables
    psave(r)    Price of savings in region r
    qsave(r)    Regional demand for NET savings
;
*       Government consumption:
variables
    pgd(*,s)    Price of domestic i in government consumption in s
    qgd(*,s)    Government hhld demand for domestic i in region s
    pm(*,r)     Market price of commodity i in region r
    pgm(*,s)    Price of imports of i in government consumption in s
    qgm(*,s)    Government hhld demand for imports of i in region s
    pim(*,r)    Market price of composite import i in region r
;
*       Private consumption:
variables
    ppd(*,s)    Price of domestic i to private households in s
    qpd(*,s)    Private hhld demand for domestic i in region s
    ppm(*,s)    Price of imports of i by private households in s
    qpm(*,s)    Private hhld demand for imports of i in region s
;
*       Firms:
variables
    ps(*,r)         Supply price of commodity i in region r
    qo(*,r)         Industry output of commodity i in region r
    pfe(*,*,r)      "Firms' price for endowment commodity i in ind. j, region r"
    qfe(*,*,r)      Demand for endowment i for use in ind. j in region r
    pfd(*,*,s)      Price index for domestic purchases of i by j in region s
    qfd(*,*,s)      Domestic good i demanded by industry j in region s
    pfm(*,*,s)      Price index for imports of i by j in region s
    qfm(*,*,s)      Demand for i by industry j in region s
    pmes(*,*,r)     Market price of sluggish endowment i used by j in r
;
*       Global bank:
variables
    kb(r)           Beginning-of-period capital stock in r
    pcgds(r)        "Price of investment goods = ps(cgds,r)"
;
*       International trade and transport:
variables
    pms(*,r,s)      Domestic price for good i supplied from r to region s
    qxs(*,r,s)      Export sales of commodity i from r to region s
    pcif(*,r,s)     Cif world price of commodity i supplied from r to s
    pfob(*,r,s)     Fob world price of commodity i supplied from r to s
    qst(*,r)        Sales of m from r to international transport
;
*       Common variables:
variables
    y(r)            Regional household income in region r
    pop(r)          Regional population
    qoes(*,*,r)     Supply of sluggish endowment i used by j in r
    endwslack(*,r)  Slack variable in endowment market clearing condition
    pgov(r)         Price index for gov't hhld expenditure in region r
    yg(r)           Regional government consumption expenditure in region r
    ug(r)           Per capita utility from gov't expend. in region r
*     ppriv(r)      Price index for private consumption expenditure in r
    uepriv(r)       Elasticity of cost wrt utility from private consumption
    yp(r)           Regional private consumption expenditure in region r
    up(r)           Per capita utility from private expend. in region r
    to(*,r)         Output (or income) tax in region r
    qim(*,s)        "Aggregate imports of i in region s, market price weights"
    globalcgds      global supply of capital goods for NET investment
    pcgdswld        world average price of capital goods (net investment weights)
    del_taxrgc(r)   Government consumption tax
    del_taxrpc(r)   Private consumption tax
    del_taxriu(r)   Tax on intermediate usage
    del_taxrfu(r)   Tax on primary factor usage
    del_taxrout(r)  Output tax
    del_taxrexp(r)  Export tax
    del_taxrimp(r)  Import tax
    del_taxrinc(r)  Income tax
;
*       --------------------------------
*       Modules:

*       Government consumption:
variables
    pg(*,r)         Government consumption price for commodity i in region r
    qg(*,r)         Government hhld demand for commodity i in region r
    tgd(*,r)        Tax on domestic i purchased by government hhld in r
    tgm(*,r)        Tax on imported i purchased by gov't hhld in r
;
*       Private consumption:
variables
    pp(*,r)         Private consumption price for commodity i in region r
    qp(*,r)         Private hhld demand for commodity i in region r
    tp(r)           "Comm.-, source-gen. shift in tax on private cons."
    tpd(*,r)        "Comm.-, source-spec. shift in tax on private cons. of dom."
    atpd(*,r)       Power of tax on domestic i purchased by private hhld in r
    tpm(*,r)        "Comm.-, source-spec. shift in tax on private cons. of imp."
    atpm(*,r)       Power of tax on imported i purchased by private hhld in r
;
*       Firms:
variables
    pva(*,r)        Firms' price of value added in industry j of region r
    qva(*,r)        Value added in industry j of region r
    pf(*,*,r)       Firms' price for commodity i for use by j in r
    qf(*,*,r)       Demand for commodity i for use by j in region r
    ao(*,r)         Output augmenting technical change in sector j of r
    ava(*,r)        Value added augmenting tech change in sector i of r
    af(*,*,r)       Composite intermed. input i augmenting tech change by j of r
    afe(*,*,r)      Primary factor i augmenting tech change by j of r
    ams(*,r,s)      Import i from region r augmenting tech change in region s
    aosec(*)        "Output tech change of sector j, worldwide"
    aoreg(r)        Output tech change in region r
    aoall(*,r)      Output augmenting technical change in sector j of r
    avasec(*)       "Value added tech change of sector j, worldwide"
    avareg(r)       Value added tech change in region r
    avaall(*,r)     Value added augmenting technical change in sector j of r
    afcom(*)        "Intermediate tech change of input i, worldwide"
    afsec(*)        "Intermediate tech change of sector j, worldwide"
    afreg(r)        Intermediate tech change in region r
    afall(*,*,r)    Intermediate input i augmenting tech change by j in r
    tfd(*,*,r)      Tax on domestic i purchased by j in r
    tfm(*,*,r)      Tax on imported i purchased by j in r
    tf(*,*,r)       Tax on primary factor i used by j in region r
    afecom(*)       "Factor input tech change of input i, worldwide"
    afesec(*)       "Factor input tech change of sector j, worldwide"
    afereg(r)       Factor input tech change in region r
    afeall(*,*,r)   Primary factor i augmenting tech change sector j in r
    profitslack(*,r)    Slack variable in the zero profit equation
;
*       Investment, Global Bank, Savings:
variables
    rental(r)       "Rental rate on capital = ps(capital,r)"
    ke(r)           End-of-period capital stock in r
    rore(r)         Expected net rate of return on capital stock in r
    rorc(r)         Current net rate of return on capital stock in r
    qcgds(r)        "Output of capital goods sector = qo(cgds,r)"
    ksvces(r)       "Capital services = qo(capital,r)"
    expand(*,r)     Change in investment levels relative to endowment stock
    rorg            global net rate of return on capital stock
    cgdslack(r)     Slack variable for qcgds(r)
    psaveslack(r)   Slack variable for the savings price equation
;
*       International Trade:
variables
    tx(*,r)         Dest.-gen. change in subsidy on exports of i from r
    txs(*,r,s)      Dest.-spec. change in subsidy on exports of i from r to s
    tm(*,s)         Source-gen. change in tax on imports of i into s
    tms(*,r,s)      Source-spec. change in tax on imports of i from r into s
    pr(*,r)         Ratio of domestic to imported prices in r
;
*       International Transport Services:
variables
    qtmfsd(m,*,r,s) International usage margin m on i from r to s
    atmfsd(m,*,r,s) Tech change in m's shipping of i from region r to s
    atm(m)          "Tech change in mode m, worldwide"
    atf(*)          "Tech change shipping of i, worldwide"
    ats(r)          Tech change shipping from region r
    atd(s)          Tech change shipping to s
    atall(m,*,r,s)  Tech change in m's shipping of i from region r to s
    ptrans(*,r,s)   Cost index for international transport of i from r to s
    qtm(m)          Global margin usage
    pt(m)           "Price of composite margins services, type"
;
*       Regional household:
variables
    uelas(r)        Elasticity of cost of utility wrt utility
    dppriv(r)       Private consumption distribution parameter
    dpgov(r)        Government consumption distribution parameter
    dpsave(r)       Saving distribution parameter
    fincome(r)      Factor income at market prices net of depreciation
    del_indtaxr(r)  Indirect taxes in r
    del_ttaxr(r)    Taxes in r
    incomeslack(r)  Slack variable in the expression for regional income
*     dpav(r)       "Average distribution parameter shift, for EV calc."
*     p(r)          Price index for disposition of income by regional household
    au(r)           Input-neutral shift in utility function
*     dpsum(r)      Sum of the distribution parameters
    u(r)            Per capita utility from aggregate hhld expend. in region r
;
*       Market clearing condition:
variables
    qds(*,r)        Domestic sales of commodity i in r
    tradslack(*,r)  Slack variable in tradeables market clearing condition
    walras_sup      Supply in omitted market--global supply of cgds composite
    walras_dem      Demand in the omitted market--global demand for savings
    walraslack      Slack variable in the omitted market
;

*       ----------------------------------------------------------------------
*       Equation declaration:
display "com: -- Equation declaration:";

*       Government consumption
equations
    GPRICEINDEX(r)      Definition of price index for aggregate gov't purchases (HT 40):
    GOVDMNDS(*,r)       Government consumption demands for composite commodities (HT41):
    GOVU(r)             Utility from government consumption in r:
    GHHDPRICE(*,r)      Eq'n links domestic market and government consumption prices (HT 19):
    GHHIPRICES(*,r)     Eq'n links domestic market and government consumption prices (HT 22):
    GCOMPRICE(*,r)      Government consumption price for composite commodities (HT 42):
    GHHLDAGRIMP(*,r)    Government consumption demand for aggregate imports (HT 43):
    GHHLDDOM(*,r)       Government consumption demand for domestic goods (HT 44):
    TGCRATIO(r)         Government consumption tax payments:
;
*       Private consumption
equations
    PRIVATEU(r)         Computation of utility from private consumption in r (HT 45):
    UTILELASPRIV(r)     Elasticity of expenditure wrt utility from private consumption:
    PRIVDMNDS(*,r)      Private consumption demands for composite commodities (HT 46):
    TPDSHIFT(*,r)       Permits uniform consumption tax change:
    PHHDPRICE(*,r)      Eq'n links domestic market and private consumption prices (HT 18):
    TPMSHIFT(*,r)       Permits uniform consumption tax change:
    PHHIPRICES(*,r)     Eq'n links domestic market and private consumption prices (HT 21):
    TPCRATIO(r)         Private consumption tax payments:
    PCOMPRICE(*,r)      Private consumption price for composite commodities (HT 47):
    PHHLDDOM(*,r)       Private consumption demand for domestic goods (HT 48):
    PHHLDAGRIMP(*,r)    Private consumption demand for aggregate imports (HT 49):
;
*       Firms
equations
    AOWORLD(*,r)        "Sector/region specific average rate of output augmenting tech change:"
    AVAWORLD(*,r)       "Sector/region specific average rate of value added augmenting tech change:"
    VADEMAND(*,r)       Sector demands for primary factor composite:
    AFWORLD(*,*,r)      "Sector/region specific average rate of intermediates augmenting tech change:"
    INTDEMAND(*,*,r)    "Industry demands for intermediate inputs, including cgds:"
    DMNDDPRICE(*,*,r)   Eq'n links domestic market and firm prices (HT 20):
    DMNDIPRICES(*,*,r)  Eq'n links domestic market and firm prices (HT 23):
    TIURATIO(r)         Tax payments on intermediate goods:
    ICOMPRICE(*,*,r)    Industry price for composite commodities (HT 30):
    INDIMP(*,*,r)       Industry j demands for composite import i (HT 31):
    INDDOM(*,*,r)       Industry j demands for domestic good i (HT 32):
    MPFACTPRICE(*,*,r)  Eq'n links domestic and firm demand prices (HT 16):
    SPFACTPRICE(*,*,r)  Eq'n links domestic and firm demand prices (HT 17):
    AFEWORLD(*,*,r)     "Sector/region specific average rate of prim. factor i augmenting tech change:"
    VAPRICE(*,r)        "Effective price of primary factor composite in each sector/region (HT 33):"
    TFURATIO(r)         Tax payments on factor usage:
    ENDWDEMAND(*,*,r)   Demands for endowment commodities (HT 34):
    TOUTRATIO(r)        Output tax payments:
    ZEROPROFITS(*,r)    Industry zero pure profits condition (HT 6):
;
*       Investment, Global Bank, and Savings
equations
    KAPSVCES(r)     Eq'n defines a variable for capital services (HT 52):
    KAPRENTAL(r)    Eq'n defines a variable for capital rental rate (HT 53):
    PRCGOODS(r)     Eq'n defines the price of cgds (HT 55):
    KBEGINNING(r)   "Associates change in cap. services w/ change in cap. stock (HT 56):"
    KEND(r)         Ending capital stock equals beginning stock plus net investment. (HT 10):
    RORCURRENT(r)   Current rate of return on capital in region r (HT 57):
    ROREXPECTED(r)  Expected rate of return depends on the current return and investment (HT 58):
    BALDWIN(*,r)    Change in investment levels relative to endowment stock:
    RORGLOBAL(r)    Either gross investment or expected rate of return in region r (HT 59):
    GLOBALINV       Either expected global rate of return or global net investment (HT 11):
    PRICGDS         Eq'n generates a price index for the aggregate global cgds composite (HT 60):
    SAVEPRICE(r)    Savings price:
;
*       International Trade
equations
    EXPRICES(*,r,s)     Eq'n links agent's and world prices (HT 27):
    TEXPRATIO(r)        Export tax payments:
    MKTPRICES(*,r,s)    Eq'n links domestic and world prices (HT 24):
    DPRICEIMP(*,s)      Price for aggregate imports (HT 28):
    PRICETGT(*,s)       Eq'n defines target price ratio to be attained via the variable levy (HT 25):
    IMPORTDEMAND(*,r,s) Regional demand for disaggregated imported commodities by source (HT 29):
    TIMPRATIO(r)        Import tax payments:
;
*       International Transport Services
equations
    QTRANS_MFSD(m,*,r,s)        Bilateral demand for transport services:
    TRANS_DEMAND(m)             Global demand for margin m:
    PTRANSPORT(m)               Generate price index for composite transportation services:
    TRANSCOSTINDEX(*,r,s)       Generates flow-specific modal average cost of transport index (cf. HT7):
    TRANSTECHANGE(m,*,r,s)      Generates flow-specific average rate of technical change:
    TRANSVCES(m,r)              Generate demand for regional supply of global transportation service (HT 61):
    FOBCIF(*,r,s)               "Eq'n links FOB and CIF prices for good i shipped from region r to s (HT 26'):"
;
*       Regional Household
equations
    TINCRATIO(r)        Income tax payments:
    ENDW_PRICE(*,r)     Eq'n generates the composite price for sluggish endowments (HT 50):
    ENDW_SUPPLY(*,*,r)  Eq'n distributes the sluggish endowments across sectors (HT 51):
    FACTORINCOME(r)     Factor income at market prices net of depreciation:
    DINDTAXRATIO(r)     Indirect taxes:
    DTAXRATIO(r)        All taxes:
    REGIONALINCOME(r)   Regional income = sum of primary factor income and indirect tax receipts:
    UTILITELASTIC(r)    Elasticity of cost of utility wrt utility:
    PRIVCONSEXP(r)      Private consumption expenditure:
    GOVCONSEXP(r)       Government consumption expenditure:
    SAVING(r)           Saving:
    UTILITY(r)          Regional household utility:
;
*       Equilibrium Conditions
equations
    MKTCLDOM(*,r)       Eq'n assures market clearing for domestic sales (HT 3):
    MKTCLTRD_MARG(m,r)  Eq'n assures market clearing for margins commodities (HT 1):
    MKTCLTRD_NMRG(*,r)  Eq'n assures market clearing for the non-margins
    MKTCLIMP(*,r)       Eq'n assures mkt clearing for imported goods entering each region (HT 2):
    MKTCLENDWM(*,r)     Eq'n assures mkt clearing for perfectly mobile endowments in each r (HT 4):
    MKTCLENDWS(*,*,r)   Eq'n assures mkt clearing for imperfectly mobile endowments in each r (HT 5):
    WALRAS_S            Extra eq'n computes change in supply in the omitted market.:
    WALRAS_D            Extra eq'n computes change in demand in the omitted market.:
    WALRAS              Check Walras' Law.  Value of "walraslack" should be zero. (HT 14):
;
$ontext
Note:

The following equations which appear in gtap.tab are not used in this program.

equations
    PHHLDINDEX          Price index for private consumption expenditure:
    OUTPUTPRICES        Eq'n links pre- and post-tax supply prices for all industries  (HT 15):
    CAPGOODS            Eq'n defines a variable for gross investment (HT 54):
    FACTORINCPRICES     eq'n links pre- and post-tax endowment supply prices (HT 15):
    DPARAV              Average distribution parameter shift:
    PRICEINDEXREG       Price index for disposition of income by regional household:
    DISTPARSUM          Sum of the distribution parameters:

$offtext

*       ----------------------------------------------------------------------
*       Original parameters, variables, and equations:
display "com: -- Original parameters, variables, and equations:";
$ontext
Parameters, variables, and equations below do not appear in the original
gtap.tab.

$offtext
parameter
    DEPR(r)             Depreciation rate
;
DEPR(r) = VDEP(r)/VKB(r);
display DEPR;

variables
    vconshr(*,r)        Share of private hhld consumption devoted to good i in r
    psave_adj           Adjustment factor for psave
    dummy_objective     Dummy variable

    sh_netinv_globinv(r)	Share of net investment
    sh_netinv_save_globinv(r)   Share of excess investment
    sh_vom_vendwreg(e,r)        Share of endowment commodities in region r
    sh_vendwreg_vendwwld(r)     Share of endowment commodities in the world
;

equations
    E_VCONSHR(*,r)      Share of private hhld consumption devoted to good i in r
    E_PSAVE_ADJ         Adjustment factor for psave
    E_PM(*,r)           Market clearing condition (pm)
    E_PFE(e,*,r)        Price of endowment commodities (pfe):
    E_PS(*,r)           Supply price

    E_DUMMY_OBJECTIVE   Dummy objective function

    E_SH_NETINV_GLOBINV(r)      Share of net investment
    E_SH_NETINV_SAVE_GLOBINV(r)	Share of excess investment
    E_SH_VOM_VENDWREG(e,r)      Share of endowment commodities in region r
    E_SH_VENDWREG_VENDWWLD(r)   Share of endowment commodities in the world
;
*       ----------------------------------------------------------------------
*       Parameters for the benchmark values:
display "com: -- Parameters for the benchmark values:";

*       Saving:
parameters
    psave0(r)           Price of savings in region r
    qsave0(r)           Regional demand for NET savings
;
*       Government consumption:
parameters
    pgd0(*,s)           Price of domestic i in government consumption in s
    qgd0(*,s)           Government hhld demand for domestic i in region s
    pm0(*,r)            Market price of commodity i in region r
    pgm0(*,s)           Price of imports of i in government consumption in s
    qgm0(*,s)           Government hhld demand for imports of i in region s
    pim0(*,r)           Market price of composite import i in region r
;
*       Private consumption:
parameters
    ppd0(*,s)           Price of domestic i to private households in s
    qpd0(*,s)           Private hhld demand for domestic i in region s
    ppm0(*,s)           Price of imports of i by private households in s
    qpm0(*,s)           Private hhld demand for imports of i in region s
;
*       Firms:
parameters
    ps0(*,r)            Supply price of commodity i in region r
    qo0(*,r)            Industry output of commodity i in region r
    pfe0(*,*,r)         "Firms' price for endowment commodity i in ind. j, region r"
    qfe0(*,*,r)         Demand for endowment i for use in ind. j in region r
    pfd0(*,*,s)         Price index for domestic purchases of i by j in region s
    qfd0(*,*,s)         Domestic good i demanded by industry j in region s
    pfm0(*,*,s)         Price index for imports of i by j in region s
    qfm0(*,*,s)         Demand for i by industry j in region s
    pmes0(*,*,r)        Market price of sluggish endowment i used by j in r
;
*       Global bank:
parameters
    kb0(r)              Beginning-of-period capital stock in r
    pcgds0(r)           "Price of investment goods = ps(cgds,r)"
;
*       International trade and transport:
parameters
    pms0(*,r,s)         Domestic price for good i supplied from r to region s
    qxs0(*,r,s)         Export sales of commodity i from r to region s
    pcif0(*,r,s)        Cif world price of commodity i supplied from r to s
    pfob0(*,r,s)        Fob world price of commodity i supplied from r to s
    qst0(*,r)           Sales of m from r to international transport
;
*       Common variables:
parameters
    y0(r)               Regional household income in region r
    pop0(r)             Regional population
    qoes0(*,*,r)        Supply of sluggish endowment i used by j in r
*     endwslack0(*,r)   Slack variable in endowment market clearing condition
    pgov0(r)            Price index for gov't hhld expenditure in region r
    yg0(r)              Regional government consumption expenditure in region r
    ug0(r)              Per capita utility from gov't expend. in region r
*     ppriv0(r)         Price index for private consumption expenditure in r
    uepriv0(r)          Elasticity of cost wrt utility from private consumption
    yp0(r)              Regional private consumption expenditure in region r
    up0(r)              Per capita utility from private expend. in region r
    to0(*,r)            Output (or income) tax in region r
    qim0(*,s)           "Aggregate imports of i in region s, market price weights"
    globalcgds0         Global supply of capital goods for NET investment
    pcgdswld0           World average price of capital goods 0(net investment weights)
    del_taxrgc0(r)      Government consumption tax
    del_taxrpc0(r)      Private consumption tax
    del_taxriu0(r)      Tax on intermediate usage
    del_taxrfu0(r)      Tax on primary factor usage
    del_taxrout0(r)     Output tax
    del_taxrexp0(r)     Export tax
    del_taxrimp0(r)     Import tax
    del_taxrinc0(r)     Income tax
;
*       --------------------------------
*       Modules:

*       Government consumption:
parameters
    pg0(*,r)            Government consumption price for commodity i in region r
    qg0(*,r)            Government hhld demand for commodity i in region r
    tgd0(*,r)           Tax on domestic i purchased by government hhld in r
    tgm0(*,r)           Tax on imported i purchased by gov't hhld in r
;
*       Private consumption:
parameters
    pp0(*,r)            Private consumption price for commodity i in region r
    qp0(*,r)            Private hhld demand for commodity i in region r
    tp0(r)              "Comm.-, source-gen. shift in tax on private cons."
    tpd0(*,r)           "Comm.-, source-spec. shift in tax on private cons. of dom."
    atpd0(*,r)          Power of tax on domestic i purchased by private hhld in r
    tpm0(*,r)           "Comm.-, source-spec. shift in tax on private cons. of imp."
    atpm0(*,r)          Power of tax on imported i purchased by private hhld in r
;
*       Firms:
parameters
    pva0(*,r)           Firms' price of value added in industry j of region r
    qva0(*,r)           Value added in industry j of region r
    pf0(*,*,r)          Firms' price for commodity i for use by j in r
    qf0(*,*,r)          Demand for commodity i for use by j in region r
    ao0(*,r)            Output augmenting technical change in sector j of r
    ava0(*,r)           Value added augmenting tech change in sector i of r
    af0(*,*,r)          Composite intermed. input i augmenting tech change by j of r
    afe0(*,*,r)         Primary factor i augmenting tech change by j of r
ams0(*,r,s)         Import i from region r augmenting tech change in region s
    aosec0(*)           "Output tech change of sector j, worldwide"
    aoreg0(r)           Output tech change in region r
    aoall0(*,r)         Output augmenting technical change in sector j of r
    avasec0(*)          "Value added tech change of sector j, worldwide"
    avareg0(r)          Value added tech change in region r
    avaall0(*,r)        Value added augmenting technical change in sector j of r
    afcom0(*)           "Intermediate tech change of input i, worldwide"
    afsec0(*)           "Intermediate tech change of sector j, worldwide"
    afreg0(r)           Intermediate tech change in region r
    afall0(*,*,r)       Intermediate input i augmenting tech change by j in r
    tfd0(*,*,r)         Tax on domestic i purchased by j in r
    tfm0(*,*,r)         Tax on imported i purchased by j in r
    tf0(*,*,r)          Tax on primary factor i used by j in region r
    afecom0(*)          "Factor input tech change of input i, worldwide"
    afesec0(*)          "Factor input tech change of sector j, worldwide"
    afereg0(r)          Factor input tech change in region r
    afeall0(*,*,r)      Primary factor i augmenting tech change sector j in r
*     profitslack0(*,r) Slack variable in the zero profit equation
;
*       Investment, Global Bank, Savings:
parameters
    rental0(r)          "Rental rate on capital = ps(capital,r)"
    ke0(r)              End-of-period capital stock in r
    rore0(r)            Expected net rate of return on capital stock in r
    rorc0(r)            Current net rate of return on capital stock in r
    qcgds0(r)           "Output of capital goods sector = qo(cgds,r)"
    ksvces0(r)          "Capital services = qo(capital,r)"
    expand0(*,r)        Change in investment levels relative to endowment stock
    rorg0               Global net rate of return on capital stock
*     cgdslack0(r)      Slack variable for qcgds(r)
*     psaveslack0(r)    Slack variable for the savings price equation
;
*       International Trade:
parameters
    tx0(*,r)            Dest.-gen. change in subsidy on exports of i from r
    txs0(*,r,s)         Dest.-spec. change in subsidy on exports of i from r to s
    tm0(*,s)            Source-gen. change in tax on imports of i into s
    tms0(*,r,s)         Source-spec. change in tax on imports of i from r into s
    pr0(*,r)            Ratio of domestic to imported prices in r
;
*       International Transport Services:
parameters
    qtmfsd0(m,*,r,s)    International usage margin m on i from r to s
    atmfsd0(m,*,r,s)    Tech change in m's shipping of i from region r to s
    atm0(m)             "Tech change in mode m, worldwide"
    atf0(*)             "Tech change shipping of i, worldwide"
    ats0(r)             Tech change shipping from region r
    atd0(s)             Tech change shipping to s
    atall0(m,*,r,s)     Tech change in m's shipping of i from region r to s
    ptrans0(*,r,s)      Cost index for international transport of i from r to s
    qtm0(m)             Global margin usage
    pt0(m)              "Price of composite margins services, type"
;
*       Regional household:
parameters
    uelas0(r)           Elasticity of cost of utility wrt utility
    dppriv0(r)          Private consumption distribution parameter
    dpgov0(r)           Government consumption distribution parameter
    dpsave0(r)          Saving distribution parameter
    fincome0(r)         Factor income at market prices net of depreciation
    del_indtaxr0(r)     Indirect taxes in r
    del_ttaxr0(r)       Taxes in r
*     incomeslack0(r)   Slack variable in the expression for regional income
*     dpav0(r)          "Average distribution parameter shift, for EV calc."
    p0(r)               Price index for disposition of income by regional household
    au0(r)              Input-neutral shift in utility function
*     dpsum0(r)         Sum of the distribution parameters
    u0(r)               Per capita utility from aggregate hhld expend. in region r
;
*       Market clearing condition:
parameters
    qds0(*,r)           Domestic sales of commodity i in r
    tradslack0(*,r)     Slack variable in tradeables market clearing condition
    walras_sup0         Supply in omitted market--global supply of cgds composite
    walras_dem0         Demand in the omitted market--global demand for savings
    walraslack0         Slack variable in the omitted market
;
*       Original parameters:
parameter
    SH_BP               Distribution parameters in CDE private utility function
    psave_adj0          Adjustment factor for psave
    vconshr0(*,r)       Share of private hhld consumption devoted to good i in r

    sh_netinv_globinv0(r)       Share of net investment
    sh_netinv_save_globinv0(r)        Share of excess investment
    sh_vom_vendwreg0(e,r)        Share of endowment factor
    sh_vendwreg_vendwwld0(r)     Share of endowment factor
;
*       ----------------------------------------------------------------------
*       Setting benchmark values:

*       (Power of) tariffs:
tm0(t,r) = 1;
tx0(t,r) = 1;
tp0(r) = 1;
txs0(t,r,s) = 1;
tms0(t,r,s) = 1;

tgd0(t,r)$VDGM(t,r) = VDGA(t,r)/VDGM(t,r);
tgm0(t,r)$VIGM(t,r) = VIGA(t,r)/VIGM(t,r);

tpd0(t,r)$VDPM(t,r) = VDPA(t,r)/VDPM(t,r);
tpm0(t,r)$VIPM(t,r) = VIPA(t,r)/VIPM(t,r);

tfd0(t,j,r)$VDFM(t,j,r) = VDFA(t,j,r) / VDFM(t,j,r);
tfm0(t,j,r)$VIFM(t,j,r) = VIFA(t,j,r) / VIFM(t,j,r);

tf0(e,j,r)$VFM(e,j,r) = VFA(e,j,r) / VFM(e,j,r);
to0(ns,r)$VOM(ns,r) = VOA(ns,r) / VOM(ns,r);

txs0(t,r,s)$VXMD(t,r,s) = VXMD(t,r,s) / VXWD(t,r,s);
tms0(t,r,s)$VIWS(t,r,s) = VIMS(t,r,s) / VIWS(t,r,s);

atpd0(t,r)$VDPM(t,r) = tpd0(t,r) * tp0(r);
atpm0(t,r)$VIPM(t,r) = tpm0(t,r) * tp0(r);

*       Benchmark prices:
pt0(m)$VTMPROV(m) = 1;
pm0(ns,r)$VOM(ns,r) = 1;
ptrans0(t,r,s)$VTFSD(t,r,s) = 1;
pmes0(es,j,r)$VFM(es,j,r) = 1;
pg0(t,r)$VGA(t,r) = 1;
pgov0(r) = 1;
pva0(j,r)$VVA(j,r) = 1;
pf0(t,j,s)$VFA(t,j,s) = 1;
pim0(t,s)$(sum(r, VIMS(t,r,s))) = 1;
pp0(t,s)$VPA(t,s) = 1;
psave0(r) = 1;
psave_adj0 = 1;
pcgds0(r) = 1;
pcgdswld0 = 1;
rental0(r) = 1;
rorc0(r) = 1;
rore0(r) = 1;
rorg0 = 1;

pgd0(t,r)$VDGM(t,r) = tgd0(t,r) * pm0(t,r);
pgm0(t,r)$VIGM(t,r) = tgm0(t,r) * pim0(t,r);
ppd0(t,r)$VDPM(t,r) = atpd0(t,r) * pm0(t,r);
ppm0(t,r)$VIPM(t,r) = atpm0(t,r) * pim0(t,r);
ps0(ns,r)$VOM(ns,r) = to0(ns,r) * pm0(ns,r);

pfd0(t,j,r)$VDFM(t,j,r) = tfd0(t,j,r) * pm0(t,r);
pfm0(t,j,r)$VIFM(t,j,r) = tfm0(t,j,r) * pim0(t,r);

pfe0(em,j,r)$VFA(em,j,r) = tf0(em,j,r) * pm0(em,r);
pfe0(es,j,r)$VFA(es,j,r) = tf0(es,j,r) * pmes0(es,j,r);
pfob0(t,r,s)$VIMS(t,r,s) = pm0(t,r) / (tx0(t,r) * txs0(t,r,s));
pcif0(t,r,s)$VXMD(t,r,s)
    = pfob0(t,r,s) + sum(m, VTMFSD(m,t,r,s) / VXMD(t,r,s));
pms0(t,r,s)$VXMD(t,r,s) = tm0(t,s) * tms0(t,r,s) * pcif0(t,r,s);
pr0(t,s)$(sum(r, VIMS(t,r,s))) = pm0(t,s) / pim0(t,s);

*       Quantity variables:
pop0(r) = POPD(r)$POPD(r) + 1$(not POPD(r));
expand0(c,r) = 1;
qg0(t,r) = VGA(t,r);
yg0(r) = GOVEXP(r);
yp0(r) = PRIVEXP(r);
ug0(r) = GOVEXP(r) / pop0(r);
qgd0(t,r) = VDGM(t,r);
qgm0(t,r) = VIGM(t,r);
qp0(t,r) = VPA(t,r);
qpd0(t,r) = VDPM(t,r);
qpm0(t,r) = VIPM(t,r);
qva0(j,r) = VVA(j,r);
qo0(ns,r) = VOM(ns,r);
qf0(t,j,r) = VFA(t,j,r);
qfm0(t,j,r) = VIFM(t,j,r);
qfd0(t,j,r) = VDFM(t,j,r);
qfe0(e,j,r) = VFM(e,j,r);
qcgds0(r) = REGINV(r);
kb0(r) = VKB(r);
ke0(r) = (1-DEPR(r)) * VKB(r) + sum(c, VOM(c,r));
qxs0(t,r,s) = VXMD(t,r,s);
qim0(t,r) = sum(j, VIFM(t,j,r)) + VIPM(t,r) + VIGM(t,r);
qoes0(es,j,r) = VFM(es,j,r);
fincome0(r) = FY(r);
y0(r) = INCOME(r);
u0(r) = INCOME(r) / pop0(r);
up0(r) = PRIVEXP(r) / pop0(r);
ug0(r) = GOVEXP(r) / pop0(r);
qsave0(r) = SAVE(r);
ksvces0(r) = sum(ec, VOM(ec,r));
qtmfsd0(m,t,r,s) = VTMFSD(m,t,r,s);
qst0(m,r) = VST(m,r);
qtm0(m) = sum((t,s,r), qtmfsd0(m,t,r,s));
globalcgds0 = GLOBINV;
qds0(ns,r) = sum(j, qfd0(ns,j,r)) + qpd0(ns,r) + qgd0(ns,r);
walras_sup0 = pcgdswld0 * globalcgds0;
walras_dem0 = sum(r, psave0(r) * qsave0(r));
vconshr0(t,r) = CONSHR(t,r);

*       Tax revenues:
del_taxrgc0(r) = sum(i, DGTAX(i,r) + IGTAX(i,r));
del_taxrpc0(r) = sum(i, DPTAX(i,r) + IPTAX(i,r));
del_taxriu0(r) = sum((i,j), DFTAX(i,j,r) + IFTAX(i,j,r));
del_taxrfu0(r) = sum((e,j), ETAX(e,j,r));
del_taxrout0(r) = sum(j, PTAX(j,r));
del_taxrexp0(r) = sum((i,s), XTAXD(i,r,s));
del_taxrimp0(r) = sum((i,s), MTAX(i,s,r));
del_taxrinc0(r) = sum(e, PTAX(e,r));
del_indtaxr0(r) = del_taxrpc0(r) + del_taxrgc0(r) + del_taxriu0(r) +
    del_taxrfu0(r) + del_taxrout0(r) + del_taxrexp0(r) + del_taxrimp0(r);
del_ttaxr0(r) = del_taxrpc0(r) + del_taxrgc0(r) + del_taxriu0(r) +
    del_taxrfu0(r) + del_taxrout0(r) + del_taxrexp0(r) + del_taxrimp0(r) +
    del_taxrinc0(r);
uepriv0(r) = sum(t, CONSHR(t,r) * INCPAR(t,r));

if(%fl_debug%,
    display psave0, qsave0, pgd0, qgd0, pm0, pgm0, qgm0, pim0, ppd0, qpd0, ppm0,
	    qpm0, ps0, qo0, pfe0, qfe0, pfd0, qfd0, pfm0, qfm0, pmes0, kb0,
	    pcgds0, pms0, qxs0, pcif0, pfob0, qst0, y0, pop0, qoes0, pgov0, yg0,
	    ug0, yp0, up0, to0, qim0, globalcgds0, pcgdswld0, del_taxrgc0,
	    del_taxrpc0, del_taxriu0, del_taxrfu0, del_taxrout0, del_taxrexp0,
	    del_taxrimp0, del_taxrinc0, pg0, qg0, tgd0, tgm0, pp0, qp0, tp0, tpd0,
	    atpd0, tpm0, atpm0, pva0, qva0, pf0, qf0, tfd0, tfm0, tf0, rental0,
	    ke0, rore0, rorc0, qcgds0, ksvces0, rorg0, tx0, txs0, tm0, tms0, pr0,
	    qtmfsd0, ptrans0, qtm0, pt0, fincome0, del_indtaxr0, del_ttaxr0, u0,
	    qds0, walras_sup0, walras_dem0, psave_adj0,
	    expand0, uepriv0;
);

*       p0,
*       uepriv0, profitslack0, cgdslack0, psaveslack0,
*       tradslack0, incomeslack0, walraslack0 *

sh_netinv_globinv0(r) =
    (pcgds0(r) * (qcgds0(r) - DEPR(r) * kb0(r)) / (pcgdswld0 * globalcgds0));
sh_netinv_save_globinv0(r) =
    (pcgds0(r) * (qcgds0(r) - DEPR(r) * kb0(r)) - psave0(r) * qsave0(r))
    / (pcgdswld0 * globalcgds0);
sh_vom_vendwreg0(e,r)$qo0(e,r) =
    (pm0(e,r) * qo0(e,r) / sum(ee$qo0(ee,r), pm0(ee,r) * qo0(ee,r)));
sh_vendwreg_vendwwld0(r) =
    (sum(e$qo0(e,r), pm0(e,r) * qo0(e,r))
    / sum((rr,ee)$qo0(ee,rr), pm0(ee,rr) * qo0(ee,rr)));
display sh_netinv_globinv0, sh_netinv_save_globinv0, sh_vom_vendwreg0, sh_vendwreg_vendwwld0;

*	----------------------------------------------------------------------
*	Variables for Appendices:
display "com: Variables for Appendices:";

variables
    vxwfob(*,s)	    "Value of merchandise regional exports, by commodity, FOB"
    viwcif(*,s)	    "Value of merchandise regional imports, by commodity, CIF"
    vxwreg(r)	    "Value of merchandise exports, by region"
    viwreg(r)	    "Value of merchandise imports, by region, at world prices"

variables
    pfactreal(*,r)  "Ratio of return to primary factor i to CPI in r"
    pfactreal(*,r)  "Ratio of return to primary factor i to CPI in r"
    pfactor(r)	    "Market price index of primary factors, by region"
    pfactwld	    "World price index of primary factors"

variables
    psw(r)	    "Index of prices received for tradeables produced in r"
    pdw(r)	    "Index of prices paid for tradeables used in region r"
    tot(r)	    "Terms of trade for region r: tot(r) = psw(r) - pdw(r)"

variables
    vgdp(r)	    "Change in value of GDP"
    pgdp(r)	    "GDP price index"
    qgdp(r)	    "GDP quantity index"
    compvalad(*,r)  "Composition of value added for good i and region r"
    ;
variables
    qxw(*,r)	    "Aggregate exports of i from region r, fob weights"

variables
    DTBALi(*,r)	    "Change in trade balance by i and by r, $US million"
    DTBAL(r) 	    "Change in trade balance X - M, $US million"
    DTBALR(r)	    "Change in ratio of trade balance to regional income"
;

variables
    sh_vga_gdp(*,r)	"Share of government expenditure in GDP"
    sh_vpa_gdp(*,r)	"Share of private consumption expenditure in GDP"
    sh_reginv_gdp(r)	"Share of investment expenditure in GDP"
    sh_vxwd_gdp(*,r,s)	"Share of export in GDP"
    sh_vst_gdp(*,r)	"Share of export to intl trns sec in GDP"
    sh_viws_gdp(*,r,s)	"Share of import in GDP"
    v_vxwregion(r)		"Value of export"
    sh_vxwd_vxwregion(*,r,s)	"Share of export to each region"
    sh_vst_vxwregion(*,r)	"Share of export to intl trns sec in GDP"
    v_viwregion(r)		"Value of import"
    sh_viws_viwregion(*,r,s)	"Share of import from each region"
    v_vxw(*,r)
    sh_vxwd_vxw(*,r,s)
    sh_vst_vxw(*,r)
;

*	Variables for calculating EV
variables
    ug_ev(r)		Per capita utility from gov't expend. in region r
    qg_ev(t,r)		Government hhld demand for commodity i in region r
    up_ev(r)		Per capita utility from private expend. in region r
    uepriv_ev(r)	Elasticity of cost wrt utility from private consumption
    vconshr_ev(t,r)	Share of private hhld consumption devoted to good i in r
    qp_ev(t,r)		Private hhld demand for commodity i in region r
    uelas_ev(r)		Elasticity of cost of utility wrt utility
    yp_ev(r)		Regional private consumption expenditure in region r
    yg_ev(r)		Regional government consumption expenditure in region r
    qsave_ev(r)		Regional demand for NET savings
    y_ev(r)		Regional household income in region r
    EV(*)		"Equivalent variation, $ US million"

    u_ev(r)		Per capita utility from aggregate hhld expend. in region r
;

*	----------------------------------------------------------------------
*	Equations for Appendices:
display "com: Equations for Appendices:";

equations
    REALRETURN	 	"Eq'n defines the real rate of return to primary factor i in region r:"
    PRIMFACTPR	 	"Computes \% change in price index of primary factors, by region:"
    E_SH_VOM_VENDWREG	"Share of endowment commodities in region r:"
    PRIMFACTPRWLD	"Computes \% change in global price index of"
    E_SH_VENDWREG_VENDWWLD	"Share of endowment commodities in the world:"
;
equations
    REGSUPRICE	 	"Estimate change in index of prices received for tradeables i produced in r:"
    REGDEMPRICE	 	"Estimate change in index of prices paid for tradeable products used in r:"
    TOTeq	 	"Terms of trade equation computed as difference in psw and pdw (HT 66):"
;
equations
    VGDP_r	 	"Change in value of GDP (HT 70):"
    PGDP_r	 	"GDP price index (HT 71):"
    QGDP_r	 	"Gdp quantity index:"
    COMPVALADEQ	 	"Track change in composition of value added:"
;
equations
    VREGEX_ir		"The change in FOB value of exports of m from r:"
*     VREGEX_ir_MARG	"The change in FOB value of exports of m from r:"
*     VREGEX_ir_NMRG	"The change in FOB value of exports of"
    VREGEX_r	 	"Computes \% change in value of merchandise exports, by region (HT 75):"
    VREGIM_is	 	"Computes \% change in value of imports, CIF basis,"
    VREGIM_s	 	"Computes \% change in value of imports, CIF basis,"
;
equations
    TRADEBAL_i	 	"Computes change in trade balance by commodity and by region (HT 97):"
    TRADEBALANCE	"Computes change in trade balance (X - M), by region (HT 98):"
    DTBALRATIO	 	"Change in ratio of trade balance to regional income:"
;

equations
    E_SH_VGA_GDP	"Share of government expenditure in GDP"
    E_SH_VPA_GDP	"Share of private consumption expenditure in GDP"
    E_SH_REGINV_GDP	"Share of investment expenditure in GDP"
    E_SH_VXWD_GDP	"Share of export in GDP"
    E_SH_VST_GDP	"Share of export to intl trns sec in GDP"
    E_SH_VIWS_GDP	"Share of import in GDP"
    E_V_VXWREGION	"Value of export"
    E_SH_VXWD_VXWREGION	"Share of export to each region"
    E_SH_VST_VXWREGION	"Share of export to intl trns sec in GDP"
    E_V_VIWREGION	"Value of import"
    E_SH_VIWS_VIWREGION	"Share of import from each region"
;
equations
*     QREGEX_ir_MARG
*     QREGEX_ir_NMRG
    QREGEX_ir		"change in volume of exports of commodity i from r:"
    E_V_VXW(*,r)
    E_SH_VXWD_VXW(*,r,s)
    E_SH_VST_VXW(*,r)
;
*	Equations for calculating EV
equations
    GOVU_EV(r)		"Per capita utility from gov't expend. in region r"
    GOVDMNDS_EV(t,r)	"Government hhld demand for commodity i in region r"
    PRIVATEU_EV(r)	"Per capita utility from private expend. in region r"
    UTILELASPRIV_EV(r)	"Elasticity of cost wrt utility from private consumption"
    E_VCONSHR_EV(t,r)	"Share of private hhld consumption devoted to good i in r"
    PRIVDMNDS_EV(t,r)	"Private hhld demand for commodity i in region r"
    UTILITELASTIC_EV(r)	"Elasticity of cost of utility wrt utility"
    PRIVCONSEXP_EV(r)	"Regional private consumption expenditure in region r"
    GOVCONSEXP_EV(r)	"Regional government consumption expenditure in region r"
    SAVING_EV(r)	"Regional demand for NET savings"
    UTILITY_EV(r)	"Regional household income in region r"
    E_EV(r)		"Equivalent variation, $ US million"
;
*	----------------------------------------------------------------------
*	Benchmark parameters for Appendices:
display "com: Benchmark parameters for Appendices:";

parameters
    vxwfob0(*,s)    "Value of merchandise regional exports, by commodity, FOB"
    viwcif0(*,s)    "Value of merchandise regional imports, by commodity, CIF"
    vxwreg0(r)	    "Value of merchandise exports, by region"
    viwreg0(r)	    "Value of merchandise imports, by region, at world prices"

parameters
    pfactreal0(*,r)  "Ratio of return to primary factor i to CPI in r"
    pfactreal0(*,r)  "Ratio of return to primary factor i to CPI in r"
    pfactor0(r)	    "Market price index of primary factors, by region"
    pfactwld0	    "World price index of primary factors"

parameters
    psw0(r)	    "Index of prices received for tradeables produced in r"
    pdw0(r)	    "Index of prices paid for tradeables used in region r"
    tot0(r)	    "Terms of trade for region r: tot(r) = psw(r) - pdw(r)"

parameters
    vgdp0(r)	    "Change in value of GDP"
    pgdp0(r)	    "GDP price index"
    qgdp0(r)	    "GDP quantity index"
    compvalad0(*,r) "Composition of value added for good i and region r"

parameters
    qxw0(*,r)	    "Aggregate exports of i from region r, fob weights"
;
parameters
    DTBALi0(*,r)    "Change in trade balance by i and by r, $US million"
    DTBAL0(r) 	    "change in trade balance X - M, $US million"
    DTBALR0(r)	    "Change in ratio of trade balance to regional income"
;

parameters
    sh_vga_gdp0(*,r)	"Share of government expenditure in GDP"
    sh_vpa_gdp0(*,r)	"Share of private consumption expenditure in GDP"
    sh_reginv_gdp0(r)	"Share of investment expenditure in GDP"
    sh_vxwd_gdp0(*,r,s)	"Share of export in GDP"
    sh_vst_gdp0(*,r)	"Share of export to intl trns sec in GDP"
    sh_viws_gdp0(*,r,s)	"Share of import in GDP"
    v_vxwregion0(r)		"Value of export"
    sh_vxwd_vxwregion0(*,r,s)	"Share of export to each region"
    sh_vst_vxwregion0(*,r)	"Share of export to intl trns sec in GDP"
    v_viwregion0(r)		"Value of import"
    sh_viws_viwregion0(*,r,s)	"Share of import from each region"
    v_vxw0(*,r)
    sh_vxwd_vxw0(*,r,s)
    sh_vst_vxw0(*,r)
;

*       ----------------------------------------------------------------------
*       Benchmark parameters in Appendices:
display "com: -- Benchmark parameters in Appendices:";

vxwfob0(i,s) = VXW(i,s);
viwcif0(i,s) = VIW(i,s);
vxwreg0(r) = sum(i, vxwfob0(i,r));
viwreg0(r) = sum(i, viwcif0(i,r));

pfactreal0(i,r) = 1;
pfactreal0(i,r) = 1;
pfactor0(r) = 1;
pfactwld0 = 1;

psw0(r)	= 1;
pdw0(r)	= 1;
tot0(r)	= 1;

vgdp0(r) = GDP(r);
pgdp0(r) = 1;
qgdp0(r) = vgdp0(r) / pgdp0(r);
compvalad0(i,r) = 1;

qxw0(t,r) = sum(s, VXWD(t,r,s)) + VST(t,r);

DTBALi0(i,r) = vxwfob0(i,r) - viwcif0(i,r);
DTBAL0(r) = vxwreg0(r) - viwreg0(r);
DTBALR0(r) = DTBAL0(r) / INCOME(r);
;

sh_vga_gdp0(t,r) = VGA(t,r) / GDP(r);
sh_vpa_gdp0(t,r) = VPA(t,r) / GDP(r);
sh_reginv_gdp0(r) = REGINV(r) / GDP(r);
sh_vxwd_gdp0(t,r,s) = VXWD(t,r,s) / GDP(r);
sh_vst_gdp0(m,r) = VST(m,r) / GDP(r);
sh_viws_gdp0(t,s,r) = VIWS(t,s,r) / GDP(r);

v_vxwregion0(r)	= sum((t,s), VXWD(t,r,s)) + sum(m, VST(m,r));
sh_vxwd_vxwregion0(t,r,s) = VXWD(t,r,s) / v_vxwregion0(r);
sh_vst_vxwregion0(m,r) = VST(m,r) / v_vxwregion0(r);
v_viwregion0(r) = sum((t,s), VIWS(t,s,r));
sh_viws_viwregion0(t,s,r) = VIWS(t,s,r) / v_viwregion0(r);

v_vxw0(t,r) = VXW(t,r);
sh_vxwd_vxw0(t,r,s)$VXW(t,r)
    = VXWD(t,r,s) / VXW(t,r);
sh_vst_vxw0(m,r)$VXW(m,r)
    = VST(m,r) / VXW(m,r);

display vxwfob0, viwcif0, vxwreg0, viwreg0;

display pfactreal0, pfactreal0, pfactor0, pfactwld0;

display psw0, pdw0, tot0;

display vgdp0, pgdp0, qgdp0, compvalad0;

display qxw0;

display DTBALi0, DTBAL0, DTBALR0;

display sh_vga_gdp0, sh_vpa_gdp0, sh_reginv_gdp0, sh_vxwd_gdp0, sh_vst_gdp0,
	sh_viws_gdp0;

display v_vxwregion0, sh_vxwd_vxwregion0, sh_vst_vxwregion0, v_viwregion0,
	sh_viws_viwregion0;

display v_vxw0, sh_vxwd_vxw0, sh_vst_vxw0;

*	----------------------------------------------------------------------
*	Variables for GTAP-E:
display "com: Variables for GTAP-E:";

variables
    gco2(r,*)       "Growth of emissions by fuel"
    gco2t(r)        "Growth of emissions  by region"
    gco2q(r)        "Growth of emissions quota by region"
    vdem(*,r)       "Per cent change of total value demand of energy goods"
    qdem(*,r)       "Per cent change of total  demand of energy goods in volume"
    apen(*,r)       "Per cent change of average energy prices"
;
variables
    qoe(*,r)		The amount of energy used in domestic products:
    qime(*,r)		The amount of energy used in import products:
    qxwe(*,r)		The amount of energy used in export products:
    qened(*,r)		The amount of energy
    v_oilsales(r,*)
    sh_vfa_oil(*,*,r)
    sh_vpa_oil(*,r)
    sh_vga_oil(*,r)
;
variables
    gmarkco2t      "\% Growth of total emissions on the multicountry market"
    DVCO2TRA(r)    "Change of value of net emission trading"
    DTBALCTRA(r)   "Change of value of trade balance including emission trading"
;

variables
    NCTAX(r)       "Change of nominal carbon taxes in 97 USD per ton of C"
    RCTAX(r)       "Change of real carbon taxes in 97 USD per ton of C"
    MARKCTAX       "Change of nominal carbon tax on multicountry market"
    VCTAX(r,*)     "Carbon tax amounts in M USD"
    dcwfd(*,*,r)   "% change of the power of the C tax on domest.uses by firms"
    dcwfi(*,*,r)   "% change of the power of the C tax on imported .uses by firms"
    dcwpd(*,r)     "% change of the power of the C tax on domest.uses by households"
    dcwpi(*,r)     "% change of the power of the C tax on imported.uses by households"
    dcwgd(*,r)     "% change of the power of the C tax on domest.uses by govern."
    dcwgi(*,r)     "% change of the power of the C tax on imported uses by govern."
;

variables
    pfdnc(*,*,s)    "Price index for domestic purchases of i by j in region s EXCL. C TAX"
    pfmnc(*,*,s)    "Price index for imports of i by j in region s EXCL. CTAX"
    ppdnc(*,s)      "Price of domestic i to private households in s; EXCL. C. TAX"
    ppmnc(*,s)      "Price of imports of i by private households in s; EXCL. C TAX"
    pgdnc(*,s)      "Price of domestic i to government households in s; EXCL. C. TAX"
    pgmnc(*,s)      "Price of imports of i by government households in s; EXCL. C.TAX"
;

variables
    pvaen(j,r)      "Firms' price of value-added in industry j of region r"
    qvaen(j,r)      "Value-added in industry j of region r"
    pke(j,r)        "Firms' price of KE composite in industry j of region r"
    qke(j,r)        "Composite capital-energy in industry j of region r "
    pen(j,r)        "Price of energy (elec.+ non elec.) composite in industry j of region r"
    qen(j,r)        "Composite energy (el.+n-el.) in industry j of region r "
    pnel(j,r)       "Price of non-electric composite in industry j of region r"
    qnel(j,r)       "Composite non-electric good in industry j of region r "
    pncoal(j,r)     "Price of non-coal composite in industry j of region r"
    qncoal(j,r)     "Composite  non-coal energy good in industry j of region r "
;

variables
    NOMCTAX_L(r)    "Level of carbon tax in nominal"
    CO2_L(r,*)      "Level of emissions"
    VDFA_L(*,*,r)   "Value (M$)of domestic energy purchases by firms, excluding carbon tax"
    VIFA_L(*,*,r)   "Value (M$)of imported energy purchases by firms, excluding carbon tax"
    VDPA_L(*,r)     "Value (M$)of domestic energy purchases by households, excl. carbon tax"
    VIPA_L(*,r)     "Value (M$)of imported energy purchases by households, excl. carbon tax"
    VDGA_L(*,r)     "Value (M$)of domestic energy purchases by government, excl. carbon tax"
    VIGA_L(*,r)     "Value (M$)of imported energy purchases by government, excl. carbon tax"
    CTAXBAS(r,*)    "Tax base (M$) for the calculation of ad valorem carbon tax rates"
    CPOWER(r,*)     "Carbon tax power"
;
*	----------------------------------------------------------------------
*	Equations for GTAP-E:
display "com: Equations for GTAP-E:";

equations
    KEPRICE		"(Effective) price of composite K+energy sectors in each sector/region. (HT 33)"
    ENPRICE		"(Effective) price of composite energy good in each sector/region. (HT 33)"
    NELYPRICE		"(Effective) price of composite non-electric good in each sector/region. (HT 33)"
    NCOALPRICE		"(Effective) price of composite non-coal energy good in each sector/region. (HT 33)"
    KEDEMAND		"Level 1: Demands for the composite KE"
    KDEMAND		"Level 2: Demands for capital"
    ENDEMAND		"Level 2: Demands for composite energy good"
    NELYDEMAND		"Level 3: Demands for composite non-electric good"
    NCOALDEMAND		"Level 4: Demands for composite non-coal energy good "
;
equations
    CEMISSIONS		"Emission growth by fuels (except crude oil) "
    OILEMISSIONS	"Emission growth from crude oil		 "
    TOTALEMISSIONS 	"Total CO2 emissions in M. tons of C"
    MARKEMISS	   	"Emission growth on multicountry market (world by default) "
    EMQUOTA	   	"Growth of em. quotas: endogenous only for non-trading cou. "
    EMTRADING	   	"Equation that calculates the value of net emission trading"
    TRAEMTRADBAL   	"Sum of trade balance and emission trading"
;
equations
    NOMCTAX	   	"Convert real tax into nominal tax"
    REALTAXCH	   	"Calculate the real tax change on multicountry market"
;
equations
    TOTVALEN
    TOTQUAEN
    AVPRICE	   	"Average energy prices in per cent change and real terms"
;
equations
    E_TAXLEV
    E_CO2
    E_VDFA_L
    E_VIFA_L
    E_VDPA_L
    E_VIPA_L
    E_VDGA_L
    E_VIGA_L
;
equations
    VALCTAX		"Carbon tax amounts by energy"
    E_TAXBASE		"Tax base for emission tax"
*     E_TAXBASCOAL	"Tax base for coal"
*     E_TAXBASOIL		"Tax base for crude oil"
*     E_TAXBASGAS		"Tax base for natural gas"
*     E_TAXBASOILPCS	"Tax base for refined oil products"
;
equations
    E_CPOWER
    E_FDPOWER		"Domestic intermediate inputs"
    E_FIPOWER		"Imported intermediate inputs "
*     E_FDPOWERCOAL	"Domestic intermediate inputs"
*     E_FDPOWEROIL
*     E_FDPOWERGAS
*     E_FDPOWEROILPCS
*     E_FIPOWERCOAL	"Imported intermediate inputs "
*     E_FIPOWEROIL
*     E_FIPOWERGAS
*     E_FIPOWEROILPCS
    E_PDPOWER		"Domestic demand by households "
    E_PIPOWER		"Imported demand by households "
    E_GDPOWER		"Domestic demand by government "
    E_GIPOWER		"Imported demand by government "
;
equations
    DMNDDPRICE1
    DMNDIPRICES1
;
equations
    PHHDPRICE1
    PHHIPRICE1
;
equations
    GHHDPRICE1
    GHHIPRICES1
;
equations
    VADEMAND_E       "Sector demands for primary factor + energy composite"
    VAPRICE_E        "Effective price of Va+energy composite in each sector/region (HT 33)"
;
equations
    E_QOE		The amount of energy used in domestic products:
    E_QIME		The amount of energy used in import products:
    E_QXWE		The amount of energy used in export products:
    E_QENED		The amount of energy
    E_V_OILSALES
    E_SH_VFA_OIL
    E_SH_VPA_OIL
    E_SH_VGA_OIL
;
$ontext
equations
    VADEMAND       "Sector demands for primary factor + energy composite"
    VAPRICE        "Effective price of Va+energy composite in each sector/region (HT 33)"
    ENDWDEMAND     "Level 1: Demands for endowment commodities other than the composite KE. demands for endowment commodities (HT 34)"
    INTDEMAND      "Industry demands for intermediate inputs, including cgds"
    ZEROPROFITS    "Industry zero pure profits condition (HT 6)"
    REGIONALINCOME "Regional income = sum of primary factor income and indirect tax receipts"
    DMNDDPRICE
    DMNDIPRICES
    PHHDPRICE
    PHHIPRICES
    GHHDPRICE
    GHHIPRICES
;
$offtext

*	----------------------------------------------------------------------
*	Benchmark parameters for GTAP-E
display "com: Benchmark parameters for GTAP-E";

parameters
    gco20(r,*)	     "Growth of emissions by fuel"
    gco2t0(r)	     "Growth of emissions  by region"
    gco2q0(r)	     "Growth of emissions quota by region"
    vdem0(*,r)	     "Per cent change of total value demand of energy goods"
    qdem0(*,r)	     "Per cent change of total	demand of energy goods in volume"
    apen0(*,r)	     "Per cent change of average energy prices"
;
parameters
    qoe0(*,r)		The amount of energy used in domestic products:
    qime0(*,r)		The amount of energy used in import products:
    qxwe0(*,r)		The amount of energy used in export products:
    qened0(*,r)		The amount of energy
    v_oilsales0(r,*)
    sh_vfa_oil0(*,*,r)
    sh_vpa_oil0(*,r)
    sh_vga_oil0(*,r)
;
parameters
    gmarkco2t0	   "\% Growth of total emissions on the multicountry market"
    DVCO2TRA0(r)    "Change of value of net emission trading"
    DTBALCTRA0(r)   "Change of value of trade balance including emission trading"
;

parameters
    NCTAX0(r)	    "Change of nominal carbon taxes in 97 USD per ton of C"
    RCTAX0(r)	    "Change of real carbon taxes in 97 USD per ton of C"
    MARKCTAX0	   "Change of nominal carbon tax on multicountry market"
    VCTAX0(r,*)	    "Carbon tax amounts in M USD"
    dcwfd0(*,*,r)   "% change of the power of the C tax on domest.uses by firms"
    dcwfi0(*,*,r)   "% change of the power of the C tax on imported .uses by firms"
    dcwpd0(*,r)	    "% change of the power of the C tax on domest.uses by households"
    dcwpi0(*,r)	    "% change of the power of the C tax on imported.uses by households"
    dcwgd0(*,r)	    "% change of the power of the C tax on domest.uses by govern."
    dcwgi0(*,r)	    "% change of the power of the C tax on imported uses by govern."
;
parameters
    pfdnc0(*,*,s)    "Price index for domestic purchases of i by j in region s EXCL. C TAX"
    pfmnc0(*,*,s)    "Price index for imports of i by j in region s EXCL. CTAX"
    ppdnc0(*,s)	     "Price of domestic i to private households in s; EXCL. C. TAX"
    ppmnc0(*,s)	     "Price of imports of i by private households in s; EXCL. C TAX"
    pgdnc0(*,s)	     "Price of domestic i to government households in s; EXCL. C. TAX"
    pgmnc0(*,s)	     "Price of imports of i by government households in s; EXCL. C.TAX"
;
parameters
    pvaen0(j,r)	     "Firms' price of value-added in industry j of region r"
    qvaen0(j,r)	     "Value-added in industry j of region r"
    pke0(j,r)	     "Firms' price of KE composite in industry j of region r"
    qke0(j,r)	     "Composite capital-energy in industry j of region r "
    pen0(j,r)	     "Price of energy (elec.+ non elec.) composite in industry j of region r"
    qen0(j,r)	     "Composite energy (el.+n-el.) in industry j of region r "
    pnel0(j,r)	     "Price of non-electric composite in industry j of region r"
    qnel0(j,r)	     "Composite non-electric good in industry j of region r "
    pncoal0(j,r)     "Price of non-coal composite in industry j of region r"
    qncoal0(j,r)     "Composite	 non-coal energy good in industry j of region r "
;
parameters
    NOMCTAX_L0(r)    "Level of carbon tax in nominal"
    CO2_L0(r,*)	     "Level of emissions"
    VDFA_L0(*,*,r)   "Value (M$)of domestic energy purchases by firms, excluding carbon tax"
    VIFA_L0(*,*,r)   "Value (M$)of imported energy purchases by firms, excluding carbon tax"
    VDPA_L0(*,r)     "Value (M$)of domestic energy purchases by households, excl. carbon tax"
    VIPA_L0(*,r)     "Value (M$)of imported energy purchases by households, excl. carbon tax"
    VDGA_L0(*,r)     "Value (M$)of domestic energy purchases by government, excl. carbon tax"
    VIGA_L0(*,r)     "Value (M$)of imported energy purchases by government, excl. carbon tax"
    CTAXBAS0(r,*)    "Tax base (M$) for the calculation of ad valorem carbon tax rates"
    CPOWER0(r,*)     "Carbon tax power"
;
*       ----------------------------------------------------------------------
*       Setting benchmark values:

vdem0(i,r) =
    sum(j, pfd0(i,j,r)*qfd0(i,j,r))
    + sum(j, pfm0(i,j,r)*qfm0(i,j,r))
    + ppd0(i,r)*qpd0(i,r) + ppm0(i,r)*qpm0(i,r) + pgd0(i,r)*qgd0(i,r) + pgm0(i,r)*qgm0(i,r);

display vdem0;

pfdnc0(t,j,s) = tfd0(t,j,s) * pm0(t,s);
pfmnc0(t,j,s) = tfm0(t,j,s) * pim0(t,s);
ppdnc0(t,s) = atpd0(t,s) * pm0(t,s);
ppmnc0(t,s) = atpm0(t,s) * pim0(t,s);
pgdnc0(t,s) = tgd0(t,s) * pm0(t,s);
pgmnc0(t,s) = tgm0(t,s) * pim0(t,s);

display pfdnc0, pfmnc0, ppdnc0, ppmnc0, pgdnc0, pgmnc0;

pvaen0(j,r) = 1;
pke0(j,r) = 1;
pen0(j,r) = 1;
pnel0(j,r) = 1;
pncoal0(j,r) = 1;
display pvaen0, pke0, pen0, pnel0, pncoal0;

*       ----------------------------------------------------------------------
*       Equation definitions:
display "com: -- Equation definitions:";

*       Definition of price index for aggregate gov't purchases (HT 40):
GPRICEINDEX(r) ..

    pgov(r) =e= prod(t$VGA(t,r), (pg(t,r))**(VGA(t,r)/GOVEXP(r)));

*       Government consumption demands for composite commodities (HT41):
GOVDMNDS(t,r)$qg0(t,r) ..

    qg(t,r) =e= pop(r) * ug(r) * (pgov(r)/pg(t,r));

*       Utility from government consumption in r:
GOVU(r) ..

    yg0(r) * yg(r) =e=
    pgov0(r) * pgov(r) * ug0(r) * ug(r) * pop0(r) * pop(r);

*       Eq'n links domestic market and government consumption prices (HT
*       19):
GHHDPRICE(t,r)$VDGM(t,r) ..

    pgd0(t,r) * pgd(t,r)
    =e= tgd(t,r) * pm0(t,r) * pm(t,r);

*       Eq'n links domestic market and government consumption prices (HT
*       22):
GHHIPRICES(t,r)$qgm0(t,r) ..

    pgm0(t,r) * pgm(t,r)
    =e= tgm(t,r) * pim0(t,r) * pim(t,r);

*       Government consumption price for composite commodities (HT 42):
GCOMPRICE(t,r) ..

    pg(t,r) =e=
    (GMSHR(t,r) * (pgm(t,r))**(1-ESUBD(t))
    + (1-GMSHR(t,r)) * (pgd(t,r))**(1-ESUBD(t))
    )**(1/(1-ESUBD(t)))
    ;

*       Government consumption demand for aggregate imports (HT 43):
GHHLDAGRIMP(t,r)$qgm0(t,r) ..

    qgm(t,r) =e= qg(t,r)
    * (pg(t,r)/pgm(t,r))**(ESUBD(t));

*       Government consumption demand for domestic goods (HT 44):
GHHLDDOM(t,r)$qgd0(t,r) ..

    qgd(t,r) =e= qg(t,r)
    * (pg(t,r)/pgd(t,r))**(ESUBD(t));

*       Government consumption tax payments:
TGCRATIO(r) ..

    del_taxrgc(r) =e=
    sum(t$qgd0(t,r),
        (tgd(t,r) - 1) * pm0(t,r) * pm(t,r) * qgd0(t,r) * qgd(t,r))
    + sum(t$qgm0(t,r),
        (tgm(t,r) - 1) * pim0(t,r) * pim(t,r) * qgm0(t,r) * qgm(t,r));

*       Computation of utility from private consumption in r (HT 45):
PRIVATEU(r) ..

    sum(t$qp0(t,r),
        SH_BP(t,r) * (up0(r)*up(r))**(SUBPAR(t,r)*INCPAR(t,r))
        * ((pp0(t,r)*pp(t,r))/(yp0(r)*yp(r)/(pop0(r)*pop(r))))**(SUBPAR(t,r)))
    =e= 1;

*       Elasticity of expenditure wrt utility from private consumption:
UTILELASPRIV(r) ..

    uepriv0(r) * uepriv(r) =e=
    sum(t$CONSHR(t,r), vconshr0(t,r) * vconshr(t,r) * INCPAR(t,r));

*       Share of private hhld consumption devoted to good i in r
E_VCONSHR(t,r)$CONSHR(t,r) ..

    vconshr0(t,r) * vconshr(t,r) =e=
    pp0(t,r) * pp(t,r) * qp0(t,r) * qp(t,r) / (yp0(r)*yp(r));

*       Private consumption demands for composite commodities (HT 46):
PRIVDMNDS(t,r)$VPA(t,r) ..

    (qp0(t,r)*qp(t,r)/(pop0(r)*pop(r)))
    =e= (SH_BP(t,r) * (up0(r)*up(r))**(SUBPAR(t,r) * INCPAR(t,r))
        * SUBPAR(t,r)
        * ((pp0(t,r)*pp(t,r))/(yp0(r)*yp(r)/(pop0(r)*pop(r)))
	)**(SUBPAR(t,r) - 1)
    ) /
    (sum(tt,
	SH_BP(tt,r) * (up0(r)*up(r))**(SUBPAR(tt,r) * INCPAR(tt,r))
        * SUBPAR(tt,r)
        * ((pp0(tt,r)*pp(tt,r))/(yp0(r)*yp(r)/(pop0(r)*pop(r)))
	)**(SUBPAR(tt,r))));

*       Permits uniform consumption tax change:
TPDSHIFT(t,r)$VDPM(t,r) ..

    atpd(t,r) =e= tpd(t,r) * tp(r);

*       Eq'n links domestic market and private consumption prices (HT 18):
PHHDPRICE(t,r)$VDPM(t,r) ..

    ppd0(t,r) * ppd(t,r) =e= atpd(t,r) * pm0(t,r) * pm(t,r);

*       Permits uniform consumption tax change:
TPMSHIFT(t,r)$VIPM(t,r) ..

    atpm(t,r) =e= tpm(t,r) * tp(r);

*       Eq'n links domestic market and private consumption prices (HT 21):
PHHIPRICES(t,r)$VIPM(t,r) ..

    ppm0(t,r) * ppm(t,r) =e= atpm(t,r) * pim0(t,r) * pim(t,r);
;
*       Private consumption tax payments:
TPCRATIO(r) ..

    del_taxrpc(r) =e=
    sum(t$qpd0(t,r),
        (atpd(t,r) - 1) * pm0(t,r) * pm(t,r) * qpd0(t,r) * qpd(t,r))
    + sum(t$qpm0(t,r),
        (atpm(t,r) - 1) * pim0(t,r) * pim(t,r) * qpm0(t,r) * qpm(t,r));

*       Private consumption price for composite commodities (HT 47):
PCOMPRICE(t,r)$qp0(t,r) ..

    pp(t,r) =e=
    ((PMSHR(t,r) * (ppm(t,r))**(1-ESUBD(t)))$qpm0(t,r)
        + ((1-PMSHR(t,r)) * (ppd(t,r))**(1-ESUBD(t)))$qpd0(t,r)
    )**(1/(1-ESUBD(t)));

*       Private consumption demand for domestic goods (HT 48):
PHHLDDOM(t,r)$qpd0(t,r) ..

    qpd(t,r) =e= qp(t,r)
    * (pp(t,r)/ppd(t,r))**(ESUBD(t));

*       Private consumption demand for aggregate imports (HT 49):
PHHLDAGRIMP(t,r)$qpm0(t,r) ..

    qpm(t,r) =e= qp(t,r)
    * (pp(t,r)/ppm(t,r))**(ESUBD(t));

*       "Sector/region specific average rate of output augmenting tech
*       change:"
AOWORLD(i,r)$qo0(i,r) ..

    ao(i,r) =e= aosec(i) * aoreg(r) * aoall(i,r);

*       "Sector/region specific average rate of value added augmenting tech
*       change:"
* AVAWORLD(i,r)$qva0(i,r) ..
AVAWORLD(i,r) ..

    ava(i,r) =e= avasec(i) * avareg(r) * avaall(i,r);

*       Sector demands for primary factor composite:
VADEMAND(j,r)$qva0(j,r) ..

    qva(j,r) - (1/ava(j,r)) * (qo(j,r)/ao(j,r))
    * (ps(j,r)*ao(j,r) / (pva(j,r)/ava(j,r)))**(ESUBT(j))
    =e= 0;

*       "Sector/region specific average rate of intermediates augmenting
*       tech change:"
AFWORLD(t,j,r)$qf0(t,j,r) ..

    af(t,j,r) =e= afcom(t) * afsec(j) * afreg(r) * afall(t,j,r);

*       "Industry demands for intermediate inputs, including cgds:"
INTDEMAND(t,j,r)$qf0(t,j,r) ..

    qf(t,j,r) =e=

    (1/af(t,j,r)) * (qo(j,r)/ao(j,r))
    * (ps(j,r)*ao(j,r) / (pf(t,j,r)/af(t,j,r)))**(ESUBT(j));

*       Eq'n links domestic market and firm prices (HT 20):
DMNDDPRICE(t,j,r)$qfd0(t,j,r) ..

    pfd0(t,j,r) * pfd(t,j,r)
    =e= tfd(t,j,r) * pm0(t,r) * pm(t,r);

*       Eq'n links domestic market and firm prices (HT 23):
DMNDIPRICES(t,j,r)$qfm0(t,j,r) ..

    pfm0(t,j,r) * pfm(t,j,r)
    =e= tfm(t,j,r) * pim0(t,r) * pim(t,r);
;
*       Tax payments on intermediate goods:
TIURATIO(r) ..

    del_taxriu(r) =e=
    sum(t, sum(j$qfd0(t,j,r),
        (tfd(t,j,r) - 1) * pm0(t,r) * pm(t,r)
        * qfd0(t,j,r) * qfd(t,j,r)))
    + sum(t, sum(j$qfm0(t,j,r),
        (tfm(t,j,r) - 1) * pim0(t,r) * pim(t,r)
        * qfm0(t,j,r) * qfm(t,j,r)));

*       Industry price for composite commodities (HT 30):
ICOMPRICE(t,j,r)$VFA(t,j,r) ..

    pf(t,j,r) =e=
    ((FMSHR(t,j,r) * (pfm(t,j,r))**(1-ESUBD(t)))$qfm0(t,j,r)
        + ((1-FMSHR(t,j,r)) * (pfd(t,j,r))**(1-ESUBD(t)))$qfd0(t,j,r)
    )**(1/(1-ESUBD(t)));

*       Industry j demands for composite import i (HT 31):
INDIMP(t,j,r)$qfm0(t,j,r) ..

    qfm(t,j,r) =e= qf(t,j,r) * (pf(t,j,r) / pfm(t,j,r))**(ESUBD(t));

*       Industry j demands for domestic good i (HT 32):
INDDOM(t,j,r)$qfd0(t,j,r) ..

    qfd(t,j,r) =e= qf(t,j,r) * (pf(t,j,r) / pfd(t,j,r))**(ESUBD(t));

*       Eq'n links domestic and firm demand prices (HT 16):
MPFACTPRICE(em,j,r)$qfe0(em,j,r) ..

    pfe0(em,j,r) * pfe(em,j,r) =e= tf(em,j,r) * pm0(em,r) * pm(em,r);

*       Eq'n links domestic and firm demand prices (HT 17):
SPFACTPRICE(es,j,r)$qoes0(es,j,r) ..

    pfe0(es,j,r) * pfe(es,j,r) =e= tf(es,j,r) * pmes0(es,j,r) * pmes(es,j,r);

*       "Sector/region specific average rate of prim. factor i augmenting
*       tech change:"
AFEWORLD(e,j,r)$qfe0(e,j,r) ..

    afe(e,j,r) =e= afecom(e) * afesec(j) * afereg(r) * afeall(e,j,r);

*       "Effective price of primary factor composite in each sector/region
*       (HT 33):"
VAPRICE(j,r)$qva0(j,r) .. 

    pva(j,r) -
    (sum(e$SVA(e,j,r), SVA(e,j,r) * (pfe(e,j,r)/afe(e,j,r))**(1-ESUBVA(j,r)))
    )**(1/(1-ESUBVA(j,r)))
    =e= 0;

*       Tax payments on factor usage:
TFURATIO(r) ..

    del_taxrfu(r) =e=
    sum(em, sum(j$qfe0(em,j,r),
        (tf(em,j,r) - 1) * pm0(em,r) * pm(em,r)
        * qfe0(em,j,r) * qfe(em,j,r)))
    + sum(es, sum(j$qfe0(es,j,r),
        (tf(es,j,r) - 1) * pmes0(es,j,r) * pmes(es,j,r)
        * qfe0(es,j,r) * qfe(es,j,r)));

*       Demands for endowment commodities (HT 34):
ENDWDEMAND(e,j,r)$qfe0(e,j,r) ..

    qfe(e,j,r) =e=
    (1/afe(e,j,r)) * qva(j,r)
	* (pva(j,r) / (pfe(e,j,r)/afe(e,j,r)))**(ESUBVA(j,r));

* OUTPUTPRICES(j,r)$qo0(j,r) ..
*     ps(j,r) =e= to(j,r) * pm(j,r);

*       Output tax payments:
TOUTRATIO(r) ..

    del_taxrout(r) =e=
    sum(j$qo0(j,r), (1 - to(j,r)) * pm0(j,r) * pm(j,r) * qo0(j,r) * qo(j,r));

*       Industry zero pure profits condition (HT 6):
ZEROPROFITS(j,r)$qo0(j,r) ..

    (1 / ao(j,r))
    * ((sum(e$STC(e,j,r),
	STC(e,j,r))) * (pva(j,r)/(ava(j,r)))**(1-ESUBT(j))
        + sum(t$STC(t,j,r),
	    STC(t,j,r) * (pf(t,j,r)/af(t,j,r))**(1-ESUBT(j)))
    )**(1/(1-ESUBT(j)))
    + profitslack(j,r)

    =g= ps(j,r);

*       Eq'n defines a variable for capital services (HT 52):
KAPSVCES(r) ..

    ksvces(r) =e= sum(ec, (VOA(ec,r)/sum(ecc, VOA(ecc,r)) * qo(ec,r)));

*       Eq'n defines a variable for capital rental rate (HT 53):
KAPRENTAL(r) ..

    rental(r) =e= sum(ec, (VOA(ec,r)/sum(ecc, VOA(ecc,r))) * ps(ec,r));

* CAPGOODS(r) ..

*     qcgds0(r) * sum(c, qo(c,r)) =e= qcgds(r);

*       Eq'n defines the price of cgds (HT 55):
PRCGOODS(r) ..

    pcgds(r) =e= sum(c, (VOA(c,r)/REGINV(r)) * ps(c,r));

*       "Associates change in cap. services w/ change in cap. stock (HT
*       56):"
KBEGINNING(r) ..

    kb(r) =e= ksvces(r);

*       Ending capital stock equals beginning stock plus net investment. (HT
*       10):
KEND(r) ..

    ke0(r) * ke(r) =e= (1-DEPR(r)) * kb0(r) * kb(r) + qcgds0(r) * qcgds(r);

*       Current rate of return on capital in region r (HT 57):
RORCURRENT(r) ..

    rorc(r)
    - (1/(rental0(r)/pcgds0(r) - DEPR(r)))
    * (rental0(r) * rental(r) / (pcgds0(r) * pcgds(r)) - DEPR(r))
    =e= 0;

*       Expected rate of return depends on the current return and investment
*       (HT 58):
ROREXPECTED(r) ..

    rore(r) - rorc(r) * (ke(r) / kb(r))**(-RORFLEX(r))
    =e= 0;

*       Change in investment levels relative to endowment stock:
BALDWIN(c,r) ..

    expand(c,r) - qcgds(r)/qo(c,r)
    =e= 0;

*       Either gross investment or expected rate of return in region r (HT
*       59):
RORGLOBAL(r) ..

    RORDELTA * (rorg - rore(r))
    + (1 - RORDELTA)
    * ((qcgds0(r) * qcgds(r) - DEPR(r) * kb0(r) * kb(r))
	/ (qcgds0(r) - DEPR(r) * kb0(r))
        - globalcgds)
    + cgdslack(r) =e= 0;

*       Either expected global rate of return or global net investment (HT
*       11):
GLOBALINV ..

    RORDELTA
    * (globalcgds0 * globalcgds
    - sum(r, (qcgds0(r) * qcgds(r) - DEPR(r) * kb0(r) * kb(r))))
    + (1 - RORDELTA)
    * (prod(r, rore(r)**(sh_netinv_globinv0(r) * sh_netinv_globinv(r))) - rorg)
    =e= 0;

*       Share of net investment:
E_SH_NETINV_GLOBINV(r) ..

    sh_netinv_globinv0(r) * sh_netinv_globinv(r) =e=
    0.5 * sh_netinv_globinv0(r)
    +
    0.5 * (pcgds0(r) * pcgds(r)
	* (qcgds0(r) * qcgds(r) - DEPR(r) * kb0(r) * kb(r))
        / (pcgdswld0 * pcgdswld * globalcgds0 * globalcgds)
    ) ;

*       Eq'n generates a price index for the aggregate global cgds composite
*       (HT 60):
PRICGDS ..

    pcgdswld - prod(r, pcgds(r)**(sh_netinv_globinv0(r) * sh_netinv_globinv(r))) =e= 0;

*       Savings price:
SAVEPRICE(r) ..

    psave(r) - pcgds(r) * psave_adj - psaveslack(r) =e= 0;

*       Adjustment factor for psave
E_PSAVE_ADJ ..

    psave_adj - prod(r, pcgds(r)**(sh_netinv_save_globinv0(r) * sh_netinv_save_globinv(r))) =e= 0;

*       Share of excess investment:
E_SH_NETINV_SAVE_GLOBINV(r) ..

    sh_netinv_save_globinv0(r) * sh_netinv_save_globinv(r) =e=
    0.5 * sh_netinv_save_globinv0(r)
    +
    0.5 * ((pcgds0(r) * pcgds(r)
    * (qcgds0(r) * qcgds(r) - DEPR(r) * kb0(r) * kb(r))
    - psave0(r) * psave(r) * qsave0(r) * qsave(r))
    / (pcgdswld0 * pcgdswld * globalcgds0 * globalcgds)
    );

*       Eq'n links agent's and world prices (HT 27):
EXPRICES(t,r,s)$qxs0(t,r,s) ..

    pfob0(t,r,s) * pfob(t,r,s) =e=
    pm0(t,r) * pm(t,r) / (tx(t,r) * txs(t,r,s));

*       Export tax payments:
TEXPRATIO(r) ..

    del_taxrexp(r) =e=
    sum(t, sum(s$qxs0(t,r,s),
        (1 - tx(t,r) * txs(t,r,s)) * pfob0(t,r,s) * pfob(t,r,s)
        * qxs0(t,r,s) * qxs(t,r,s)));

*       Eq'n links domestic and world prices (HT 24):
MKTPRICES(t,r,s)$qxs0(t,r,s) ..

    pms0(t,r,s) * pms(t,r,s) =e=
    tm(t,s) * tms(t,r,s) * pcif0(t,r,s) * pcif(t,r,s);

*       Price for aggregate imports (HT 28):
DPRICEIMP(t,s)$qim0(t,s) ..

    pim(t,s) =e=
    (sum(r$MSHRS(t,r,s),
        MSHRS(t,r,s) * (pms(t,r,s)/ams(t,r,s))**(1-ESUBM(t)))
    )**(1/(1-ESUBM(t)));

*       Eq'n defines target price ratio to be attained via the variable levy
*       (HT 25):
PRICETGT(t,s)$qim0(t,s) ..

    pr0(t,s) * pr(t,s) =e= pm0(t,s) * pm(t,s) / (pim0(t,s) * pim(t,s));

*       Regional demand for disaggregated imported commodities by source (HT
*       29):
IMPORTDEMAND(t,r,s)$qxs0(t,r,s) ..

    qxs(t,r,s) =e= (1/ams(t,r,s)) * qim(t,s)
    * (pim(t,s) / (pms(t,r,s)/ams(t,r,s)))**(ESUBM(t));

*       Import tax payments:
TIMPRATIO(r) ..

    del_taxrimp(r) =e=
    sum(t, sum(s$qxs0(t,s,r),
        (tm(t,r) * tms(t,s,r) - 1)
        * pcif0(t,s,r) * pcif(t,s,r) * qxs0(t,s,r) * qxs(t,s,r)));

*       Bilateral demand for transport services:
QTRANS_MFSD(m,t,r,s)$qtmfsd0(m,t,r,s) ..

    qtmfsd(m,t,r,s) =e= qxs(t,r,s) / atmfsd(m,t,r,s);

*       Global demand for margin m:
TRANS_DEMAND(m) ..

    qtm0(m) * qtm(m) =e=
    sum(t, sum((s,r)$VTMUSESHR(m,t,r,s), qtmfsd0(m,t,r,s) * qtmfsd(m,t,r,s)));

*       Generate price index for composite transportation services:
PTRANSPORT(m) ..

    pt(m) =e= prod(r$VTSUPPSHR(m,r), pm(m,r)**(VTSUPPSHR(m,r)));

*       Generates flow-specific modal average cost of transport index
*       (cf. HT7):
TRANSCOSTINDEX(t,r,s)$VTFSD(t,r,s) ..

    ptrans(t,r,s) =e= sum(m$VTMFSD(m,t,r,s), pt(m)/atmfsd(m,t,r,s));

*       Generates flow-specific average rate of technical change:
TRANSTECHANGE(m,t,r,s)$VTMFSD(m,t,r,s) ..

    atmfsd(m,t,r,s) =e= atm(m) * atf(t) * ats(r) * atd(s) * atall(m,t,r,s);

*       Generate demand for regional supply of global transportation service
*       (HT 61):
TRANSVCES(m,r)$qst0(m,r) ..

    qst(m,r) =e= qtm(m) * (pt(m)/pm(m,r));

*       "Eq'n links FOB and CIF prices for good i shipped from region r to s
*       (HT 26'):"
FOBCIF(t,r,s)$qxs0(t,r,s) ..

    pcif(t,r,s) =e=
    (FOBSHR(t,r,s) * pfob(t,r,s)
        + ((1 - FOBSHR(t,r,s)) * ptrans(t,r,s))$VTFSD(t,r,s)
    );

* FACTORINCPRICES(e,r) ..

*     ps(e,r) =e= to(e,r) * pm(e,r);

*       Income tax payments:
TINCRATIO(r) ..

    del_taxrinc(r) =e=
    sum(e$qo0(e,r),
        (1 - to(e,r)) * pm0(e,r) * pm(e,r) * qo0(e,r) * qo(e,r));

*       Eq'n generates the composite price for sluggish endowments (HT 50):
ENDW_PRICE(es,r)$qo0(es,r) ..

    pm(es,r) =e= (sum(j$REVSHR(es,j,r),
        REVSHR(es,j,r) * pmes(es,j,r)**(1-ETRAE(es)))
    )**(1/(1-ETRAE(es)));

*       Eq'n distributes the sluggish endowments across sectors (HT 51):
ENDW_SUPPLY(es,j,r)$qoes0(es,j,r) ..

    qoes(es,j,r) =e= qo(es,r)
    * (pm(es,r) / pmes(es,j,r))**(ETRAE(es))
    - endwslack(es,r);

*       Factor income at market prices net of depreciation:
FACTORINCOME(r) ..

    fincome0(r) * fincome(r) =e=
    sum(e$qo0(e,r), pm0(e,r) * pm(e,r) * qo0(e,r) * qo(e,r))
    - DEPR(r) * pcgds0(r) * pcgds(r) * kb0(r) * kb(r);

*       Indirect taxes:
DINDTAXRATIO(r) ..

    del_indtaxr(r) =e=
    del_taxrpc(r) + del_taxrgc(r) + del_taxriu(r) + del_taxrfu(r)
    + del_taxrout(r) + del_taxrexp(r) + del_taxrimp(r);

*       All taxes:
DTAXRATIO(r) ..

    del_ttaxr(r) =e=
    del_taxrpc(r) + del_taxrgc(r) + del_taxriu(r) + del_taxrfu(r)
    + del_taxrout(r) + del_taxrexp(r) + del_taxrimp(r) + del_taxrinc(r);

*       Regional income = sum of primary factor income and indirect tax
*       receipts:
REGIONALINCOME(r) ..

    y0(r) * y(r) =e=
    fincome0(r) * fincome(r) + del_indtaxr(r) + incomeslack(r);
;
*       Elasticity of cost of utility wrt utility:
UTILITELASTIC(r) ..

    uelas0(r) * uelas(r) =e=
    1 / (dppriv0(r) * dppriv(r) / (uepriv0(r) * uepriv(r))
        + dpgov0(r) * dpgov(r) + dpsave0(r) * dpsave(r));

*       Private consumption expenditure:
PRIVCONSEXP(r) ..

    yp0(r) * yp(r) =e=
    y0(r) * y(r)
    * (uelas0(r)*uelas(r)/(uepriv0(r)*uepriv(r)))
    * dppriv0(r) * dppriv(r);

*       Government consumption expenditure:
GOVCONSEXP(r) ..

    yg0(r) * yg(r) =e=
    y0(r) * y(r) * uelas0(r) * uelas(r) * dpgov0(r) * dpgov(r);

*       Saving:
SAVING(r) ..

    psave0(r) * psave(r) * qsave0(r) * qsave(r)
    =e= y0(r) * y(r) * uelas0(r) * uelas(r) * dpsave0(r) * dpsave(r);

*       Regional household utility:
UTILITY(r) ..

    u(r) =e= au(r)
    * up(r)**(dppriv0(r) * dppriv(r))
    * ug(r)**(dpgov0(r) * dpgov(r))
    * qsave(r)**(dpsave0(r) * dpsave(r));

*       Eq'n assures market clearing for domestic sales (HT 3):
MKTCLDOM(t,r)$VDM(t,r) ..

    qds0(t,r) * qds(t,r) =e= sum(j$qfd0(t,j,r), qfd0(t,j,r) * qfd(t,j,r))
    + (qpd0(t,r)*qpd(t,r))$qpd0(t,r) + (qgd0(t,r)*qgd(t,r))$(qgd0(t,r));

*       Eq'n assures market clearing for margins commodities (HT 1):
MKTCLTRD_MARG(m,r)$qo0(m,r) ..

    qo0(m,r) * qo(m,r) =e=
    (qds0(m,r)*qds(m,r))$VDM(m,r)
    + (qst0(m,r)*qst(m,r))$qst0(m,r)
    + sum(s$qxs0(m,r,s), qxs0(m,r,s) * qxs(m,r,s))
    + tradslack(m,r);

*       Eq'n assures market clearing for the non-margins
MKTCLTRD_NMRG(i,r)$(nm(i) and qo0(i,r)) ..

    qo0(i,r) * qo(i,r) =e= (qds(i,r)*qds(i,r))$VDM(i,r)
    + sum(s$qxs0(i,r,s), qxs0(i,r,s) * qxs(i,r,s)) + tradslack(i,r);

*       Eq'n assures mkt clearing for imported goods entering each region
*       (HT 2):
MKTCLIMP(t,r)$qim0(t,r) ..

    qim0(t,r) * qim(t,r) =e= sum(j$qfm0(t,j,r), qfm0(t,j,r) * qfm(t,j,r))
    + (qpm0(t,r)*qpm(t,r))$qpm0(t,r) + (qgm0(t,r)*qgm(t,r))$qgm0(t,r);

*       Eq'n assures mkt clearing for perfectly mobile endowments in each r
*       (HT 4):
MKTCLENDWM(em,r)$qo0(em,r) ..

    qo0(em,r) * qo(em,r) =e= sum(j$qfe0(em,j,r), qfe0(em,j,r) * qfe(em,j,r))
    + endwslack(em,r);

*       Eq'n assures mkt clearing for imperfectly mobile endowments in each
*       r (HT 5):
MKTCLENDWS(es,j,r)$qoes0(es,j,r) ..

    qoes0(es,j,r) * qoes(es,j,r) =e= qfe0(es,j,r) * qfe(es,j,r);

*       Extra eq'n computes change in supply in the omitted market.:
WALRAS_S ..

    walras_sup0 * walras_sup =e=
    pcgdswld0 * pcgdswld * globalcgds0 * globalcgds;

*       Extra eq'n computes change in demand in the omitted market.:
WALRAS_D ..

    walras_dem0 * walras_dem
    =e= sum(r, psave0(r) * psave(r) * qsave0(r) * qsave(r));

*       Check Walras' Law.  Value of "walraslack" should be zero. (HT 14):
WALRAS ..

    walras_sup0 * walras_sup =e= walras_dem0 * walras_dem + walraslack;

*       Price of endowment commodities (pfe):
E_PFE(e,j,r)$VFM(e,j,r) ..

    (pfe0(e,j,r) * pfe(e,j,r)
        - tf(e,j,r) * pm0(e,r) * pm(e,r))$em(e)
    +
    (pfe0(e,j,r) * pfe(e,j,r)
        - tf(e,j,r) * pmes0(e,j,r) * pmes(e,j,r))$es(e)
    =e= 0;

*       Market clearing condition (pm)
E_PM(g,r)$(ns(g) and qo0(g,r)) ..

    (qo0(g,r) * qo(g,r) - (qds0(g,r)*qds(g,r))$VDM(g,r)
        - (qst0(g,r)*qst(g,r))$qst0(g,r)
	- sum(s$qxs0(g,r,s), qxs0(g,r,s) * qxs(g,r,s))
        - tradslack(g,r)
    )$m(g)
    +
    (qo0(g,r) * qo(g,r) - (qds0(g,r)*qds(g,r))$VDM(g,r)
        - sum(s$qxs0(g,r,s), qxs0(g,r,s) * qxs(g,r,s))
	- tradslack(g,r)
    )$nm(g)
    +
    (qo0(g,r) * qo(g,r)
	- sum(j$qfe0(g,j,r), qfe0(g,j,r) * qfe(g,j,r))
	- endwslack(g,r)
    )$em(g)
    +
    (pm(g,r) -
        (sum(j$REVSHR(g,j,r),
            REVSHR(g,j,r) * pmes(g,j,r)**(1-ETRAE(g)))
        )**(1/(1-ETRAE(g)))
    )$es(g)
    +
    (sum(c, qo(c,r)) - qcgds(r))$c(g)

    =e= 0;

*       Supply price
E_PS(ns,r)$qo0(ns,r) ..

    ps0(ns,r) * ps(ns,r) =e= to(ns,r) * pm0(ns,r) * pm(ns,r);

*       Dummy objective function
E_DUMMY_OBJECTIVE ..

    dummy_objective =e= 1;

*	----------------------------------------------------------------------
*	Equation definition in Appendix:
display "com: Equation definition in Appendix:";

* REALRETURN(e,s) ..

*     pfactreal(e,s) =e= pm(e,s) / ppriv(s);

*       "Computes % change in price index of primary factors, by region"
PRIMFACTPR(r) ..

    pfactor(r) - prod(e$VOM(e,r), pm(e,r)**(sh_vom_vendwreg0(e,r) * sh_vom_vendwreg(e,r)))
    =e= 0;

*       Share of endowment commodities in region r:
E_SH_VOM_VENDWREG(e,r)$VOM(e,r) ..

    sh_vom_vendwreg0(e,r) * sh_vom_vendwreg(e,r) =e=
    0.5 * sh_vom_vendwreg0(e,r)
    +
    0.5 * (pm0(e,r) * pm(e,r) * qo0(e,r) * qo(e,r)
    / sum(ee$qo0(ee,r), pm0(ee,r) * pm(ee,r) * qo0(ee,r) * qo(ee,r))
    );

*       "Computes % change in global price index of primary factors"
PRIMFACTPRWLD ..

    pfactwld
    - prod(r, pfactor(r)**(sh_vendwreg_vendwwld0(r) * sh_vendwreg_vendwwld(r)))
    =e= 0
;

*       Share of endowment commodities in the world:
E_SH_VENDWREG_VENDWWLD(r) ..

    sh_vendwreg_vendwwld0(r) * sh_vendwreg_vendwwld(r) =e=
    0.5 * sh_vendwreg_vendwwld0(r)
    +
    0.5 * (sum(e$qo0(e,r), pm0(e,r) * pm(e,r) * qo0(e,r) * qo(e,r))
    / sum((rr,ee)$qo0(ee,rr),
	pm0(ee,rr) * pm(ee,r) * qo0(ee,rr) * qo(ee,r))
    );

REGSUPRICE(r) ..

    psw(r) =e=
    prod((t,s)$VXWD(t,r,s),
	pfob(t,r,s)**(sh_vxwd_vxwregion0(t,r,s) * sh_vxwd_vxwregion(t,r,s))
    )
    * prod(m$VST(m,r),
	pm(m,r)**(sh_vst_vxwregion0(m,r) * sh_vst_vxwregion(m,r))
    )
    ;

E_V_VXWREGION(r) ..

    v_vxwregion0(r) * v_vxwregion(r) =e=
    sum((t,s)$qxs0(t,r,s), pfob0(t,r,s) * pfob(t,r,s) * qxs0(t,r,s) * qxs(t,r,s))
    + sum(m$qst0(m,r), pm0(m,r) * pm(m,r) * qst0(m,r) * qst(m,r));

E_SH_VXWD_VXWREGION(t,r,s)$qxs0(t,r,s) ..

    sh_vxwd_vxwregion0(t,r,s) * sh_vxwd_vxwregion(t,r,s)
    =e= 0.5 * sh_vxwd_vxwregion0(t,r,s)
    +
    0.5 * ( pfob0(t,r,s) * pfob(t,r,s) * qxs0(t,r,s) * qxs(t,r,s)
	/ (v_vxwregion0(r) * v_vxwregion(r)) );

E_SH_VST_VXWREGION(m,r)$qst0(m,r) ..

    sh_vst_vxwregion0(m,r) * sh_vst_vxwregion(m,r)
    =e= 0.5 * sh_vst_vxwregion0(m,r)
    +
    0.5 * ( pm0(m,r) * pm(m,r) * qst0(m,r) * qst(m,r)
	/ (v_vxwregion0(r) * v_vxwregion(r)) );

REGDEMPRICE(r) ..

    pdw(r) =e= prod((t,s)$qxs0(t,s,r),
	pcif(t,s,r)**(sh_viws_viwregion0(t,s,r) * sh_viws_viwregion(t,s,r)))
    ;

E_V_VIWREGION(r) ..

    v_viwregion0(r) * v_viwregion(r) =e=
    sum((t,s)$qxs0(t,s,r), pcif0(t,s,r) * pcif(t,s,r) * qxs0(t,s,r) * qxs(t,s,r));

E_SH_VIWS_VIWREGION(t,s,r)$qxs0(t,s,r) ..

    sh_viws_viwregion0(t,s,r) * sh_viws_viwregion(t,s,r)
    =e=
    0.5 * sh_viws_viwregion0(t,s,r)
    +
    0.5 * ( pcif0(t,s,r) * pcif(t,s,r) * qxs0(t,s,r) * qxs(t,s,r)
	/ (v_viwregion0(r) * v_viwregion(r)) );

TOTeq(r) ..

    tot(r) =e= psw(r) / pdw(r);

VGDP_r(r) ..

    vgdp0(r) * vgdp(r)
    =e=
    sum(t$VGA(t,r), pg0(t,r) * pg(t,r) * qg0(t,r) * qg(t,r))
    + sum(t$VPA(t,r), pp0(t,r) * pp(t,r) * qp0(t,r) * qp(t,r))
    + pcgds0(r) * pcgds(r) * qcgds0(r) * qcgds(r)
    + sum((t,s)$VXWD(t,r,s),
	pfob0(t,r,s) * pfob(t,r,s) * qxs0(t,r,s) * qxs(t,r,s))
    + sum(m$VST(m,r), pm0(m,r) * pm(m,r) * qst0(m,r) * qst(m,r))
    - sum((t,s)$VIWS(t,s,r),
	pcif0(t,s,r) * pcif(t,s,r) * qxs0(t,s,r) * qxs(t,s,r));

PGDP_r(r) ..

    pgdp0(r) * pgdp(r)
    =e=
    prod(t$sh_vga_gdp0(t,r), pg(t,r)**(sh_vga_gdp0(t,r) * sh_vga_gdp(t,r)))
    * prod(t$sh_vpa_gdp0(t,r), pp(t,r)**(sh_vpa_gdp0(t,r) * sh_vpa_gdp(t,r)))
    * (pcgds(r))**(sh_reginv_gdp0(r) * sh_reginv_gdp(r))
    * prod((t,s)$sh_vxwd_gdp0(t,r,s), pfob(t,r,s)**(sh_vxwd_gdp0(t,r,s) * sh_vxwd_gdp(t,r,s)))
    * prod(m$sh_vst_gdp0(m,r), pm(m,r)**(sh_vst_gdp0(m,r) * sh_vst_gdp(m,r)))
    * prod((t,s)$sh_viws_gdp0(t,s,r), pcif(t,s,r)**(- sh_viws_gdp0(t,s,r) * sh_viws_gdp(t,s,r)))
    ;

E_SH_VGA_GDP(t,r)$VGA(t,r) ..

    sh_vga_gdp0(t,r) * sh_vga_gdp(t,r)
    =e=
    0.5 * sh_vga_gdp0(t,r)
    +
    0.5 * ( pg0(t,r) * pg(t,r) * qg0(t,r) * qg(t,r) / (vgdp0(r) * vgdp(r)) );

E_SH_VPA_GDP(t,r)$VPA(t,r) ..

    sh_vpa_gdp0(t,r) * sh_vpa_gdp(t,r)
    =e=
    0.5 * sh_vpa_gdp0(t,r)
    +
    0.5 * ( pp0(t,r) * pp(t,r) * qp0(t,r) * qp(t,r) / (vgdp0(r) * vgdp(r)) );

E_SH_REGINV_GDP(r) ..

    sh_reginv_gdp0(r) * sh_reginv_gdp(r)
    =e=
    0.5 * sh_reginv_gdp0(r)
    +
    0.5 * ( pcgds0(r) * pcgds(r) * qcgds0(r) * qcgds(r) / (vgdp0(r) * vgdp(r)) );

E_SH_VXWD_GDP(t,r,s)$VXWD(t,r,s) ..

    sh_vxwd_gdp0(t,r,s) * sh_vxwd_gdp(t,r,s)
    =e=
    0.5 * sh_vxwd_gdp0(t,r,s)
    +
    0.5 * ( pfob0(t,r,s) * pfob(t,r,s) * qxs0(t,r,s) * qxs(t,r,s) / (vgdp0(r) * vgdp(r)) );

E_SH_VST_GDP(m,r)$VST(m,r) ..

    sh_vst_gdp0(m,r) * sh_vst_gdp(m,r)
    =e=
    0.5 * sh_vst_gdp0(m,r)
    +
    0.5 * ( pm0(m,r) * pm(m,r) * qst0(m,r) * qst(m,r)  / (vgdp0(r) * vgdp(r)) );

E_SH_VIWS_GDP(t,r,s)$VIWS(t,r,s) ..

    sh_viws_gdp0(t,r,s) * sh_viws_gdp(t,r,s)
    =e=
    0.5 * sh_viws_gdp0(t,r,s)
    +
    0.5 * ( pcif0(t,r,s) * pcif(t,r,s) * qxs0(t,r,s) * qxs(t,r,s) / (vgdp0(s) * vgdp(s)) );

QGDP_r(r) ..

    qgdp0(r) * qgdp(r) =e= vgdp0(r) * vgdp(r) / (pgdp0(r) * pgdp(r));

COMPVALADEQ(i,r)$qo0(i,r) ..

    compvalad(i,r) =e= qo(i,r) / qgdp(r);

VREGEX_ir(i,r)$vxwfob0(i,r) ..

    vxwfob0(i,r) * vxwfob(i,r) =e=
    sum(s$qxs0(i,r,s), pfob0(i,r,s) * pfob(i,r,s) * qxs0(i,r,s) * qxs(i,r,s))
    + (pm0(i,r) * pm(i,r) * qst0(i,r) * qst(i,r))$(m(i) and qst0(i,r))
    ;

VREGEX_r(r) ..

    vxwreg0(r) * vxwreg(r) =e=
    sum(t$vxwfob0(t,r), vxwfob0(t,r) * vxwfob(t,r));

VREGIM_is(t,s)$viwcif0(t,s) ..

    viwcif0(t,s) * viwcif(t,s) =e=
    sum(r$qxs0(t,r,s), pcif0(t,r,s) * pcif(t,r,s) * qxs0(t,r,s) * qxs(t,r,s));

VREGIM_s(s) ..

    viwreg0(s) * viwreg(s) =e=
    sum(t$viwcif0(t,s), viwcif0(t,s) * viwcif(t,s));
;

QREGEX_ir(t,r)$VXW(t,r) ..

    qxw(t,r)
    =e=
    (prod(s$VXWD(t,r,s), qxs(t,r,s)**(sh_vxwd_vxw0(t,r,s)*sh_vxwd_vxw(t,r,s)))
    * qst(t,r)**(sh_vst_vxw0(t,r)*sh_vst_vxw(t,r))
    )$m(t)
    +
    (prod(s$VXWD(t,r,s), qxs(t,r,s)**(sh_vxwd_vxw0(t,r,s)*sh_vxwd_vxw(t,r,s)))
    )$(not m(t))
    ;

E_V_VXW(t,r)$VXW(t,r) ..

    v_vxw0(t,r) * v_vxw(t,r) =e=
    sum(s$qxs0(t,r,s),
    pfob0(t,r,s) * pfob(t,r,s) * qxs0(t,r,s) * qxs(t,r,s))
    + (pm0(t,r) * pm(t,r) * qst0(t,r) * qst(t,r))$(m(t) and qst0(t,r))
    ;

E_SH_VXWD_VXW(t,r,s)$VXWD(t,r,s) ..

    sh_vxwd_vxw0(t,r,s) * sh_vxwd_vxw(t,r,s)
    =e=
    0.5 * sh_vxwd_vxw0(t,r,s)
    + 0.5 *
    ( pfob0(t,r,s) * pfob(t,r,s) * qxs0(t,r,s) * qxs(t,r,s)
    / (v_vxw0(t,r) * v_vxw(t,r)) );

E_SH_VST_VXW(t,r)$(m(t) and VST(t,r)) ..

    sh_vst_vxw0(t,r) * sh_vst_vxw(t,r)
    =e=
    0.5 * sh_vst_vxw0(t,r)
    + 0.5 *
    ( pm0(t,r) * pm(t,r) * qst0(t,r) * qst(t,r)
    / (v_vxw0(t,r) * v_vxw(t,r)) );

TRADEBAL_i(t,r)$DTBALi0(t,r) ..

    DTBALi0(t,r) * DTBALi(t,r) =e=
    vxwfob0(t,r) * vxwfob(t,r) - viwcif0(t,r) * viwcif(t,r);

TRADEBALANCE(r) ..

    DTBAL0(r) * DTBAL(r) =e=
    vxwreg0(r) * vxwreg(r) - viwreg0(r) * viwreg(r);

DTBALRATIO(r) ..

    DTBALR(r) =e= DTBAL(r) / y(r);

*	----------------------------------------------------------------------
*	EV calculation in Appendix:

$ontext
In equations defined below, all price variables are set to their initial values
(normally unity).  For example, equation GOVU_EV(r) is derived by setting
pgov(r) to unity in the original equation GOVU(r).

GOVU(r) ..

    yg0(r) * yg(r) =e=
    pgov0(r) * pgov(r) * ug0(r) * ug(r) * pop0(r) * pop(r);

$offtext

GOVU_EV(r) ..

    yg0(r) * yg_ev(r)
    =e= pgov0(r) * ug0(r) * ug_ev(r) * pop0(r) * pop(r);

GOVDMNDS_EV(t,r)$qg0(t,r) ..

    qg_ev(t,r) =e= pop(r) * ug_ev(r);

PRIVATEU_EV(r) ..

    sum(t$qp0(t,r),
	SH_BP(t,r) * (up0(r)*up_ev(r))**(SUBPAR(t,r)*INCPAR(t,r))
	* (pp0(t,r)/(yp0(r)*yp_ev(r)/(pop0(r)*pop(r))))**(SUBPAR(t,r)))
    =e= 1;

UTILELASPRIV_EV(r) ..

    uepriv0(r) * uepriv_ev(r) =e=
    sum(t$CONSHR(t,r), vconshr0(t,r) * vconshr_ev(t,r) * INCPAR(t,r));


E_VCONSHR_EV(t,r)$CONSHR(t,r) ..

    vconshr0(t,r) * vconshr_ev(t,r) =e=
    pp0(t,r) * qp0(t,r) * qp_ev(t,r) / (yp0(r)*yp_ev(r));

PRIVDMNDS_EV(t,r)$VPA(t,r) ..

    (qp0(t,r)*qp_ev(t,r)/(pop0(r)*pop(r)))
    =e= (SH_BP(t,r) * (up0(r)*up_ev(r))**(SUBPAR(t,r) * INCPAR(t,r))
	* SUBPAR(t,r)
	* (pp0(t,r)/(yp0(r)*yp_ev(r)/(pop0(r)*pop(r))))**(SUBPAR(t,r) - 1)
    ) /
    (sum(tt, SH_BP(tt,r) * (up0(r)*up_ev(r))**(SUBPAR(tt,r) * INCPAR(tt,r))
	* SUBPAR(tt,r)
	* (pp0(tt,r)/(yp0(r)*yp_ev(r)/(pop0(r)*pop(r))))**(SUBPAR(tt,r))));

UTILITELASTIC_EV(r) ..

    uelas0(r) * uelas_ev(r) =e=
    1 / (dppriv0(r) * dppriv(r) / (uepriv0(r) * uepriv_ev(r))
	+ dpgov0(r) * dpgov(r) + dpsave0(r) * dpsave(r));

PRIVCONSEXP_EV(r) ..

    yp0(r) * yp_ev(r) =e=
    y0(r) * y_ev(r)
    * (uelas0(r)*uelas_ev(r)/(uepriv0(r)*uepriv_ev(r)))
    * dppriv0(r) * dppriv(r);

GOVCONSEXP_EV(r) ..

    yg0(r) * yg_ev(r)
    =e= y0(r) * y_ev(r) * uelas0(r) * uelas_ev(r) * dpgov0(r) * dpgov(r);

SAVING_EV(r) ..

    psave0(r) * qsave0(r) * qsave_ev(r)
    =e= y0(r) * y_ev(r) * uelas0(r) * uelas_ev(r) * dpsave0(r) * dpsave(r);

UTILITY_EV(r) ..

    au(r) * up_ev(r)**(dppriv0(r) * dppriv(r))
    * ug_ev(r)**(dpgov0(r) * dpgov(r))
    * qsave_ev(r)**(dpsave0(r) * dpsave(r))
    =e= u(r);

E_EV(r) ..

    EV(r) =e= (1/scale_factor) * (y0(r) * y_ev(r) - y0(r));

*       ----------------------------------------------------------------------
*       Model declaration:
display "com: -- Model declaration:";

model gtap_mcp GTAP standard model in MCP format

      / GPRICEINDEX.pgov, GOVDMNDS.qg, GOVU.ug, GHHDPRICE.pgd,
        GHHIPRICES.pgm, GCOMPRICE.pg, GHHLDAGRIMP.qgm, GHHLDDOM.qgd,
        TGCRATIO.del_taxrgc, PRIVATEU.up, UTILELASPRIV.uepriv,
        E_VCONSHR.vconshr, PRIVDMNDS.qp, TPDSHIFT.atpd, PHHDPRICE.ppd,
        TPMSHIFT.atpm, PHHIPRICES.ppm, TPCRATIO.del_taxrpc, PCOMPRICE.pp,

        PHHLDDOM.qpd, PHHLDAGRIMP.qpm, AOWORLD.ao, AVAWORLD.ava,
        VADEMAND.qva, AFWORLD.af, INTDEMAND.qf, DMNDDPRICE.pfd,
        DMNDIPRICES.pfm, TIURATIO.del_taxriu, ICOMPRICE.pf, INDIMP.qfm,
        INDDOM.qfd,

        AFEWORLD.afe, VAPRICE.pva, TFURATIO.del_taxrfu, ENDWDEMAND.qfe,
        TOUTRATIO.del_taxrout, ZEROPROFITS.qo, KAPSVCES.ksvces,
        KAPRENTAL.rental, PRCGOODS.pcgds, KBEGINNING.kb, KEND.ke,
        RORCURRENT.rorc, ROREXPECTED.rore, BALDWIN.expand,

        PRICGDS.pfactwld, SAVEPRICE.psave, E_PSAVE_ADJ.psave_adj,
        EXPRICES.pfob, TEXPRATIO.del_taxrexp, MKTPRICES.pms, DPRICEIMP.pim,
        PRICETGT.pr, IMPORTDEMAND.qxs, TIMPRATIO.del_taxrimp,
        QTRANS_MFSD.qtmfsd, TRANS_DEMAND.qtm, PTRANSPORT.pt,
        TRANSCOSTINDEX.ptrans, TRANSTECHANGE.atmfsd, TRANSVCES.qst,
        FOBCIF.pcif, TINCRATIO.del_taxrinc,

        ENDW_SUPPLY.qoes, FACTORINCOME.fincome, DINDTAXRATIO.del_indtaxr,
        DTAXRATIO.del_ttaxr, REGIONALINCOME.y, UTILITELASTIC.uelas,
        PRIVCONSEXP.yp, GOVCONSEXP.yg, SAVING.qsave, UTILITY.u, MKTCLDOM.qds,

        WALRAS_S.walras_sup, WALRAS_D.walras_dem, WALRAS.rorg, MKTCLIMP.qim,
        MKTCLENDWS.pmes,

        E_PM.pm, E_PFE.pfe, E_PS.ps, RORGLOBAL.qcgds, GLOBALINV.globalcgds,

        E_SH_NETINV_GLOBINV.sh_netinv_globinv,
        E_SH_NETINV_SAVE_GLOBINV.sh_netinv_save_globinv,

*	Equations for Appendices
	PRIMFACTPR.pfactor, E_SH_VOM_VENDWREG.sh_vom_vendwreg,
	PRIMFACTPRWLD.pcgdswld, E_SH_VENDWREG_VENDWWLD.sh_vendwreg_vendwwld,
	REGSUPRICE.psw, E_V_VXWREGION.v_vxwregion,

	E_SH_VXWD_VXWREGION.sh_vxwd_vxwregion,
	E_SH_VST_VXWREGION.sh_vst_vxwregion, REGDEMPRICE.pdw,
	E_V_VIWREGION.v_viwregion, E_SH_VIWS_VIWREGION.sh_viws_viwregion,
	TOTeq.tot, VGDP_r.vgdp, PGDP_r.pgdp, E_SH_VGA_GDP.sh_vga_gdp,
	E_SH_VPA_GDP.sh_vpa_gdp, E_SH_REGINV_GDP.sh_reginv_gdp,
	E_SH_VXWD_GDP.sh_vxwd_gdp, E_SH_VST_GDP.sh_vst_gdp,
	E_SH_VIWS_GDP.sh_viws_gdp, QGDP_r.qgdp, COMPVALADEQ.compvalad,
	VREGEX_ir.vxwfob, VREGEX_r.vxwreg, VREGIM_is.viwcif, QREGEX_ir.qxw,
	E_V_VXW.v_vxw, E_SH_VXWD_VXW.sh_vxwd_vxw, E_SH_VST_VXW.sh_vst_vxw,
	VREGIM_s.viwreg, TRADEBAL_i.DTBALi, TRADEBALANCE.DTBAL,
	DTBALRATIO.DTBALR,

*	EV calculation
	GOVU_EV.ug_ev, GOVDMNDS_EV.qg_ev, PRIVATEU_EV.up_ev,
	UTILELASPRIV_EV.uepriv_ev, E_VCONSHR_EV.vconshr_ev,
	PRIVDMNDS_EV.qp_ev, UTILITELASTIC_EV.uelas_ev, PRIVCONSEXP_EV.yp_ev,
	GOVCONSEXP_EV.yg_ev, SAVING_EV.qsave_ev, UTILITY_EV.y_ev, E_EV.EV

        /;

model gtap_nlp GTAP standard model in NLP format

      / GPRICEINDEX, GOVDMNDS, GOVU, GHHDPRICE,
        GHHIPRICES, GCOMPRICE, GHHLDAGRIMP, GHHLDDOM,
        TGCRATIO, PRIVATEU, UTILELASPRIV,
        E_VCONSHR, PRIVDMNDS, TPDSHIFT, PHHDPRICE,
        TPMSHIFT, PHHIPRICES, TPCRATIO, PCOMPRICE,

        PHHLDDOM, PHHLDAGRIMP, AOWORLD, AVAWORLD,
        VADEMAND, AFWORLD, INTDEMAND, DMNDDPRICE,
        DMNDIPRICES, TIURATIO, ICOMPRICE, INDIMP,
        INDDOM,

        AFEWORLD, VAPRICE, TFURATIO, ENDWDEMAND,
        TOUTRATIO, ZEROPROFITS, KAPSVCES,
        KAPRENTAL, PRCGOODS, KBEGINNING, KEND,
        RORCURRENT, ROREXPECTED, BALDWIN,

        PRICGDS, SAVEPRICE, E_PSAVE_ADJ,
        EXPRICES, TEXPRATIO, MKTPRICES, DPRICEIMP,
        PRICETGT, IMPORTDEMAND, TIMPRATIO,
        QTRANS_MFSD, TRANS_DEMAND, PTRANSPORT,
        TRANSCOSTINDEX, TRANSTECHANGE, TRANSVCES,
        FOBCIF, TINCRATIO,

        ENDW_SUPPLY, FACTORINCOME, DINDTAXRATIO,
        DTAXRATIO, REGIONALINCOME, UTILITELASTIC,
        PRIVCONSEXP, GOVCONSEXP, SAVING, UTILITY, MKTCLDOM,

        WALRAS_S, WALRAS_D, WALRAS, MKTCLIMP,
        MKTCLENDWS,

        E_PM, E_PFE, E_PS, RORGLOBAL, GLOBALINV,

        E_SH_NETINV_GLOBINV, E_SH_NETINV_SAVE_GLOBINV,

*	Equations for Appendices
	PRIMFACTPR, E_SH_VOM_VENDWREG,
	PRIMFACTPRWLD, E_SH_VENDWREG_VENDWWLD,
	REGSUPRICE, E_V_VXWREGION,

	E_SH_VXWD_VXWREGION, E_SH_VST_VXWREGION,
	REGDEMPRICE, E_V_VIWREGION,
	E_SH_VIWS_VIWREGION, TOTeq, VGDP_r, PGDP_r,
	E_SH_VGA_GDP, E_SH_VPA_GDP,
	E_SH_REGINV_GDP, E_SH_VXWD_GDP,
	E_SH_VST_GDP, E_SH_VIWS_GDP, QGDP_r,
	COMPVALADEQ, VREGEX_ir, VREGEX_r, VREGIM_is,
	VREGIM_s, TRADEBAL_i, TRADEBALANCE, DTBALRATIO,

*	EV calculation
	GOVU_EV, GOVDMNDS_EV, PRIVATEU_EV, UTILELASPRIV_EV,
	E_VCONSHR_EV, PRIVDMNDS_EV, UTILITELASTIC_EV,
	PRIVCONSEXP_EV, GOVCONSEXP_EV, SAVING_EV, UTILITY_EV,
	E_EV,

        E_DUMMY_OBJECTIVE

        /;

option nlp = %nlp_solver%;
option mcp = %mcp_solver%;

*	----------------------------------------------------------------------
*	Model for parameter calibaration:
display "com: Model for parameter calibaration:";

*	----------------------------------------------------------------------
*	Model for calibration of distribution parameters in CDE private utility
*	function:
display "com: -- Model for calibration of distribution parameters in CDE private utility function:";

set	t_first(i);
loop(i$t(i),
    if((ord(i) eq 1),
	t_first(i) = yes;
    ));
display t_first;

parameter
    qp_(i)	Private hhld demand
    pop_	Regional population
    SUBPAR_(i)	Substitution parameter in CDE minimum expenditure function
    INCPAR_(i)	Expansion parameter in the CDE minimum expenditure function
    pp_(i)	Private consumption price
    up_		Per capita utility from private expend
    yp_		Regional private consumption expenditure
;
variables
    sh_bp_(i)	Distribution parameters in CDE private utility function
    dummy_obj	Dummy variable for NLP
;
equations
    e_sh_bp_(i)
    e_dummy_obj
;

e_sh_bp_(i)$(t(i) and qp_(i)) ..

    (1 - sum(j$(t(j) and qp_(j)), sh_bp_(j)
	* up_**(SUBPAR_(j)*INCPAR_(j))
	* (pp_(j)/(yp_/pop_))**(SUBPAR_(j)))
    )$t_first(i)
    +
    ( ( sh_bp_(i) * up_**(SUBPAR_(i) * INCPAR_(i))
	* SUBPAR_(i) * (pp_(i)/(yp_/pop_))**(SUBPAR_(i) - 1)
    ) /
	( sum(j$(t(j) and qp_(j)),
	    sh_bp_(j) * up_**(SUBPAR_(j) * INCPAR_(j))
	    * SUBPAR_(j) * (pp_(j)/(yp_/pop_))**(SUBPAR_(j))) )
	- qp_(i)/pop_
    )$(not t_first(i)) =e= 0;

e_dummy_obj ..

    dummy_obj =e= 1;

model calib_mcp Calibration by MCP / e_sh_bp_.sh_bp_ /;
model calib_nlp Calibration by NLP / e_sh_bp_, e_dummy_obj /;

* sh_bp_.lo(i)$t(i) = 0;

*	----------------------------------------------------------------------
*	Model for calibration of distribution parameters:
display "com: -- Model for calibration of distribution parameters:";

parameter
    y_		Regional household income
    yp_		Regional private consumption expenditure
    yg_		Regional government consumption expenditure
    vsave_	Expenditure on NET savings
    uepriv_	Elasticity of cost wrt utility from private consumption
;

variables
    dppriv_	Private consumption distribution parameter
    dpgov_	Government consumption distribution parameter
    dpsave_	Saving distribution parameter
    uelas_	Elasticity of cost of utility wrt utility
;

equations
    e_dppriv_
    e_dpgov_
    e_dpsave_
    e_uelas_
;

e_dppriv_ ..

    yp_ * uepriv_ =e= y_ * uelas_ * dppriv_;

e_dpgov_ ..

    yg_ =e= y_ * uelas_ * dpgov_;

e_dpsave_ ..

    vsave_ =e= y_ * uelas_ * dpsave_;

e_uelas_ ..

    uelas_ * (dppriv_  + uepriv_ * (dpgov_ + dpsave_)) =e= uepriv_;

model calib_dist_mcp Calibration of distribution parameters by MCP
      / e_dppriv_.dppriv_, e_dpgov_.dpgov_, e_dpsave_.dpsave_, e_uelas_.uelas_ /;

*	----------------------------------------------------------------------
*	Calibration:
display "com: Calibration:";

option solprint = off;

*	----------------------------------------------------------------------
*	Calibration of distribution parameters in CDE private utility function:
display "com: -- Calibration of distribution parameters in CDE private utility function:";

putclose titlemaker
   '@title Experiment name = %exp_name%, Calibration of dist. parameters';
execute '.\%exp_name%_titlemaker.cmd';

loop(r,
    qp_(i) = qp0(i,r);
    pop_ = pop0(r);
    SUBPAR_(i) = SUBPAR(i,r);
    INCPAR_(i) = INCPAR(i,r);
    pp_(i) = pp0(i,r);
    up_ = up0(r);
    yp_ = PRIVEXP(r);
    qp_(i) = qp0(i,r);

    sh_bp_.l(i)$t(i) = 0.1;

    if(%fl_debug%,
	option solprint = on;
    else
	option solprint = off;
    );
    solve calib_mcp using mcp;

*     solve calib_nlp using nlp maximizing dummy_obj;

    option solprint = off;

if(((calib_mcp.solvestat <> 1) or (calib_mcp.modelstat <> 1)),
	abort "Calibration failed!!!!", calib_mcp.modelstat, calib_mcp.solvestat;
    );

    SH_BP(i,r) = sh_bp_.l(i);

);

SH_BP("sum",r) = sum(i, SH_BP(i,r));
if((smin((i,r), SH_BP(i,r)) < 0),
    abort "Calibration failed!!!!", SH_BP;
    else
    display "Calibrated distribution parameters in CDE utility.";
    display SH_BP;
);

*	----------------------------------------------------------------------
*	Calibration of distribution parameters in regional utility:
display "com: -- Calibration of distribution parameters in regional utility:";

loop(r,
    yp_ = yp0(r);
    yg_ = yg0(r);
    vsave_ = y0(r) - yp0(r) - yg0(r);
    uepriv_ = uepriv0(r);
    y_ = y0(r);

    dppriv_.l = yp0(r) / y0(r);
    dpgov_.l = yg0(r) / y0(r);
    dpsave_.l = (y0(r) - yp0(r) - yg0(r)) / y0(r);
    uelas_.l = 1/(dppriv_.l / uepriv_ + dpgov_.l + dpsave_.l)

    if(%fl_debug%,
	option solprint = on;
    else
	option solprint = off;
    );
    solve calib_dist_mcp using mcp;
    option solprint = off;

    if(((calib_dist_mcp.solvestat <> 1) or (calib_dist_mcp.modelstat <> 1)),
	abort "Calibration failed!!!!", calib_dist_mcp.modelstat, calib_dist_mcp.solvestat;
    );

    dppriv0(r) = dppriv_.l;
    dpgov0(r) = dpgov_.l;
    dpsave0(r) = dpsave_.l;
    uelas0(r) = uelas_.l;

);
display "Calibrated distribution parameters in regional utility.";
display dppriv0, dpgov0, dpsave0, uelas0;

option solprint = on;

*	----------------------------------------------------------------------
*	Initial values and lower bounds of endogenous variables:
display "com: Initial values and lower bounds of endogenous variables:";

*	----------------------------------------------------------------------
*	Initial values of endogenous variables:
display "com: -- Initial values of endogenous variables:";

*	Price variables:
ps.l(g,r) = 1;
psave.l(r) = 1;
pm.l(ns,r) = 1;
pgd.l(i,s) = 1;
pgm.l(i,s) = 1;
pim.l(i,r) = 1;
ppd.l(i,s) = 1;
ppm.l(i,s) = 1;
pfe.l(e,j,r) = 1;
pfd.l(i,j,r) = 1;
pfm.l(i,j,r) = 1;
pmes.l(es,j,r) = 1;
pcif.l(i,r,s) = 1;
pfob.l(i,r,s) = 1;
pt.l(m) = 1;
ptrans.l(i,r,s) = 1;
pms.l(i,r,s) = 1;
pgov.l(r) = 1;
pg.l(i,r) = 1;
pp.l(i,r) = 1;
pva.l(i,r) = 1;
pf.l(i,j,r) = 1;
pcgds.l(r) = 1;
pcgdswld.l = 1;
pr.l(i,r) = 1;
psave_adj.l = 1;

*	Quantity variables:
qo.l(j,r) = 1;
qsave.l(r) = 1;
qgd.l(i,s) = 1;
qgm.l(i,s) = 1;
qpd.l(i,s) = 1;
qpm.l(i,s) = 1;
qfe.l(e,j,r) = 1;
qfd.l(i,j,s) = 1;
qfm.l(i,j,s) = 1;
qxs.l(i,r,s) = 1;
qst.l(m,r) = 1;
qoes.l(es,j,r) = 1;
qim.l(i,s) = 1;
qg.l(i,r) = 1;
qp.l(i,r) = 1;
qva.l(i,r) = 1;
qf.l(i,j,r) = 1;
qtmfsd.l(m,i,r,s) = 1;
qtm.l(m) = 1;
qds.l(i,r) = 1;
u.l(r) = 1;
ug.l(r) = 1;
up.l(r) = 1;
kb.l(r) = 1;
ke.l(r) = 1;
ksvces.l(r) = 1;
qcgds.l(r) = 1;
globalcgds.l = 1;

*	Tax rates and tax revenues:
atpm.l(i,r) = atpm0(i,r);
atpd.l(i,r) = atpd0(i,r);
del_taxrgc.l(r) = del_taxrgc0(r);
del_taxrpc.l(r) = del_taxrpc0(r);
del_taxriu.l(r) = del_taxriu0(r);
del_taxrfu.l(r) = del_taxrfu0(r);
del_taxrout.l(r) = del_taxrout0(r);
del_taxrexp.l(r) = del_taxrexp0(r);
del_taxrimp.l(r) = del_taxrimp0(r);
del_taxrinc.l(r) = del_taxrinc0(r);
del_indtaxr.l(r) = del_indtaxr0(r);
del_ttaxr.l(r) = del_ttaxr0(r);

*	Other variables:
vconshr.l(i,r) = 1;
uepriv.l(r) = 1;
y.l(r) = 1;
yg.l(r) = 1;
yp.l(r) = 1;
rental.l(r) = 1;
rore.l(r) = 1;
rorc.l(r) = 1;
rorg.l = 1;
expand.l(c,r) = 1;
uelas.l(r) = 1;
fincome.l(r) = 1;
walras_sup.l = 1;
walras_dem.l = 1;
ao.l(i,r) = 1;
ava.l(i,r) = 1;
af.l(i,j,r) = 1;
afe.l(e,j,r) = 1;
atmfsd.l(m,i,r,s) = 1;

pop.l(r) = 1;
qo.l(e,r) = 1;
psaveslack.l(r) = 0;
profitslack.l(j,r) = 0;
endwslack.l(e,r) = 0;
incomeslack.l(r) = 0;
cgdslack.l(r) = 0;
tradslack.l(i,r) = 0;
walraslack.l = 0;

ams.l(i,r,s) = 1;
atm.l(m) = 1;
atf.l(i) = 1;
ats.l(r) = 1;
atd.l(s) = 1;
aosec.l(i) = 1;
aoreg.l(r) = 1;
avasec.l(i) = 1;
avareg.l(r) = 1;
afcom.l(i) = 1;
afsec.l(j) = 1;
afreg.l(r) = 1;
afecom.l(e) = 1;
afesec.l(j) = 1;
afereg.l(r) = 1;
aoall.l(i,r) = 1;
afall.l(i,j,r) = 1;
afeall.l(e,j,r) = 1;
au.l(r) = 1;
avaall.l(i,r) = 1;
atall.l(m,i,r,s) = 1;

dppriv.l(r) = 1;
dpgov.l(r) = 1;
dpsave.l(r) = 1;
to.l(ns,r) = to0(ns,r);
tp.l(r) = tp0(r);
tm.l(i,r) = tm0(i,r);
tms.l(i,r,s) = tms0(i,r,s);
tx.l(i,r) = tx0(i,r);
txs.l(i,r,s) = txs0(i,r,s);
tgd.l(t,r) = tgd0(t,r);
tgm.l(t,r) = tgm0(t,r);
tpd.l(t,r) = tpd0(t,r);
tpm.l(t,r) = tpm0(t,r);
tfd.l(i,j,r) = tfd0(i,j,r);
tfm.l(i,j,r) = tfm0(i,j,r);
tf.l(e,j,r) = tf0(e,j,r);

*	Variables in Appendices:
vxwfob.l(i,s) = 1;
viwcif.l(i,s) = 1;
vxwreg.l(r) = 1;
viwreg.l(r) = 1;
pfactreal.l(e,r) = 1;
pfactor.l(r) = 1;
pfactwld.l = 1;
psw.l(r) = 1;
pdw.l(r) = 1;
tot.l(r) = 1;
vgdp.l(r) = 1;
pgdp.l(r) = 1;
qgdp.l(r) = 1;
compvalad.l(i,r) = 1;
v_vxw.l(t,r) = 1;
sh_vxwd_vxw.l(t,r,s) = 1;
sh_vst_vxw.l(m,r) = 1;
DTBALi.l(i,r) = 1;
DTBAL.l(r) = 1;
DTBALR.l(r) = 1;
sh_vga_gdp.l(t,r) = 1;
sh_vpa_gdp.l(t,r) = 1;
sh_reginv_gdp.l(r) = 1;
sh_vxwd_gdp.l(t,r,s) = 1;
sh_vst_gdp.l(m,r) = 1;
sh_viws_gdp.l(t,r,s) = 1;
v_vxwregion.l(r) = 1;
sh_vxwd_vxwregion.l(t,r,s) = 1;
sh_vst_vxwregion.l(m,r) = 1;
v_viwregion.l(r) = 1;
sh_viws_viwregion.l(t,r,s) = 1;
;

*	Appendix:
ug_ev.l(r) = 1;
qg_ev.l(t,r) = 1;
up_ev.l(r) = 1;
uepriv_ev.l(r) = 1;
vconshr_ev.l(t,r) = 1;
qp_ev.l(t,r) = 1;
uelas_ev.l(r) = 1;
yp_ev.l(r) = 1;
yg_ev.l(r) = 1;
qsave_ev.l(r) = 1;
y_ev.l(r) = 1;
EV.l(r) = 0;
* u_ev.fx(r) = 1;

*	----------------------------------------------------------------------
*	Lower bound of endogenous variables:
display "com: -- Lower bound of endogenous variables";

ps.lo(g,r) = 1e-6;
psave.lo(r) = 1e-6;
pm.lo(ns,r) = 1e-6;
pgd.lo(i,s) = 1e-6;
pgm.lo(i,s) = 1e-6;
pim.lo(i,r) = 1e-6;
ppd.lo(i,s) = 1e-6;
ppm.lo(i,s) = 1e-6;
pfe.lo(e,j,r) = 1e-6;
pfd.lo(i,j,r) = 1e-6;
pfm.lo(i,j,r) = 1e-6;
pmes.lo(es,j,r) = 1e-6;
pcgds.lo(r) = 1e-6;
pms.lo(i,r,s) = 1e-6;
pfob.lo(i,r,s) = 1e-6;
pgov.lo(r) = 1e-6;
pcgdswld.lo = 1e-6;
pg.lo(i,r) = 1e-6;
pp.lo(i,r) = 1e-6;
pva.lo(i,r) = 1e-6;
pf.lo(i,j,r) = 1e-6;
pr.lo(i,r) = 1e-6;
ptrans.lo(i,r,s) = 1e-6;
pt.lo(m) = 1e-6;
pcif.lo(i,r,s) = 1e-6;
* psave_adj.lo = 1e-6;
qo.lo(j,r) = 1e-6;
qsave.lo(r) = 1e-6;
qgd.lo(i,s) = 1e-6;
qgm.lo(i,s) = 1e-6;
qpd.lo(i,s) = 1e-6;
qpm.lo(i,s) = 1e-6;
qfe.lo(e,j,r) = 1e-6;
qfd.lo(i,j,s) = 1e-6;
qfm.lo(i,j,s) = 1e-6;
kb.lo(r) = 1e-6;
qxs.lo(i,r,s) = 1e-6;
qst.lo(m,r) = 1e-6;
y.lo(r) = 1e-6;
qoes.lo(es,j,r) = 1e-6;
yg.lo(r) = 1e-6;
ug.lo(r) = 1e-6;
vconshr.lo(i,r) = 1e-6;
uepriv.lo(r) = 1e-6;
yp.lo(r) = 1e-6;
up.lo(r) = 1e-6;
qim.lo(i,s) = 1e-6;
globalcgds.lo = 1e-6;
qg.lo(i,r) = 0;
qp.lo(i,r) = 0;
qva.lo(i,r) = 0;
qf.lo(i,j,r) = 0;
rental.lo(r) = 0;
ke.lo(r) = 1e-6;
rore.lo(r) = 1e-6;
rorc.lo(r) = 1e-6;
qcgds.lo(r) = 0;
ksvces.lo(r) = 0;
expand.lo(c,r) = 0;
rorg.lo = 0;
qtmfsd.lo(m,i,r,s) = 0;
qtm.lo(m) = 0;
uelas.lo(r) = 0;
fincome.lo(r) = 0;
u.lo(r) = 0;
qds.lo(i,r) = 0;
walras_sup.lo = 0;
walras_dem.lo = 0;
ao.lo(i,r) = 0;
ava.lo(i,r) = 0;
af.lo(i,j,r) = 0;
afe.lo(e,j,r) = 0;
atmfsd.lo(m,i,r,s) = 0;
pfactor.lo(r) = 1e-6;
pfactwld.lo = 1e-6;

sh_netinv_globinv.l(r) = 1;
sh_netinv_save_globinv.l(r) = 1;
sh_vom_vendwreg.l(e,r) = 1;
sh_vendwreg_vendwwld.l(r) = 1;

sh_netinv_globinv.lo(r) = 0;
sh_vom_vendwreg.lo(e,r) = 0;
sh_vendwreg_vendwwld.lo(r) = 0;

pop.lo(r) = 0;
qo.lo(e,r) = 0;

ams.lo(i,r,s) = 0;
atm.lo(m) = 0;
atf.lo(i) = 0;
ats.lo(r) = 0;
atd.lo(s) = 0;
aosec.lo(i) = 0;
aoreg.lo(r) = 0;
avasec.lo(i) = 0;
avareg.lo(r) = 0;
afcom.lo(i) = 0;
afsec.lo(j) = 0;
afreg.lo(r) = 0;
afecom.lo(e) = 0;
afesec.lo(j) = 0;
afereg.lo(r) = 0;
aoall.lo(i,r) = 0;
afall.lo(i,j,r) = 0;
afeall.lo(e,j,r) = 0;
au.lo(r) = 0;
avaall.lo(i,r) = 0;
atall.lo(m,i,r,s) = 0;

* dppriv.lo(r) = 1;
* dpgov.lo(r) = 1;
* dpsave.lo(r) = 1;
to.lo(ns,r) = 0;
tp.lo(r) = 0;
tm.lo(i,r) = 0;
tms.lo(i,r,s) = 0;
tx.lo(i,r) = 0;
txs.lo(i,r,s) = 0;
tgd.lo(t,r) = 0;
tgm.lo(t,r) = 0;
tpd.lo(t,r) = 0;
tpm.lo(t,r) = 0;
tfd.lo(i,j,r) = 0;
tfm.lo(i,j,r) = 0;
tf.lo(e,j,r) = 0;

*	Variables in Appendices:
vxwfob.lo(i,s) = 0;
viwcif.lo(i,s) = 0;
vxwreg.lo(r) = 0;
viwreg.lo(r) = 0;
pfactreal.lo(e,r) = 0;
pfactor.lo(r) = 0;
pfactwld.lo = 0;
psw.lo(r) = 1e-6;
pdw.lo(r) = 1e-6;
tot.lo(r) = 0;
vgdp.lo(r) = 0;
pgdp.lo(r) = 1e-6;
qgdp.lo(r) = 0;
compvalad.lo(i,r) = 0;
* DTBALi.lo(i,r) = 0;
* DTBAL.lo(r) = 0;
* DTBALR.lo(r) = 0;
sh_vga_gdp.lo(t,r) = 0;
sh_vpa_gdp.lo(t,r) = 0;
sh_reginv_gdp.lo(r) = 0;
sh_vxwd_gdp.lo(t,r,s) = 0;
sh_vst_gdp.lo(m,r) = 0;
sh_viws_gdp.lo(t,r,s) = 0;
v_vxwregion.lo(r) = 0;
sh_vxwd_vxwregion.lo(t,r,s) = 0;
sh_vst_vxwregion.lo(m,r) = 0;
v_viwregion.lo(r) = 0;
sh_viws_viwregion.lo(t,r,s) = 0;
;
*	EV calibration in Appendix:
ug_ev.lo(r) = 0;
qg_ev.lo(t,r) = 0;
up_ev.lo(r) = 0;
uepriv_ev.lo(r) = 0;
vconshr_ev.lo(t,r) = 0;
qp_ev.lo(t,r) = 0;
uelas_ev.lo(r) = 0;
yp_ev.lo(r) = 0;
yg_ev.lo(r) = 0;
qsave_ev.lo(r) = 0;
y_ev.lo(r) = 0;

*	----------------------------------------------------------------------
*	Check:
display "com: ";

parameter
    chk_GHHDPRICE
;
chk_GHHDPRICE(t,r,"left")$qgd0(t,r)
    = pgd0(t,r) * pgd.l(t,r);
chk_GHHDPRICE(t,r,"right")$qgd0(t,r)
    = tgd.l(t,r) * pm0(t,r) * pm.l(t,r);
chk_GHHDPRICE(t,r,"diff")
    = chk_GHHDPRICE(t,r,"left") - chk_GHHDPRICE(t,r,"right");

display chk_GHHDPRICE;

*	----------------------------------------------------------------------
*	Fixed irrelevant values:
display "com: Fixed irrelevant values:";

pgd.fx(t,r)$(not qgd0(t,r)) = 0;



*	----------------------------------------------------------------------
*	Declaration of parameters for displaying results:
display "com: Declaration of parameters for displaying results:";

*	----------------------------------------------------------------------
*	Pecentage changes:

*	Saving:
parameters
    pc_psave(r)		Price of savings in region r
    pc_qsave(r)		Regional demand for NET savings
;
*	Government consumption:
parameters
    pc_pgd(*,s)		Price of domestic i in government consumption in s
    pc_qgd(*,s)		Government hhld demand for domestic i in region s
    pc_pm(*,r)		Market price of commodity i in region r
    pc_pgm(*,s)		Price of imports of i in government consumption in s
    pc_qgm(*,s)		Government hhld demand for imports of i in region s
    pc_pim(*,r)		Market price of composite import i in region r
;
*	Private consumption:
parameters
    pc_ppd(*,s)		Price of domestic i to private households in s
    pc_qpd(*,s)		Private hhld demand for domestic i in region s
    pc_ppm(*,s)		Price of imports of i by private households in s
    pc_qpm(*,s)		Private hhld demand for imports of i in region s
;
*	Firms:
parameters
    pc_ps(*,r)		Supply price of commodity i in region r
    pc_qo(*,r)		Industry output of commodity i in region r
    pc_pfe(*,*,r)	"Firms' price for endowment commodity i in ind. j, region r"
    pc_qfe(*,*,r) 	Demand for endowment i for use in ind. j in region r
    pc_pfd(*,*,s)	Price index for domestic purchases of i by j in region s
    pc_qfd(*,*,s) 	Domestic good i demanded by industry j in region s
    pc_pfm(*,*,s)	Price index for imports of i by j in region s
    pc_qfm(*,*,s)	Demand for i by industry j in region s
    pc_pmes(*,*,r)	Market price of sluggish endowment i used by j in r
;
*	Global bank:
parameters
    pc_kb(r)		Beginning-of-period capital stock in r
    pc_pcgds(r)		"Price of investment goods = ps(cgds,r)"
;
*	International trade and transport:
parameters
    pc_pms(*,r,s)	Domestic price for good i supplied from r to region s
    pc_qxs(*,r,s)	Export sales of commodity i from r to region s
    pc_pcif(*,r,s)	Cif world price of commodity i supplied from r to s
    pc_pfob(*,r,s)	Fob world price of commodity i supplied from r to s
    pc_qst(*,r)		Sales of m from r to international transport
;
*	Common parameters:
parameters
    pc_y(r)		Regional household income in region r
    pc_pop(r)		Regional population
    pc_qoes(*,*,r)	Supply of sluggish endowment i used by j in r
    pc_endwslack(*,r)	Slack variable in endowment market clearing condition
    pc_pgov(r)		Price index for gov't hhld expenditure in region r
    pc_yg(r)   		Regional government consumption expenditure in region r
    pc_ug(r)		Per capita utility from gov't expend. in region r
*     pc_ppriv(r)	Price index for private consumption expenditure in r
    pc_uepriv(r)	Elasticity of cost wrt utility from private consumption
    pc_yp(r)		Regional private consumption expenditure in region r
    pc_up(r)		Per capita utility from private expend. in region r
    pc_to(*,r)		Output (or income) tax in region r
    pc_qim(*,s)		"Aggregate imports of i in region s, market price weights"
    pc_globalcgds	global supply of capital goods for NET investment
    pc_pcgdswld		world average price of capital goods (net investment weights)
    pc_del_taxrgc(r)	Government consumption tax
    pc_del_taxrpc(r)	Private consumption tax
    pc_del_taxriu(r)	Tax on intermediate usage
    pc_del_taxrfu(r)	Tax on primary factor usage
    pc_del_taxrout(r)	Output tax
    pc_del_taxrexp(r)	Export tax
    pc_del_taxrimp(r)	Import tax
    pc_del_taxrinc(r)	Income tax
;
*	--------------------------------
*	Modules:

*	Government consumption:
parameters
    pc_pg(*,r)		Government consumption price for commodity i in region r
    pc_qg(*,r)		Government hhld demand for commodity i in region r
    pc_tgd(*,r)		Tax on domestic i purchased by government hhld in r
    pc_tgm(*,r)		Tax on imported i purchased by gov't hhld in r
;
*	Private consumption:
parameters
    pc_pp(*,r)		Private consumption price for commodity i in region r
    pc_qp(*,r)		Private hhld demand for commodity i in region r
    pc_tp(r)		"Comm.-, source-gen. shift in tax on private cons."
    pc_tpd(*,r)		"Comm.-, source-spec. shift in tax on private cons. of dom."
    pc_atpd(*,r)	Power of tax on domestic i purchased by private hhld in r
    pc_tpm(*,r)		"Comm.-, source-spec. shift in tax on private cons. of imp."
    pc_atpm(*,r)	Power of tax on imported i purchased by private hhld in r
;
*	Firms:
parameters
    pc_pva(*,r)		Firms' price of value added in industry j of region r
    pc_qva(*,r)		Value added in industry j of region r
    pc_pf(*,*,r)	Firms' price for commodity i for use by j in r
    pc_qf(*,*,r)	Demand for commodity i for use by j in region r
    pc_ao(*,r)		Output augmenting technical change in sector j of r
    pc_ava(*,r)		Value added augmenting tech change in sector i of r
    pc_af(*,*,r)	Composite intermed. input i augmenting tech change by j of r
    pc_afe(*,*,r)	Primary factor i augmenting tech change by j of r
    pc_ams(*,r,s)	Import i from region r augmenting tech change in region s
    pc_aosec(*)		"Output tech change of sector j, worldwide"
    pc_aoreg(r)		Output tech change in region r
    pc_aoall(*,r)	Output augmenting technical change in sector j of r
    pc_avasec(*)	"Value added tech change of sector j, worldwide"
    pc_avareg(r)	Value added tech change in region r
    pc_avaall(*,r)	Value added augmenting technical change in sector j of r
    pc_afcom(*)		"Intermediate tech change of input i, worldwide"
    pc_afsec(*)		"Intermediate tech change of sector j, worldwide"
    pc_afreg(r)		Intermediate tech change in region r
    pc_afall(*,*,r)	Intermediate input i augmenting tech change by j in r
    pc_tfd(*,*,r)	Tax on domestic i purchased by j in r
    pc_tfm(*,*,r)	Tax on imported i purchased by j in r
    pc_tf(*,*,r)	Tax on primary factor i used by j in region r
    pc_afecom(*)	"Factor input tech change of input i, worldwide"
    pc_afesec(*)	"Factor input tech change of sector j, worldwide"
    pc_afereg(r)	Factor input tech change in region r
    pc_afeall(*,*,r)	Primary factor i augmenting tech change sector j in r
    pc_profitslack(*,r)	Slack variable in the zero profit equation
;
*	Investment, Global Bank, Savings:
parameters
    pc_rental(r)	"Rental rate on capital = ps(capital,r)"
    pc_ke(r)		End-of-period capital stock in r
    pc_rore(r)		Expected net rate of return on capital stock in r
    pc_rorc(r)		Current net rate of return on capital stock in r
    pc_qcgds(r)		"Output of capital goods sector = qo(cgds,r)"
    pc_ksvces(r)	"Capital services = qo(capital,r)"
    pc_expand(*,r)	Change in investment levels relative to endowment stock
    pc_rorg		global net rate of return on capital stock
    pc_cgdslack(r)	Slack variable for qcgds(r)
    pc_psaveslack(r)	Slack variable for the savings price equation
;
*	International Trade:
parameters
    pc_tx(*,r)		Dest.-gen. change in subsidy on exports of i from r
    pc_txs(*,r,s)	Dest.-spec. change in subsidy on exports of i from r to s
    pc_tm(*,s)		Source-gen. change in tax on imports of i into s
    pc_tms(*,r,s)	Source-spec. change in tax on imports of i from r into s
    pc_pr(*,r)		Ratio of domestic to imported prices in r
;
*	International Transport Services:
parameters
    pc_qtmfsd(m,*,r,s)	International usage margin m on i from r to s
    pc_atmfsd(m,*,r,s)	Tech change in m's shipping of i from region r to s
    pc_atm(m)		"Tech change in mode m, worldwide"
    pc_atf(*)		"Tech change shipping of i, worldwide"
    pc_ats(r)		Tech change shipping from region r
    pc_atd(s)		Tech change shipping to s
    pc_atall(m,*,r,s)	Tech change in m's shipping of i from region r to s
    pc_ptrans(*,r,s)	Cost index for international transport of i from r to s
    pc_qtm(m)		Global margin usage
    pc_pt(m)		"Price of composite margins services, type"
;
*	Regional household:
parameters
    pc_uelas(r)		Elasticity of cost of utility wrt utility
    pc_dppriv(r)	Private consumption distribution parameter
    pc_dpgov(r)		Government consumption distribution parameter
    pc_dpsave(r)	Saving distribution parameter
    pc_fincome(r)	Factor income at market prices net of depreciation
    pc_del_indtaxr(r)	Indirect taxes in r
    pc_del_ttaxr(r)	Taxes in r
    pc_incomeslack(r)	Slack variable in the expression for regional income
*     pc_dpav(r)	"Average distribution parameter shift, for EV calc."
*     pc_p(r)		Price index for disposition of income by regional household
    pc_au(r)		Input-neutral shift in utility function
*     pc_dpsum(r)	Sum of the distribution parameters
    pc_u(r)		Per capita utility from aggregate hhld expend. in region r
;
*	Market clearing condition:
parameters
    pc_qds(*,r)		Domestic sales of commodity i in r
    pc_tradslack(*,r)	Slack variable in tradeables market clearing condition
    pc_walras_sup	Supply in omitted market--global supply of cgds composite
    pc_walras_dem	Demand in the omitted market--global demand for savings
    pc_walraslack	Slack variable in the omitted market
;
*	----------------------------------------------------------------------
*	Appendices:
parameters
    pc_vxwfob(*,s)	    "Value of merchandise regional exports, by commodity, FOB"
    pc_viwcif(*,s)	    "Value of merchandise regional imports, by commodity, CIF"
    pc_vxwreg(r)	    "Value of merchandise exports, by region"
    pc_viwreg(r)	    "Value of merchandise imports, by region, at world prices"

parameters
    pc_pfactreal(*,r)	"Ratio of return to primary factor i to CPI in r"
    pc_pfactreal(*,r)	"Ratio of return to primary factor i to CPI in r"
    pc_pfactor(r)	"Market price index of primary factors, by region"
    pc_pfactwld	    	"World price index of primary factors"

parameters
    pc_psw(r)	    "Index of prices received for tradeables produced in r"
    pc_pdw(r)	    "Index of prices paid for tradeables used in region r"
    pc_tot(r)	    "Terms of trade for region r: tot(r) = psw(r) - pdw(r)"

parameters
    pc_vgdp(r)	    "Change in value of GDP"
    pc_pgdp(r)	    "GDP price index"
    pc_qgdp(r)	    "GDP quantity index"
    pc_compvalad(*,r)  "Composition of value added for good i and region r"

parameters
    pc_DTBALi(*,r)	    "Change in trade balance by i and by r, $US million"
    pc_DTBAL(r) 	    "change in trade balance X - M, $US million"
    pc_DTBALR(r)	    "Change in ratio of trade balance to regional income"
;
*	Equivalent variation:
parameter
    l_EV(*)		"Equivalent variation, $US million"
;

*	Delete irrelevant files:
execute 'del .\%basedata_file%.gdx';
execute 'del .\%par_file%.gdx';
execute 'del .\%set_file%.gdx';

* --------------------
* Local Variables:
* mode: gams
* fill-column: 76
* End:
